 function G_xy = Green_incl_g_xy_inf(a,b,theta,x,y)
%
% Provides the Green's function g_xy (for normal stresses sigma_xy) analytically integrated
% over an infinite reservoir domain crossed by an inclined displaced fault. 
%
% Jan Dirk Jansen, TU Delft, November 2018; vectorized August 2022
%

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y)*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );
x = x + small * (x == 0);

% Manually simplified symbolic output for limiting case of an infinite reservoir;
%     eq. (SI 48) of Jansen et al. (2019):
G_xy =   ((sin(theta))^2)/2 *...
    log((((y-a).^2+(x-a*cot(theta)).^2).*((y+a).^2+(x+a*cot(theta)).^2)) ...
    ./  (((y-b).^2+(x-b*cot(theta)).^2).*((y+b).^2+(x+b*cot(theta)).^2)))...
   +(sin(theta)*cos(theta)) ...
   .* (atan ((y+a+cot(theta).*(x+a*cot(theta)))./(y*cot(theta)-x))...
     - atan ((y-b+cot(theta).*(x-b*cot(theta)))./(y*cot(theta)-x))...
     + atan ((y-a+cot(theta).*(x-a*cot(theta)))./(y*cot(theta)-x))...
     - atan ((y+b+cot(theta).*(x+b*cot(theta)))./(y*cot(theta)-x)));
 
% % Further simplified, only valid at fault; eq. (SI 51) of Jansen et al. (2019):
% G_xy = ((sin(theta))^2/2) *... 
%    log( ( (y-a).^2 .* (y+a).^2 ) ...
%      ./ ( (y-b).^2 .* (y+b).^2 ) )...
%    - sin(theta)*cos(theta)*(pi/2) * ( sign(y+a) + sign(y-a) - sign(y-b) - sign(y+b) );

 