function G_yy = Green_incl_g_yy(a,b,c,d,theta,x,y)
%
% Provides the Green's function g_yy (for stress sigma_yy) analytically integrated over a
% rectangular reservoir domain crossed by an inclined displaced fault. The integral is
% either split in four domains (two rectangles and two triangles) or in two domains (two
% trapezoids).
%
% Jan Dirk Jansen, TU Delft, August 2022
%

% Compute integration boundaries:
e = a/tan(theta);            
f = b/tan(theta);
              
% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y)*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );
x = x + small*abs(c+d).*( (x == 0) + (x == c) + (x == d) + (x == e) + (x == f) + ...
    (x == -c) + (x == -d) + (x == -e) + (x == -f) );

% G_yy_1 = g_yy_int_square(-c,-f,-b,a,x,y); % square to the left
% G_yy_2  = g_yy_int_triang(-e,f,-a,b,-x,-y); % triangle to the left
% G_yy_3 = g_yy_int_triang(-e,f,-a,b,x,y); % triangle to the right
% G_yy_4 = g_yy_int_square(f,d,-a,b,x,y); % square to the right
% 
% G_yy = G_yy_1 + G_yy_2 + G_yy_3 + G_yy_4;

G_yy_12 = g_yy_int_trap(-e,f,c,-a,b,-x,-y); % trapezoid to the left
G_yy_34 = g_yy_int_trap(-e,f,d,-a,b,x,y); % trapezoid to the right

G_yy = G_yy_12 + G_yy_34; 


