function G_yy = Green_incl_g_yy_inf(a,b,theta,x,y)
%
% Provides the Green's function g_yy (for normal stresses sigma_yy) analytically integrated
% over an infinite reservoir domain crossed by an inclined displaced fault.
%
% Jan Dirk Jansen, TU Delft, November 2018; vectorized August 2022
%

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y)*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );
x = x + small * (x == 0);

% Manually simplified symbolic output for limiting case of an infinite reservoir;
%     eq. (SI 47) of Jansen et al. (2019):
G_yy =  atan( (x-a*cot(theta))./(y-a) ) - atan( (x-b*cot(theta))./(y-b) )...
   +    atan( (x+a*cot(theta))./(y+a) ) - atan( (x+b*cot(theta))./(y+b) )...
   + (pi/2) * ( sign(y+a)-sign(y-a)+sign(y+b)-sign(y-b) )...
   + ( sin(theta)*cos(theta)/2 ) .*...
     log(  ( ((y-b).^2+(x-(b*cot(theta))).^2) .* ((y+b).^2 +(x+(b*cot(theta))).^2) ) ...
          ./( ((y-a).^2+(x-(a*cot(theta))).^2) .* ((y+a).^2 +(x+(a*cot(theta))).^2) ) ) ...
   - ((cos(theta)).^2) ...
   .* (   atan( (x*tan(theta)+a+tan(theta)^2.*(y+a)) ./ (tan(theta).*(y-x*tan(theta))) )...
       -  atan( (x*tan(theta)-b+tan(theta)^2.*(y-b)) ./ (tan(theta).*(y-x*tan(theta))) )...
       +  atan( (x*tan(theta)-a+tan(theta)^2.*(y-a)) ./ (tan(theta).*(y-x*tan(theta))) )...
       -  atan( (x*tan(theta)+b+tan(theta)^2.*(y+b)) ./ (tan(theta).*(y-x*tan(theta))) ) );
 
% % Further simplified, only valid at fault; eq. (SI 50) of Jansen et al. (2019):
% G_yy = (sin(theta)*cos(theta)/2) *...
%     log( ( (y-b).^2 .* (y+b).^2 ) ...
%     ./ ( (y-a).^2 .* (y+a).^2 ) )...
%     + (cos(theta)).^2 .* (pi/2)*( sign(y+a) + sign(y-a) - sign(y-b) - sign(y+b) ) ...
%     +                    (pi/2)*( sign(y+a) - sign(y-a) - sign(y-b) + sign(y+b) );
% 
