function G_xx = Green_vert_g_xx(a,b,c,d,x,y)
%
% Provides the Green's function g_xx (for stress sigma_xx) analytically integrated over a
% rectangular reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) rectangle to the left of the fault, 2) rectangle to the right.
%

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y)*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );
x = x + small*abs(c+d).*( (x == 0) + (x == c) + (x == d) + (x == -c) + (x == -d) );

% % Integrate:
% G_xx_1 = g_xx_int_square(-c,0,-b,a,x,y);
% G_xx_4 = g_xx_int_square(0,d,-a,b,x,y);
% 
% G_xx = G_xx_1 + G_xx_4;

% Alternative; manually simplified output for a finite reservoir:
% % G_xx = atan2( (-b - a)* x      , (      x.^2 + (y + b).*(y - a)) ) ...
% %      - atan2( (-b - a)*(x + c) , ((x + c).^2 + (y + b).*(y - a)) ) ...
% %      + atan2( (-a - b)*(x - d) , ((x - d).^2 + (y + a).*(y - b)) ) ...
% %      - atan2( (-a - b)* x      , (      x.^2 + (y + a).*(y - b)) );
 
% % G_xx = atan2( -(a + b)* x      , (      x.^2 + (y + b).*(y - a)) ) ...
% %      - atan2( -(a + b)*(x + c) , ((x + c).^2 + (y + b).*(y - a)) ) ...
% %      + atan2( -(a + b)*(x - d) , ((x - d).^2 + (y + a).*(y - b)) ) ...
% %      - atan2( -(a + b)* x      , (      x.^2 + (y + a).*(y - b)) );
 
G_xx = atan2(  (a + b)* x      , (      x.^2 + (y - b).*(y + a)) ) ...
     + atan2(  (a + b)*(x + c) , ((x + c).^2 + (y + b).*(y - a)) ) ...
     - atan2(  (a + b)*(x - d) , ((x - d).^2 + (y + a).*(y - b)) ) ...
     - atan2(  (a + b)* x      , (      x.^2 + (y - a).*(y + b)) );
 
