function G_xx = Green_vert_g_xx_inf(a,b,x,y)
%
% Provides the Green's function g_xx (for normal stresses sigma_xx) analytically integrated
% over an infinite reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) reservoir to the left of the fault, 2) reservoir to the right.
%

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y)*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );

% Manually simplified symbolic output for limiting case of an infinite reservoir:
G_xx_1 = - atan2((a+b)*x,(x.^2+(y-a).*(y+b)));
G_xx_4 = atan2((a+b)*x,(x.^2+(y-b).*(y+a)));
G_xx = G_xx_1 + G_xx_4; %  Eq. (SI 43) Jansen et al. (2019)
