function G_xy = Green_vert_g_xy_inf(a,b,x,y)
%
% Provides the Green's function g_xy (for shear stresses sigma_xy) analytically integrated
% over an infinite reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) reservoir to the left of the fault, 2) reservoir to the right.
%

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y).*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );

% Manually simplified symbolic output for limiting case of an infinite reservoir:
G_xy = 0.5* log(  ( (x.^2+(y-a).^2) .* (x.^2+(y+a).^2) ) ./ ...
                  ( (x.^2+(y-b).^2) .* (x.^2+(y+b).^2) )  );
