function G_y = Green_vert_g_y(a,b,c,d,x,y)
%
% Provides the Green's function g_y (for displacements u_y) analytically integrated over a
% rectangular reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) rectangle to the left of the fault, 2) rectangle to the right.
%

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y)*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );
x = x + small*abs(c+d).*( (x == 0) + (x == c) + (x == d) + (x == -c) + (x == -d) );

% % % Original symbolic output (as taken from Matlab command window):
% % G_y_1 = ...
% %  (x*log(2*c*x + (b + y)^2 + c^2 + x^2))/4 ...
% %  - (x*log((b + y)^2 + x^2))/4 ...
% %  - (c*log(2*c*x + c^2 + x^2 + (a - y)^2))/4 ...
% %  - (x*log(2*c*x + c^2 + x^2 + (a - y)^2))/4 ...
% %  + (x*log(x^2 + (a - y)^2))/4 ...
% %  + (atan(c/(b + y) + x/(b + y)) ...
% %  - atan(x/(b + y)))*(b/2 + y/2) ...
% %  + (atan(x/(a - y)) - atan(c/(a - y) ...
% %  + x/(a - y)))*(a/2 - y/2) ...
% %  + (c*log(2*c*x + (b + y)^2 + c^2 + x^2))/4;
  
% % % G_y_4 =...
% % (x*log((a + y)^2 + x^2))/4 ...
% % - (x*log((a + y)^2 - 2*d*x + d^2 + x^2))/4 ...
% % + (atan(d/(a + y) - x/(a + y)) ...
% % + atan(x/(a + y)))*(a/2 + y/2) ...
% % - (atan(x/(b - y)) + atan(d/(b - y) ...
% % - x/(b - y)))*(b/2 - y/2) ...
% % - (d*log(d^2 - 2*d*x + x^2 + (b - y)^2))/4 ...
% % + (x*log(d^2 - 2*d*x + x^2 + (b - y)^2))/4 ...
% % - (x*log(x^2 + (b - y)^2))/4 ...
% % + (d*log((a + y)^2 - 2*d*x + d^2 + x^2))/4;

% % % Manually simplified symbolic output (only g_y_4; just to check):
% % G_y_4 = ...
% %   (log((x-d)^2 + (y-b)^2) - log((x-d)^2 + (y+a)^2)) * (x-d)/4 ...
% % - (log(    x^2 + (y-b)^2) - log(    x^2 + (y+a)^2)) *     x/4 ...
% % - (atan(    x/(y-b)) - atan((x-d)/(y-b))) * (y-b)/2 ...
% % + (atan(    x/(y+a)) - atan((x-d)/(y+a))) * (y+a)/2;
 
% % % Further manually simplified symbolic output (only g_y_4; requires use of atan2 function):
% % G_y_4 = ...
% %   log(((x-d)^2 + (y-b)^2) / ((x-d)^2 + (y+a)^2) ) * (x-d)/4 ...
% % - log((    x^2 + (y-b)^2) / (    x^2 + (y+a)^2) ) *     x/4 ...
% % + atan2( -d*(y-b) , ((y-b)^2 + (x-d)*x) ) * (y-b)/2 ...
% % - atan2( -d*(y+a) , ((y+a)^2 + (x-d)*x) ) * (y+a)/2;

% Manually simplified symbolic output (via generic integration over a square):
G_y_1 = g_y_int_square(-c,0,-b,a,x,y);
G_y_4 = g_y_int_square(0,d,-a,b,x,y);

G_y = G_y_1 + G_y_4;

