function G_yy = Green_vert_g_yy(a,b,c,d,x,y)
%
% Provides the Green's function g_yy (for stress sigma_yy) analytically integrated over a
% rectangular reservoir domain crossed by a vertical displaced fault. The integral is
% splitted in two domains: 1) rectangle to the left of the fault, 2) rectangle to the right.
%

% Check if x or y corresponds to a singularity (at the integration boundaries) and if so,
% perturb the values to avoid problems (division by zero): 
small = 1e-9; % small number to modify input parameters  
y = y + sign(y)*small*(a+b).*( (y == a) + (y == b) + (y == -a) + (y == -b) );
x = x + small*abs(c+d).*( (x == 0) + (x == c) + (x == d) + (x == -c) + (x == -d) );

% Integrate:
G_yy_1 = g_yy_int_square(-c,0,-b,a,x,y);
G_yy_4 = g_yy_int_square(0,d,-a,b,x,y);

G_yy = G_yy_1 + G_yy_4;

