function G_x = g_x_int_square(p,q,r,s,x,y)
%
% Computes the integral of Green's function g_x for a square area with
% p <= zeta <= q (in the x direction) and r <= xi <= s (in the y direction).
%

% Manually simplified:
% % part_1 =   (  log((x-q)^2+(y-s)^2) - log((x-p)^2+(y-s)^2)  ) * (y-s)/4;
% % part_2 = - (  log((x-q)^2+(y-r)^2) - log((x-p)^2+(y-r)^2)  ) * (y-r)/4;
% % part_3 =   ( atan((y-s)/(x-q)) - atan((y-r)/(x-q)) ) * (x-q)/2;
% % part_4 = - ( atan((y-s)/(x-p)) - atan((y-r)/(x-p)) ) * (x-p)/2;

% Further manually simplified, with atan2 function:
part_1 =  log( ((x-q).^2 + (y-s).^2) ./ ((x-p).^2 + (y-s).^2) ) .* (y-s)/4; 
part_2 = -log( ((x-q).^2 + (y-r).^2) ./ ((x-p).^2 + (y-r).^2) ) .* (y-r)/4; 
part_3 =  atan2( (r-s) .* (x-q), ( (x-q).^2 + (y-r).*(y-s)) ) .* (x-q)/2; 
part_4 = -atan2( (r-s) .* (x-p), ( (x-p).^2 + (y-r).*(y-s)) ) .* (x-p)/2; 

G_x = part_1 + part_2 + part_3 + part_4; 