function G_x = g_x_int_square_Wu(p,q,r,s,x,y)
%
% Computes the integral of Green's function g_x for a square area with
% p <= zeta <= q (in the x direction) and r <= xi <= s (in the y direction).
%
% Uses expressions from Wu et al. (2024).
%
% Note: only uses the full-space part of the expressions (corresponding to radius R_1) and
% ignores the half-space terms (corresponding to radius R_2). 
%

part_1 =  -(y-s)/2 .* log((y-s).^2+(x-q).^2) + (y-r)/2 .* log((y-r).^2+(x-q).^2);
part_2 =   (y-s)/2 .* log((y-s).^2+(x-p).^2) - (y-r)/2 .* log((y-r).^2+(x-p).^2);
part_3 =   q  * ( atan((y-s)./(x-q)) - atan((y-r)./(x-q)) ) ...
         + x .* ( atan((x-q)./(y-s)) - atan((x-q)./(y-r)) );
part_4 = - p  * ( atan((y-s)./(x-p)) - atan((y-r)./(x-p)) ) ...
         - x .* ( atan((x-p)./(y-s)) - atan((x-p)./(y-r)) );

extra = pi .* x .* (p < x) .* (x < q) .* (r < y) .* (y < s); 

G_x = (-1/2) * (part_1 + part_2 + part_3 + part_4) + extra; 