function G_xx = g_xx_int_square(p,q,r,s,x,y)
%
% Computes the integral of Green's function g_xx for a square area with
% p <= zeta <= q (in the x direction) and r <= xi <= s (in the y direction).
%

% % Compute the integrals symbolically: (Note: only done once and off-line; time consuming!)
% syms P Q R S X Y Zeta Xi 
% gxx = ( (Y-Xi)^2 - (X-Zeta)^2 ) / ( (X-Zeta)^2 + (Y-Xi)^2 )^2;
% g1xx1 = int(gxx,Zeta);
% g2xx1 = simplify(subs(g1xx1,Zeta,Q) - subs(g1xx1,Zeta,P),'Steps',10);
% g3xx1 = int(g2xx1,Xi);
% g4xx1 = simplify(subs(g3xx1,Xi,S) - subs(g3xx1,Xi,R),'Steps',10)
% clear P Q R S X Y Zeta Xi

% Original symbolic output (as taken from Matlab command window after replacing capitals):
% G_xx = atan((r - y)/(p - x)) - atan((r - y)/(q - x)) - atan((s - y)/(p - x)) + atan((s - y)/(q - x));

% % Modified output (reordered variables with associated sign switches):
% G_xx = atan((y - r)/(x - p)) - atan((y - r)/(x - q)) - atan((y - s)/(x - p)) + atan((y - s)/(x - q));

% Manually simplified; Eq. (SI 32) of Jansen et al. (2019):
G_xx = atan2( (r - s)*(x - q) , ((x - q).^2 + (y - r).*(y - s)) ) ...
     - atan2( (r - s)*(x - p) , ((x - p).^2 + (y - r).*(y - s)) );
