function G_xx = g_xx_int_triang(o,p,r,s,x,y)
% Computes the integral of Green's function g_xx for a triangular area to the right of the
% fault with o <= xi/tan(theta) <= zeta <= p (in the x direction) and r <= xi <= s (in the y
% direction), 
%
% Pranshu Singhal, TU Delft, December 2018
%
theta = atan2((s-r),(p-o));
% Original symbolic output (as taken from Matlab command window after replacing capitals):
% G_xx = (log(r^2 - (x^2*cos(2*theta))/2 - (y^2*cos(2*theta))/2 - r*y + x^2/2 + y^2/2 + r*y*cos(2*theta) - r*x*sin(2*theta))*sin(2*theta))/4 ...
%        -(sin(2*theta)*log(s^2 - (x^2*cos(2*theta))/2 - (y^2*cos(2*theta))/2 - s*y + x^2/2 + y^2/2 + s*y*cos(2*theta) - s*x*sin(2*theta)))/4 ...
%        - cos(theta)^2*(atan((r - y)/(p - x)) - atan((s - y)/(p - x)))...
%        - sin(theta)^2*(atan((r - y)/(p - x)) - atan((s - y)/(p - x)) - atan((2*r - y + y*cos(2*theta) - x*sin(2*theta))/(x*cos(2*theta) - x + y*sin(2*theta))) + atan((2*s - y + y*cos(2*theta) - x*sin(2*theta))/(x*cos(2*theta) - x + y*sin(2*theta))));

% % Manually simplified:
% G_xx = (1/4)*sin(2*theta) * log((r^2 - 2*r*sin(theta)*(y*sin(theta)...
%       + x*cos(theta)) + (x^2 + y^2 ) * (sin(theta))^2)/(s^2 - 2*s*sin(theta)*(y*sin(theta)...
%       + x*cos(theta)) + (x^2 + y^2 ) * (sin(theta))^2))...
%       + atan2( (r - s)*(x - p) , ((x - p)^2 + (y - r)*(y - s)) ) ... 
%       -(sin(theta))^2 * (-atan((r-sin(theta)*(y*sin(theta) + x*cos(theta)))/( sin(theta)*(y*cos(theta) - x*sin(theta))))...
%       + atan((s-sin(theta)*(y*sin(theta) + x*cos(theta)))/ (sin(theta)*(y*cos(theta) - x*sin(theta)))));

% Further simplified; eq. (SI 35) of Jansen et al. (2019):
G_xx = (1/2) * log( ( (y-r)^2+(x-r*cot(theta))^2 ) / ( (y-s)^2+(x-s*cot(theta))^2 ) ) * sin(theta)*cos(theta) ...
     + atan2( ( (r-s)*(x-p) ) , ( (x-p)^2+(y-r)*(y-s) ) ) ...
     - atan2( ( (s-r)*(y*cot(theta)-x) ) , ( x^2+y^2+r*s*(csc(theta))^2-(r+s)*(y+x*cot(theta))  )  ) * sin(theta)^2;
    