function G_xy = g_xy_int_square(p,q,r,s,x,y)
% Computes the integral of Green's function g_xy for a square area with
% p <= zeta <= q (in the x direction) and r <= xi <= s (in the y direction).
%

% % Compute the integrals symbolically: (Note: only done once and off-line; time consuming!)
% syms P Q R S X Y Zeta Xi 
% RR = ((X - Zeta)^2 + (Y - Xi)^2)^2;
% gxy = -2*((X-Zeta)*(Y-Xi))/RR; % Green's function g_xx;
% g1xy1 = int(gxy,Zeta);
% g2xy1 = simplify(subs(g1xy1,Zeta,Q) - subs(g1xy1,Zeta,P),'Steps',10);
% g3xy1 = int(g2xy1,Xi);
% g4xy1 = simplify(subs(g3xy1,Xi,S) - subs(g3xy1,Xi,R),'Steps',10)
% clear P Q R S X Y Zeta Xi

% Original symbolic output (as taken from Matlab command window after replacing capitals):
% G_xy = log(p^2 - 2*p*x + r^2 - 2*r*y + x^2 + y^2)/2 ...
%      - log(p^2 - 2*p*x + s^2 - 2*s*y + x^2 + y^2)/2 ...
%      - log(q^2 - 2*q*x + r^2 - 2*r*y + x^2 + y^2)/2 ...
%      + log(q^2 - 2*q*x + s^2 - 2*s*y + x^2 + y^2)/2;

% Manually simplified (1):
% G_xy = log((x-p)^2 + (y-r)^2)/2 ...
%      - log((x-p)^2 + (y-s)^2)/2 ...
%      - log((x-q)^2 + (y-r)^2)/2 ...
%      + log((x-q)^2 + (y-s)^2)/2;

 % Manually simplified (2); Eq. (SI 34) of Jansen et al. (2019):
G_xy = 0.5 * log( ((x-p).^2 + (y-r).^2) .* ((x-q).^2 + (y-s).^2) ...
        ./  (((x-p).^2 + (y-s).^2) .* ((x-q).^2 + (y-r).^2)) );
