function G_y = g_y_int_square(p,q,r,s,x,y)
%
% Computes the integral of Green's function g_y for a square area with
% p <= zeta <= q (in the x direction) and r <= xi <= s (in the y direction).
%

% % % Manually simplified:
% % part_1 =    ( log((x-q)^2+(y-s)^2) - log((x-q)^2+(y-r)^2) ) * (x-q)/4;
% % part_2 =  - ( log((x-p)^2+(y-s)^2) - log((x-p)^2+(y-r)^2) ) * (x-p)/4;
% % part_3 =    ( atan((x-q)/(y-s)) - atan((x-p)/(y-s)) ) * (y-s)/2;
% % part_4 =  - ( atan((x-q)/(y-r)) - atan((x-p)/(y-r)) ) * (y-r)/2;

% Further manually simplified (requires use of atan2 function):
part_1 =  log( ((x-q).^2 + (y-s).^2) ./ ((x-q).^2 + (y-r).^2) ) .* (x-q)/4; 
part_2 = -log( ((x-p).^2 + (y-s).^2) ./ ((x-p).^2 + (y-r).^2) ) .* (x-p)/4; 
part_3 =  atan2( (p-q) .* (y-s), ( (y-s).^2 + (x-q).*(x-p)) ) .* (y-s)/2; 
part_4 = -atan2( (p-q) .* (y-r), ( (y-r).^2 + (x-q).*(x-p)) ) .* (y-r)/2; 

G_y = part_1 + part_2 + part_3 + part_4; 