function G_y = g_y_int_square_Cornelissen(p,q,r,s,x,y)
%
% Computes the integral of Green's function g_y for a square area with
% p <= zeta <= q (in the x direction) and r <= xi <= s (in the y direction).
%
% Uses expressions from Cornelissen et al. (2024).
%
% Note: here we multiply all terms by a factor f = 0.5, to correct for the different scaling as
% compared to Jansen et al. (2019) and Wu et al. (2024).   
%

f = 0.5; % correction factor to compensate for different scaling

part_1 =    log( ((x-q).^2+(y-s).^2) ./ ((x-q).^2+(y-r).^2) ) .* (x-q)/2;
part_2 =  - log( ((x-p).^2+(y-s).^2) ./ ((x-p).^2+(y-r).^2) ) .* (x-p)/2;
part_3 =    ( atan((x-q)./(y-s)) - atan((x-p)./(y-s)) ) .* (y-s);
part_4 =  - ( atan((x-q)./(y-r)) - atan((x-p)./(y-r)) ) .* (y-r);

G_y = (part_1 + part_2 + part_3 + part_4) * f; 