function G_yy = g_yy_int_square(p,q,r,s,x,y)
%
% Computes the integral of Green's function g_yy for a square area with
% p <= zeta <= q (in the x direction) and r <= xi <= s (in the y direction).
%

% % Compute the integrals symbolically: (Note: only done once and off-line; time consuming!)
% syms P Q R S X Y Zeta Xi 
% gyy = ( (X-Zeta)^2 -(Y-Xi)^2 ) / ( (X-Zeta)^2 + (Y-Xi)^2 )^2;
% g1yy1 = int(gyy,Xi);
% g2yy1 = simplify(subs(g1yy1,Xi,S) - subs(g1yy1,Xi,R),'Steps',10);
% g3yy1 = int(g2yy1,Zeta);
% g4yy1 = simplify(subs(g3yy1,Zeta,Q) - subs(g3yy1,Zeta,P),'Steps',10)
% clear P Q R S X Y Zeta Xi

% Original symbolic output (as taken from Matlab command window after replacing capitals):
% G_yy = atan((p - x)/(r - y)) - atan((p - x)/(s - y)) - atan((q - x)/(r - y)) + atan((q - x)/(s - y));

% % Modified output (reordered variables with associated sign switches):
% G_yy = atan((x - p)/(y - r)) - atan((x - q)/(y - r)) + atan((x - q)/(y - s)) - atan((x - p)/(y - s));

% Manually simplified; Eq. (SI 33) of Jansen et al. (2019):
G_yy = atan2( (p - q)*(y - s) , ((y - s).^2 + (x - q).*(x - p)) ) ...
     - atan2( (p - q)*(y - r) , ((y - r).^2 + (x - q).*(x - p)) );
