function G_yy = g_yy_int_trap(o,p,q,r,s,x,y)
%
% Computes the integral of Green's function g_yy for a trapezoidal area to the right of the 
% fault. 
%
% Jan Dirk Jansen, TU Delft, August 2022
%
theta = atan2((s-r),(p-o));

% % Eq. (SI 39) of Jansen et al. (2019):
% % Checked with Macsyma and seems to be correct. However, gives (minor but irritating) ...
%     % spurious results (concentrated stresses).
% G_yy = (1/2) * log( ( (x-p).^2+(y-p*cot(theta)).^2 ) ./ ( (x-o).^2+(y-o*cot(theta)).^2 ) ) * sin(theta)*cos(theta) ...
%      + atan2( ( (p-q)*(y-s) ) , ( (y-s).^2+(x-p).*(x-q) ) ) ...
%      - atan2( ( (o-q)*(y-r) ) , ( (y-r).^2+(x-o).*(x-q) ) ) ...
%      - atan2( ( (p-o)*(y-x*tan(theta)) ) , ( x.^2+y.^2+o*p*(sec(theta))^2-(p+o)*(x+y*tan(theta)) ) ) * cos(theta)^2;

% Alternative: Eq. (SI 33) + Eq. (SI 36) of Jansen et al. (2019):
G_yy = (1/2) * log( ( (x-p).^2+(y-p*tan(theta)).^2 ) ./ ( (x-o).^2+(y-o*tan(theta)).^2 ) ) * sin(theta)*cos(theta) ...
     + atan2( (p-q)*(y-s) , ((y-s).^2 + (x-q).*(x-p)) ) ...
     - atan2( (p-q)*(y-r) , ((y-r).^2 + (x-q).*(x-p)) ) ... 
     - atan2( ( (o-p)*(y-r) ) , ( (y-r).^2+(x-p).*(x-o) ) ) ...
     - atan2( ( (p-o)*(y-x*tan(theta)) ) , ( x.^2+y.^2+o*p*(sec(theta))^2-(p+o)*(x+y*tan(theta)) ) ) * cos(theta)^2;

