function [w_i,w_j,y_i,y_j,z_i,z_j] = ifs_GaussCheb(end_type,N,y_min,y_plus)
%
% Computes parameters for Gauss-Chebyshev numerical integration.
% Reference: Viesca and Garagash (2018), Table 1.
% Note: here we flip the order of the Chebyshev points such that they run from -1 to 1
% whereas in Viesca and Garagash (2018) they run from 1 to -1.
%
bar_y = (y_plus-y_min)/2; % half length of integration interval
y_bar = (y_min+y_plus)/2; % mid point of integration interval
switch end_type       
    case 00 % both end points unbounded; 1st-kind Chebyshev points
        z_j = flip( cos( pi*((1:N)-0.5)/N ) )'; % 1st-kind Chebyshev points
        z_i = flip( cos( pi*(1:N-1)/N ) )'; % 1st-kind auxiliary points 
        w_j = ones(length(z_j),1)*pi/N; 
        w_i = ones(length(z_i),1)*pi/N; 
    case 01 % left end point unbounded; right end point bounded % 4th-kind Chebyshev points
        z_j = flip( cos( pi*(1:N)/(N+0.5) ) )'; 
        z_i = flip( cos( pi*((1:N)-0.5)/(N+0.5) ) )'; 
        w_j = pi*(1-z_j)/(N+0.5); 
        w_i = pi*(1-z_i)/(N+0.5); 
    case 10 % left end point bounded; right end point unbounded % 3rd-kind Chebyshev points
        z_j = flip( cos( pi*((1:N)-0.5)/(N+0.5) ) )'; 
        z_i = flip( cos( pi*(1:N)/(N+0.5) ) )'; 
        w_j = pi*(1+z_j)/(N+0.5); 
        w_i = pi*(1+z_i)/(N+0.5); 
    case 11 % both end points bounded % 2nd-kind Chebyshev points
        z_j = flip( cos( pi*(1:N)/(N+1) ) )'; 
        z_i = flip( cos( pi*((1:N+1)-0.5)/(N+1) ) )'; 
        w_j = pi*(1-z_j.^2)/(N+1); 
        w_i = pi*(1-z_i.^2)/(N+1); 
    case 22 % both end points bounded % extended 2nd-kind Chebyshev (Chebyshev-Lobatto)
    % points. To be checked!!!
        z_j = flip( cos( pi*(0:N-1)/N ) )'; 
        z_i = flip( cos( pi*((1:N)-0.5)/N ) )'; 
        w_j = pi*(1-z_j.^2)/N; 
        w_i = pi*(1-z_i.^2)/N; 
end
y_j = y_bar + z_j * bar_y;
y_i = y_bar + z_i * bar_y;
