function [Delta_y_UR_bot,Delta_y_UR_top] = ifs_UR(flag,model,numpar,delta,p_inc,y_delta,y_til)
%
% Computes the nucleation length for top and bottom patches with the Uenishi and Rice
% criterion.  
%

% Retrieve:
delta_c = model.delta_c;
G = model.G;
mu_dyn = model.mu_dyn;
mu_st = model.mu_st;
N_cheb = numpar.N_cheb; 
nu = model.nu;

switch flag.sim_type
    case 1 % uncoupled
        N = N_cheb/2;
        [~,~,~,y_j_bot] = ifs_GaussCheb(11,N,y_til(1),y_til(2));
        [~,~,~,y_j_top] = ifs_GaussCheb(11,N,y_til(3),y_til(4));
        if delta == 0
            delta_bot = 0;
            delta_top = 0;
            y_delta_bot = 0;
            y_delta_top = 0;
        else
            if flag.int ~= 3
                delta_bot = delta(2:N);
                delta_top = delta(N+1:end-1);
                y_delta_bot = y_delta(2:N);
                y_delta_top = y_delta(N+1:end-1);
            else
                delta_bot = delta(2:N+1);
                delta_top = delta(N+2:end-1);
                y_delta_bot = y_delta(2:N+1);
                y_delta_top = y_delta(N+2:end-1);
            end
        end
        sigma_bot = ifs_sigma(flag,model,numpar,delta_bot,0,p_inc,y_delta_bot,...
            y_j_bot,y_j_bot);
        sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,...
            y_j_top,y_j_top);
        sigma_j = sigma_bot.norm_eff_comb;
        if flag.int ~= 3 % inverse method
            delta_j = interp1(y_delta_bot,delta_bot,y_j_bot,'linear',0);
        else % forward method: discrete Chebyshev polynomials
            delta_j = delta_bot;
        end
        w_bar = ( trapz(y_j_bot,-sigma_j.* (abs(delta_j) <= delta_c) ) * ...
            (mu_st-mu_dyn) / delta_c ) / (y_til(2)-y_til(1));
        Delta_y_UR_bot = 1.158*G/(w_bar*(1-nu));
        sigma_j = sigma_top.norm_eff_comb;
        if flag.int ~= 3 % inverse method
            delta_j = interp1(y_delta_top,delta_top,y_j_top,'linear',0);
        else % forward method: discrete Chebyshev polynomials
            delta_j = delta_top;
        end
        w_bar = ( trapz(y_j_top,-sigma_j.* (abs(delta_j) <= delta_c) ) * ...
            (mu_st-mu_dyn) / delta_c ) / (y_til(4)-y_til(3));
        Delta_y_UR_top = 1.158*G/(w_bar*(1-nu));
    case 2 % coupled
        N = N_cheb/2;
        [~,~,~,y_j_bot] = ifs_GaussCheb(11,N,y_til(1),y_til(2));
        [~,~,~,y_j_top] = ifs_GaussCheb(11,N,y_til(3),y_til(4));
        if delta == 0
            delta_bot = 0;
            delta_top = 0;
            y_delta_bot = 0;
            y_delta_top = 0;
        else
            if flag.int ~= 3 % inverse method
                delta_bot = delta(2:N);
                delta_top = delta(N+1:end-1);
                y_delta_bot = y_delta(2:N);
                y_delta_top = y_delta(N+1:end-1);
            else % forward method: discrete Chebyshev polynomials
                delta_bot = delta(2:N+1);
                delta_top = delta(N+2:end-1);
                y_delta_bot = y_delta(2:N+1);
                y_delta_top = y_delta(N+2:end-1);
            end
        end
        sigma_bot = ifs_sigma(flag,model,numpar,delta_bot,0,p_inc,y_delta_bot,...
            y_j_bot,y_j_bot);
        sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,...
            y_j_top,y_j_top);
%         N = N_cheb/2;
%         [U,z_n] = ifs_cheb_matrix_U(N,N,2);
%         [T,zeta_m] = ifs_cheb_matrix_T(N+1,N+1,1);
%         z_p = flip(cos( pi*(1:N)/(N+1) ))';
%         NN = diag(1./(1:N));
%         Z = diag(sqrt(1-z_n.^2));

%         r_bar = 2*(y_til(1)+y_til(2))/(y_til(2)-y_til(1));
%         Z_hat = (1/(N+1))*(2*zeta_m'+r_bar)./...
%             ((zeta_m'-z_p).*(zeta_m'+z_p+r_bar));
%         B_hat = (Z_hat*T(:,2:N+1))\(Z*U*NN);
%         [~,lambda_UR_bot] = eigs(B_hat,1);
        sigma_j = sigma_bot.norm_eff_comb;
        if flag.int ~= 3 % inverse method
            delta_j = interp1(y_delta_bot,delta_bot,y_j_bot,'linear',0);
        else % forward method: discrete Chebyshev polynomials
            delta_j = delta_bot;
        end
        w_bar = ( trapz(y_j_bot,-sigma_j.* (abs(delta_j) <= delta_c) ) * ...
            (mu_st-mu_dyn) / delta_c ) / (y_til(2)-y_til(1));
%         Delta_y_UR_bot = G/(lambda_UR_bot*w_bar*(1-nu));
        r_hat = (y_til(3)-y_til(2))/(y_til(2)-y_til(1));
        A_hat = 17.872;
        B_hat = 0.895;
        f_r_hat = (1.158/2) * (1 - (1/pi) * asec(A_hat * r_hat^B_hat + 1) )^(-1);
        Delta_y_UR_bot = f_r_hat * G/(w_bar*(1-nu));

% %         r_bar = 2*(y_til(3)+y_til(4))/(y_til(4)-y_til(3));
%         r_bar = (-y_til(1)-y_til(2)+y_til(3)+y_til(4))/(y_til(4)-y_til(3));
%         Z_hat = (1/(N+1))*(2*zeta_m'+r_bar)./...
%             ((zeta_m'-z_p).*(zeta_m'+z_p+r_bar));
%         B_hat = (Z_hat*T(:,2:N+1))\(Z*U*NN);
%         [~,lambda_UR_top] = eigs(B_hat,1);
        sigma_j = sigma_top.norm_eff_comb;
        if flag.int ~= 3 % inverse method
            delta_j = interp1(y_delta_top,delta_top,y_j_top,'linear',0);
        else % forward method: discrete Chebyshev polynomials
            delta_j = delta_top;
        end
        w_bar = ( trapz(y_j_top,-sigma_j.* (abs(delta_j) <= delta_c) ) * ...
            (mu_st-mu_dyn) / delta_c ) / (y_til(4)-y_til(3));
%        Delta_y_UR_top = G/(lambda_UR_top*w_bar*(1-nu));
        r_hat = (y_til(3)-y_til(2))/(y_til(4)-y_til(3));
        f_r_hat = (1.158/2) * (1 - (1/pi) * asec(A_hat * r_hat^B_hat + 1) )^(-1);
        Delta_y_UR_top = f_r_hat * G/(w_bar*(1-nu));
    case 3 % merged
        error('U&R criterion not available for merged case.')
end
