function sigma_brv = ifs_breve(flag,model,grad,N,y_brv,y_delta,y_loc)
%
% Computes the slip-induced shear stress sigma_brv at points y_brv.    
%

% Retrieve:
G = model.G; % shear modulus, Pa
nu = model.nu; % Poisson's ratio, -

% Compute auxiliary variables:
A = G / (2*pi*(1-nu));

% Compute induced shear stress:
switch flag.int
    case 1 % inverse method: Gauss-Chebyshev quadrature:
        w_j = pi/N; % Gauss-Chebyshev weight function
        sigma_brv = A * (sum(grad .* sqrt( abs( (y_delta-y_loc(1)) .* ...
            (y_delta-y_loc(2)) ) ) .*  w_j ./ (y_delta-y_brv')))';
    case 2 % inverse method: Matlab's variable-support trapezium rule:
        sigma_brv = A * (trapz(y_delta,grad ./ (y_delta-y_brv')))';
    case 3 % forward method: discrete Chebyshev polynomials:
        sigma_brv = A * (trapz(y_delta,grad ./ (y_delta-y_brv')))'; %%%
end
