function [flag,numpar,plotpar] = ifs_check(admin,flag,model,numpar,plotpar)
%
% Checks input.
%

% Retrieve:
c = model.c; % reservoir width to the left of the fault, m
d = model.d; % reservoir width to the right of the fault, m
p_max_bounds = numpar.p_max_bounds; % highest incremental pressure (negative for depletion), Pa
p_min_bounds = numpar.p_min_bounds; % lowest incremental pressure (negative for depletion), Pa
p_step_init = numpar.p_step_init; % initial pressure step size (negative for depletion), Pa
% n_snap = plotpar.n_snap; % number of snap_shots, - 
p_inc_ref = plotpar.p_inc_ref; % reference pressure used in image plots etc., Pa
p_inc_snap = plotpar.p_inc_snap; % incremental pressures at which to take snapshots, Pa

% Auxiliary variables:
if 0 < p_step_init
    dir = 1; % injection
else
    dir = -1; % depletion
end
numpar.dir = dir;
n_snap = length(plotpar.p_inc_snap); % number of snap_shots, -
plotpar.n_snap = n_snap;

% Perform checks:
if (c == inf && d ~= inf) || (c ~= inf && d == inf)
    error('Boundaries c and d should be either both finite or both infinite.');
end

if flag.fric == 0 
    if admin.input ~= 01
        error('Frictionless solution only available for ifs_input_01_example_1.');
    end
else % finite friction
    if flag.varstep == 0 && flag.plot_snap == 1
        error('Plotting snapshots requires variable step size. Set flag.varstep = 1 or flag.plot_snap = 0.');
    end

    if p_max_bounds < p_min_bounds
        error('p_max_bounds must be larger than p_min_bounds.');
    end

    if flag.plot_snap == 1
        if (p_min_bounds < p_inc_ref)*( p_inc_ref < p_max_bounds) == 0
            error('p_inc_ref value must be between p_min_bounds and p_max_bounds.');
        end

        if sum( (p_min_bounds < p_inc_snap).*( p_inc_snap < p_max_bounds) ) ~= n_snap
            error('p_inc_snap values must be between p_min_bounds and p_max_bounds.');
        end

        % If list of snap shot pressures does not include reference pressure, add to list:
        if sum(p_inc_snap == p_inc_ref) == 0
            n_snap = n_snap + 1;
            p_inc_snap = dir*sort([dir*p_inc_snap,dir*p_inc_ref]);
            fprintf('\nNote: p_inc_ref has been added to list of snap shot pressure p_inc_snap');
            fprintf('\n      Total number of snap shots is now %g\n', n_snap);
        end
        i_snap_ref = nonzeros( (dir*p_inc_snap == dir*p_inc_ref).*(1:n_snap) );
        plotpar.i_snap_ref = i_snap_ref; % snap shot serving as reference, -
        plotpar.n_snap = n_snap;
        plotpar.p_inc_snap = p_inc_snap;
    end

    if (flag.plot_adu == 1 && flag.coupled ~= 1) || (flag.plot_adu == 1 && flag.fric ~= 1)
        fprintf('\nNote: flag.plot_adu = 1 requires flag.coupled = 1 and flag.fric = 1');
        fprintf('\n      flag.plot_adu reset to 0\n');
        flag.plot_adu = 0;
    end

    if (flag.plot_amu == 1 && flag.coupled ~= 1) || (flag.plot_amu == 1 && flag.fric ~= 1)
        fprintf('\nNote: flag.plot_amu = 1 requires flag.coupled = 1 and flag.fric = 1');
        fprintf('\n      flag.plot_amu reset to 0\n');
        flag.plot_amu = 0;
    end

    if (flag.plot_amu == 1 && flag.int == 3)
        fprintf('\nNote: flag.plot_amu = 1 requires flag.int = 1 or flag.int = 2');
        fprintf('\n      flag.plot_amu reset to 0\n');
        flag.plot_amu = 0;
    end  
    
    if (flag.plot_asy == 1 && flag.coupled ~= 1) || (flag.plot_asy == 1 && flag.fric ~= 1)
        fprintf('\nNote: flag.plot_asy = 1 requires flag.coupled = 1 and flag.fric = 1');
        fprintf('\n      flag.plot_asy reset to 0\n');
        flag.plot_asy = 0;
    end

    if (flag.plot_asy == 1 && flag.int == 3)
        fprintf('\nNote: flag.plot_asy = 1 requires flag.int = 1 or flag.int = 2');
        fprintf('\n      flag.plot_asy reset to 0\n');
        flag.plot_asy = 0;
    end  

    if flag.int == 3 && flag.N_cheb == 1
        fprintf('\nNote: flag.N_cheb = 1 not available for flag.int = 3');
        fprintf('\n      flag.N_cheb reset to 0\n');
        flag.N_cheb = 0;
    end

    if flag.int == 3 && (-1)^numpar.N_cheb == -1
        fprintf('\nNote: numpar.N_cheb must be an even number');
        fprintf('\n      numpar.N_cheb reset to numpar.N_cheb + 1\n');
        flag.N_cheb = 0;
    end

    if flag.int == 3 && flag.depdep == 0
        fprintf('\nNote: Symmetric formulation not available for flag_int = 3;');
        fprintf('\n      asymmetric formulation will be used');
    end

    if flag.fric == 2 && flag.nuc == 1 && flag.int == 3 
        error('flag.nuc = 1 only available for flag.int ~= 3');
    end

    if flag.fric == 2 && flag.nuc == 2 && flag.int ~= 3 
        error('flag.nuc = 2 only available for flag.int = 3');
    end

    if flag.fric == 2 && flag.nuc == 4 && flag.int ~= 3 
        error('flag.nuc = 4 only available for flag.int = 3');
    end

end