function [C0,C0_short,D0,D2] = ifs_compute_CD_sym(flag,model,numpar,p_inc,y_loc)
%
% Computes values of coefficients C0, D0 and D2 for coupled simulation. Makes use of symmetry
% around y = 0. Because of symmetry, y_loc has only two elements.    
%

N_top = numpar.N_top; % number of integration steps, -

bar_y_top = (y_loc(2)-y_loc(1))/2; % m
y_bar_top = (y_loc(1)+y_loc(2))/2; % m
z_j_top = flip(cos( pi*((1:N_top)-0.5)/N_top ))'; % -
z_i_top = flip(cos( pi*((1:N_top-1))/N_top ))'; % -
y_j_top = y_bar_top + z_j_top * bar_y_top; % m
y_i_top = y_bar_top + z_i_top * bar_y_top; % m
w_j_top = pi/N_top;

sigma_top = ifs_sigma(flag,model,numpar,0,0,p_inc,0,y_j_top,y_j_top); % Pa
Psi_1_sym = sqrt( abs( (y_i_top.^2-y_loc(1).^2) .* (y_loc(2).^2-y_i_top.^2) ) ); % m^2
Psi_2_sym = sqrt( abs( (y_j_top.^2-y_loc(1).^2) .* (y_loc(2).^2-y_j_top.^2) ) ); % m^2
 
% Compute C0 and C1 (short cut method):
switch flag.int
    case 1 % Gauss-Chebyshev quadrature
        F_top = -sigma_top.C ./  sqrt( abs( (y_j_top+y_loc(1)) .* (y_j_top+y_loc(2)) ) );        
        I1_top = sum(y_j_top    .* F_top .* w_j_top); % Pa
        I3_top = sum(y_j_top.^3 .* F_top .* w_j_top); % Pa*m^2
    case 2 % Matlab's variable-support trapezium rule
        F_top = -sigma_top.C ./ Psi_2_sym; % Pa/m^2
        I1_top = trapz(y_j_top, y_j_top    .* F_top); % Pa
        I3_top = trapz(y_j_top, y_j_top.^3 .* F_top); % Pa*m^2
end
I1 = 2 * I1_top; % should be equal to zero
I3 = 2 * I3_top;
y3 = y_loc(1); % m
y4 = y_loc(2); % m
B1 = y3*y4; % m^2
B3 = 1; % -
D0 = B1*I1 + B3*I3; % Pa*m^2
D2 = B3*I1; % Pa
C0_short = -D0; % Pa*m^2

% Compute C0:
switch flag.int
    case 1 % Gauss-Chebyshev quadrature
        F_top = 1 ./  sqrt( abs( (y_j_top+y_loc(1)) .* (y_loc(2)+y_j_top) ) );        
        aa = sum(F_top .* w_j_top); % 1/m
        G_top = -2 * y_j_top .* sigma_top.C .* ...
            sqrt( abs( (y_j_top+y_loc(1)) .* (y_loc(2)+y_j_top) ) ) .* ...
                  abs( (y_j_top-y_loc(1)) .* (y_loc(2)-y_j_top) ); % Pa*m^2       
        help_top = ( sum(G_top .* w_j_top ./ -(y_j_top.^2-y_i_top.^2')) )'; % Pa*m^2
        bb = -sum(w_j_top .* help_top ./ ...
            sqrt( abs( (y_i_top+y_loc(1)) .* (y_loc(2)+y_i_top) ) )); % Pa*m
    case 2 % Matlab's variable-support trapezium rule
        aa = trapz(y_j_top, 1 ./ Psi_2_sym); % 1/m
        G_top = -2 * y_j_top .* sigma_top.C .* Psi_2_sym; % Pa*m^2       
        help_top = ( trapz(y_j_top, G_top ./ -(y_j_top.^2-y_i_top.^2')) )'; % Pa*m^2
        bb = -trapz(y_i_top,(1 ./ Psi_1_sym) .* help_top); % Pa*m
end
C0 = bb/aa; % Pa*m^2
