function [numpar,sigma,sigma_brv,y_sigma] = ifs_compute_snaps(flag,model,numpar,grad,...
    p_inc,plotpar,y_delta,y_til)
%
% Computes some data for snapshot plots (pre-slip stresses and induced stresses). 
%

% Retrieve:
y_plot = plotpar.y_plot;
y_min = numpar.y_sim_min; % minimum y value for simulation, m
y_max = numpar.y_sim_max; % maximum y value for simulation, m
n_pt_y = y_plot.n_pt;

% Compute auxiliary variables:
N_bot = numpar.N_bot;
N_top = numpar.N_top;

% Compute pre-slip stresses:
[sigma,~,~,~,y_sigma] = ifs_sigma(flag,model,numpar,0,n_pt_y,p_inc,0,y_max,y_min);

% Compute induced stresses:
switch flag.sim_type
    case 1 % uncoupled
        y_bot = y_til(1:2);
        y_top = y_til(3:4);
        y_brv_botbot = nonzeros( y_sigma .* (y_sigma < y_bot(1)) );
        y_brv_midbot = nonzeros( y_sigma .* (y_bot(2) < y_sigma) .* (y_sigma <= 0));
        y_brv_midtop = nonzeros( y_sigma .* (0 < y_sigma) .* (y_sigma < y_top(1)) );
        y_brv_toptop = nonzeros( y_sigma .* (y_top(2) < y_sigma) );
        grad_bot = grad(2:N_bot);
        grad_top = grad(N_bot+1:end-1);
        y_delta_bot = y_delta(2:N_bot);
        y_delta_top = y_delta(N_bot+1:end-1);
        sigma_brv_botbot = ifs_breve(flag,model,grad_bot,N_bot,y_brv_botbot,y_delta_bot,y_bot);
        sigma_brv_bot = nonzeros(-sigma.C .* (y_bot(1) < y_sigma) .* (y_sigma <= y_bot(2)));
        sigma_brv_midbot = ifs_breve(flag,model,grad_bot,N_bot,y_brv_midbot,y_delta_bot,y_bot);
        sigma_brv_midtop = ifs_breve(flag,model,grad_top,N_top,y_brv_midtop,y_delta_top,y_top);
        sigma_brv_top = nonzeros(-sigma.C .* (y_top(1) < y_sigma) .* (y_sigma <= y_top(2)));
        sigma_brv_toptop = ifs_breve(flag,model,grad_top,N_top,y_brv_toptop,y_delta_top,y_top);
        sigma_brv = [sigma_brv_botbot;sigma_brv_bot;sigma_brv_midbot;sigma_brv_midtop;...
            sigma_brv_top;sigma_brv_toptop];
        
    case 2 % coupled
        y_bot = y_til(1:2);
        y_top = y_til(3:4);
        y_brv_botbot = nonzeros( y_sigma .* (y_sigma < y_bot(1)) );
        y_brv_mid = nonzeros( y_sigma .* (y_bot(2) < y_sigma) .* (y_sigma < y_top(1)) );
        y_brv_toptop = nonzeros( y_sigma .* (y_top(2) < y_sigma) );
        grad_bot = grad(2:N_bot);
        grad_top = grad(N_bot+1:end-1);
        y_delta_bot = y_delta(2:N_bot);
        y_delta_top = y_delta(N_bot+1:end-1);
        sigma_brv_botbot = ...
            ifs_breve(flag,model,grad_bot,N_bot,y_brv_botbot,y_delta_bot,y_bot) + ...
            ifs_breve(flag,model,grad_top,N_top,y_brv_botbot,y_delta_top,y_top);
        sigma_brv_bot = nonzeros(-sigma.C .* (y_bot(1) < y_sigma) .* (y_sigma <= y_bot(2)));
        sigma_brv_mid = ...
            ifs_breve(flag,model,grad_bot,N_bot,y_brv_mid,y_delta_bot,y_bot) + ...
            ifs_breve(flag,model,grad_top,N_top,y_brv_mid,y_delta_top,y_top);
        sigma_brv_top = nonzeros(-sigma.C .* (y_top(1) < y_sigma) .* (y_sigma <= y_top(2)));
        sigma_brv_toptop = ...
            ifs_breve(flag,model,grad_bot,N_bot,y_brv_toptop,y_delta_bot,y_bot) + ...
            ifs_breve(flag,model,grad_top,N_top,y_brv_toptop,y_delta_top,y_top);
        sigma_brv = [sigma_brv_botbot;sigma_brv_bot;sigma_brv_mid;sigma_brv_top;...
            sigma_brv_toptop];

    case 3 % merged
        N_mer = numpar.N_mer;
        y_mer = [y_til(1) y_til(4)];
        y_brv_botbot = nonzeros( y_sigma .* (y_sigma < y_mer(1)) );
        y_brv_toptop = nonzeros( y_sigma .* (y_mer(2) < y_sigma) );
        grad_mer = grad(2:end-1);
        y_delta_mer = y_delta(2:end-1);
        sigma_brv_botbot = ifs_breve(flag,model,grad_mer,N_mer,y_brv_botbot,y_delta_mer,y_mer);
        sigma_brv_mer = nonzeros(-sigma.C .* (y_mer(1) < y_sigma) .* (y_sigma < y_mer(2)));
        sigma_brv_toptop = ifs_breve(flag,model,grad_mer,N_mer,y_brv_toptop,y_delta_mer,y_mer);
        sigma_brv = [sigma_brv_botbot;sigma_brv_mer;sigma_brv_toptop];
end

