function d_sigma_C_dy = ifs_d_sigma_C_dy(flag,model,numpar,p_inc,y)
%
% Computes the derivative d_sigma_C_dy for an inclined displaced fault with constant friction
% in an infinite-width reservoir. 
%

% Retrieve:
a = model.a;
b = model.b;
alpha = model.alpha;
g = model.g;
K_eff = model.K_eff;
mu_st = model.mu_st;
nu = model.nu;
phi = model.phi;
rho_f = model.rho_f;
rho_s = model.rho_s;
theta = model.theta;
e = numpar.eta_reg;

% Auxiliary variables:
C = ((1-2*nu)*alpha*p_inc) / (2*pi*(1-nu)); % scaling parameter, N/m^2
cc = (cos(theta))^2;
sc = sin(theta)*cos(theta);
ss = (sin(theta))^2;

% Compute derivative of pressure gradient:
 d_p_0_dy = rho_f * g;
    
% Compute derivatives of initial stresses:
if flag.sym == 0
    d_sigma_v_0_dy = ( (1-phi)*rho_s + phi*rho_f ) * g;
    d_sigma_v_eff_0_dy = d_sigma_v_0_dy + alpha * d_p_0_dy;
    d_sigma_h_eff_0_dy = K_eff .* d_sigma_v_eff_0_dy;
    d_sigma_h_0_dy = d_sigma_h_eff_0_dy - alpha * d_p_0_dy;
    d_sigma_norm_0_dy = d_sigma_h_0_dy * ss + d_sigma_v_0_dy * cc;
    d_sigma_shear_0_dy = - (d_sigma_v_0_dy - d_sigma_h_0_dy) * sc;
end

% Compute derivatives of incremental stresses:
d_sigma_xx_dy = C * ( ( (a+b)*e*(2*y+a-b) )./( ((a+b)*e)^2 + ((y-b).*(y+a)+e^2).^2 ) ...
                    + ( (a+b)*e*(2*y-a+b) )./( ((a+b)*e)^2 + ((y-a).*(y+b)+e^2).^2 ) );
P = e^2 + (y-a).^2;
Q = e^2 + (y+a).^2;
R = e^2 + (y-b).^2;
S = e^2 + (y+b).^2;
d_sigma_xy_dy = (C./(P.*Q)) .* ( P.*(y+a) + Q.*(y-a) - P.*Q.*(y+b)./S - P.*Q.*(y-b)./R );
d_sigma_norm_dy  = -d_sigma_xy_dy * sc + d_sigma_xx_dy * ss;
d_sigma_shear_dy =  d_sigma_xy_dy * ss + d_sigma_xx_dy * sc;

% Compute derivatives of effective stresses:
if flag.sym == 0
    d_sigma_norm_eff_0_dy = d_sigma_norm_0_dy + alpha*d_p_0_dy;
end
d_sigma_norm_eff_dy = d_sigma_norm_dy + (alpha*p_inc/pi) * ...
-(2*(b+a)*e*y)./(((y-b).*(y+b)+e.^2).^2.*(((b+a).^2*e.^2)./((y-b).*(y+b)+e.^2).^2+1));

% Compute derivatives of combined quantities:
if flag.sym == 0
    d_sigma_norm_eff_comb_dy = d_sigma_norm_eff_0_dy + d_sigma_norm_eff_dy;
    d_sigma_shear_comb_dy = d_sigma_shear_0_dy + d_sigma_shear_dy;
else
    d_sigma_norm_eff_comb_dy = d_sigma_norm_eff_dy;
    d_sigma_shear_comb_dy = d_sigma_shear_dy;
end
d_sigma_slip_dy = -mu_st*d_sigma_norm_eff_comb_dy;
d_sigma_C_dy = d_sigma_shear_comb_dy - d_sigma_slip_dy;
