function [e_bot,e_top,E_bot,E_top] = ifs_eigen(flag,model,numpar,delta,p_inc,y_delta,y_til)
%
% Computes the nucleation length for top and bottom patches with an eigenvalue approach. 
%

% Retrieve:
A = model.A;
delta_c = model.delta_c;
mu_dyn = model.mu_dyn;
mu_st = model.mu_st;
N_cheb = numpar.N_cheb; 

switch flag.sim_type
    case 1 % uncoupled
        if flag.sym == 0
            switch flag.int
                case {1,2}  % inverse method: Gauss-Chebyshev quadrature, or Matlab's ...
                % variable-support trapezium rule
                    error('Eigenvalues only available for Chebyshev polynomials.')                    
                case 3 % forward method: discrete Chebyshev polynomials
                    N = N_cheb/2;
                    [~,~,~,y_j_bot] = ifs_GaussCheb(11,N,y_til(1),y_til(2));
                    [~,~,~,y_j_top] = ifs_GaussCheb(11,N,y_til(3),y_til(4));
                    if delta == 0
                        delta_bot = 0;
                        delta_top = 0;
                        y_delta_bot = 0;
                        y_delta_top = 0;
                    else
                        delta_bot = delta(2:N+1);
                        delta_top = delta(N+2:end-1);
                        y_delta_bot = y_delta(2:N+1);
                        y_delta_top = y_delta(N+2:end-1);
                    end
                    sigma_bot = ifs_sigma(flag,model,numpar,delta_bot,0,p_inc,y_delta_bot,...
                        y_j_bot,y_j_bot);
                    sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,...
                        y_j_top,y_j_top);
                    U = numpar.U_2;
                    z_n = numpar.z_U_2;
                    NN = diag(1./(1:N));
                    Z = diag(sqrt(1-z_n.^2));
                    bar_y_bot = (y_til(2)-y_til(1))/2;
                    bar_y_top = (y_til(4)-y_til(3))/2;
                    W_bot = -sigma_bot.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                    W_top = -sigma_top.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                    w_tilde_bot = W_bot*bar_y_bot;
                    w_tilde_top = W_top*bar_y_top;
                    WW_tilde_bot = diag(w_tilde_bot);
                    WW_tilde_top = diag(w_tilde_top);
                    BB_bot = (2/(pi*A*(N+1)))*U'*Z^3*WW_tilde_bot*U*NN;
                    BB_top = (2/(pi*A*(N+1)))*U'*Z^3*WW_tilde_top*U*NN;
                    [E_bot,e_bot] = eigs(BB_bot,1); 
                    [E_top,e_top] = eigs(BB_top,1); 
            end
        end
    case 2 % coupled
        if flag.sym == 0
            switch flag.int
                case {1,2}  % inverse method: Gauss-Chebyshev quadrature, or Matlab's ...
                % variable-support trapezium rule
                    error('Eigenvalues only available for Chebyshev polynomials.')                    
                case 3 % forward method: discrete Chebyshev polynomials
                    N = N_cheb/2;
                    [~,~,~,y_j_bot] = ifs_GaussCheb(11,N,y_til(1),y_til(2));
                    [~,~,~,y_j_top] = ifs_GaussCheb(11,N,y_til(3),y_til(4));
                    if delta == 0
                        delta_bot = 0;
                        delta_top = 0;
                        y_delta_bot = 0;
                        y_delta_top = 0;
                    else
                        delta_bot = delta(2:N+1);
                        delta_top = delta(N+2:end-1);
                        y_delta_bot = y_delta(2:N+1);
                        y_delta_top = y_delta(N+2:end-1);
                    end
                    sigma_bot = ifs_sigma(flag,model,numpar,delta_bot,0,p_inc,y_delta_bot,...
                        y_j_bot,y_j_bot);
                    sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,...
                        y_j_top,y_j_top);
                    T = numpar.T_1;
                    U = numpar.U_2;
                    z_n = numpar.z_U_2;
                    z_m = numpar.z_T_1;
                    NN = diag(1./(1:N));
                    Z = diag(sqrt(1-z_n.^2));
                    bar_y_bot = (y_til(2)-y_til(1))/2;
                    bar_y_top = (y_til(4)-y_til(3))/2;
                    y_bar_bot = (y_til(1)+y_til(2))/2;
                    y_bar_top = (y_til(3)+y_til(4))/2;
                    W_bot = -sigma_bot.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                    W_top = -sigma_top.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                    w_tilde_bot = W_bot*bar_y_bot;
                    w_tilde_top = W_top*bar_y_top;
                    WW_tilde_bot = diag(w_tilde_bot);
                    WW_tilde_top = diag(w_tilde_top);
                    alpha_bot = bar_y_bot/bar_y_top;
                    alpha_top = bar_y_top/bar_y_bot;
                    beta_bot = (y_bar_top-y_bar_bot)/bar_y_top;
                    beta_top = (y_bar_bot-y_bar_top)/bar_y_bot;
                    Z_tilde_bot = (pi/N)./(z_m'-z_n*alpha_bot+beta_bot);
                    Z_tilde_top = (pi/N)./(z_m'-z_n*alpha_top+beta_top);
                    BC_bot = Z_tilde_bot * T(:,2:N+1); % cross term
                    BC_top = Z_tilde_top * T(:,2:N+1);
                    BB_11 = (2/(pi*A*(N+1)))*U'*Z^3*WW_tilde_bot*U*NN; 
                    BB_22 = (2/(pi*A*(N+1)))*U'*Z^3*WW_tilde_top*U*NN;
                    BB_12 = (2/(pi*(N+1)))*U'*Z^2*BC_bot;
                    BB_21 = (2/(pi*(N+1)))*U'*Z^2*BC_top;
                    BB = [BB_11 BB_12; BB_21 BB_22];
                    [E,e] = eigs(BB,1);
                    e_bot = e;
                    e_top = e;   
                    E_bot = E(1:N);
                    E_top = E(N+1:end);                     
            end
        end        
    case 3 % merged
        error('Eigenvalues not available for merged case.')
end
