function [Delta_y_UR_bot,Delta_y_UR_top,e_bot,e_top,E_bot,E_top] = ...
    ifs_eigen_cheb(flag,model,numpar,delta,p_inc,y_delta,y_til)
%
% Computes the nucleation length for top and bottom patches with an eigenvalue approach. 
%

% Retrieve:
delta_c = model.delta_c;
G = model.G;
mu_dyn = model.mu_dyn;
mu_st = model.mu_st;
nu = model.nu;
N_bot = numpar.N_bot;     
N_top = numpar.N_top;     
delta_bot = delta(2:N_bot);
delta_top = delta(N_bot+1:end-1);
y_delta_bot = y_delta(2:N_bot);
y_delta_top = y_delta(N_bot+1:end-1);

% Compute auxiliary variables:
A = G / (2*pi*(1-nu));
points_type = 1; % points z_j chosen as zeros of T_n(z) where -1 < z < 1

switch flag.sim_type
    case {1,4} % uncoupled %%%
        if flag.sym == 0
            % Compute critical slip length for bottom patch:
            N = N_bot;
            [T,z_j] = ifs_cheb_matrix_T(N,N,points_type); % T = N x N matrix with ...
                % first-kind Chebyshev polynomials as columns, discretized at points z_j
            [U,~] = ifs_cheb_matrix_U(N,N,points_type); % U = N x N matrix with ...
                % second-kind Chebyshev polynomials as columns, discretized at points z_j
            n_0 = [0,0,1./(2*(3:N))];
            N_0 = diag(n_0);
            n_2 = [0,0,1./(2*(1:N-2))]; % n_tilde
            N_2 = diag(n_2); % N_tilde
            U_2 = [zeros(N,2),U(:,1:N-2)]; % U_tilde
            T(:,1) = T(:,1)/2; % to account for halving of first coefficient
            bar_y_bot = (y_til(2)-y_til(1))/1;
            y_bar_bot = (y_til(1)+y_til(2))/2;
            y_j_bot = y_bar_bot + z_j * bar_y_bot; % rescaled Chebyshev points; ...
                % y_til(1) < y_j < y_til(2)
            sigma_bot = ifs_sigma(flag,model,numpar,delta_bot,0,p_inc,y_delta_bot,...
                y_j_bot,y_j_bot);
            sigma_norm_eff_comb_bot = sigma_bot.norm_eff_comb;
            sigma_j = sigma_norm_eff_comb_bot;
            delta_j = interp1(y_delta_bot,delta_bot,y_j_bot,'linear');

            % Approximate analytical solution (Uenishi and Rice):
            w_bar = ( trapz(y_j_bot,-sigma_j.* (abs(delta_j) <= delta_c) ) * ...
                (mu_st-mu_dyn) / delta_c ) / (y_til(2)-y_til(1));
            Delta_y_UR_bot = 1.158*G/(w_bar*(1-nu));

            % Semi-analytical solution in terms of Chebyshev polynomials:
            ww = -sigma_j .* (mu_st - mu_dyn) .* (abs(delta_j) <= delta_c) ./ (delta_c);
            % 1 x N vector
            W = diag(ww); % N x N diagonal matrix
            zz = sqrt(1-z_j.^2)/(pi*A); % 1 x N vector
            Z = diag(zz); % N x N diagonal matrix
            % a_tilde = -( (acos(z_j) - pi - z_j.*sqrt(1-z_j.^2))/(2*pi*A) )'; % N x 1 vector
            % AA_tilde = [zeros(N,1),a_tilde,zeros(N,N-2)];
            % AA = W*(AA_tilde + Z*(U*N_0-U_2*N_2) );
            AA = W*Z*(U*N_0-U_2*N_2);
            BB = 2*T;
            % % % [E_bot,e_bot] = eigs(AA,BB,1);
            % % % (AA*E_bot - e_bot*BB*E_bot)' * (AA*E_bot - e_bot*BB*E_bot) % check; should be zero
            AA_bar = AA(2:N-1,3:N);
            BB_bar = BB(2:N-1,3:N);
            [E_bar_bot,e_bar_bot] = eigs(AA_bar,BB_bar,1);
            e_bot = e_bar_bot;
            E_bot = [0;0;E_bar_bot];
        end

        % Compute critical slip length for top patch:
        N = N_top;
        [T,z_j] = ifs_cheb_matrix_T(N,N,points_type);
        [U,~] = ifs_cheb_matrix_U(N,N,points_type);
        n_0 = [0,0,1./(2*(3:N))];
        N_0 = diag(n_0);
        n_2 = [0,0,1./(2*(1:N-2))];
        N_2 = diag(n_2);
        U_2 = [zeros(N,2),U(:,1:N-2)];
        T(:,1) = T(:,1)/2;
        bar_y_top = (y_til(4)-y_til(3))/2;
        y_bar_top = (y_til(3)+y_til(4))/2;
        y_j_top = y_bar_top + z_j * bar_y_top;
        sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,y_j_top,y_j_top);
        sigma_norm_eff_comb_top = sigma_top.norm_eff_comb;
        sigma_j = sigma_norm_eff_comb_top;
        delta_j = interp1(y_delta_top,delta_top,y_j_top,'linear');

        % Approximate analytical solution (Uenishi and Rice):
        w_bar = ( trapz(y_j_top,-sigma_j.* (abs(delta_j) <= delta_c) ) * ...
            (mu_st-mu_dyn) / delta_c ) / (y_til(4)-y_til(3));
        Delta_y_UR_top = 1.158*G/(w_bar*(1-nu));

        % Semi-analytical solution in terms of Chebyshev polynomials:
% % %         ww = -sigma_j .* (mu_st - mu_dyn) ./ (2*pi*A*delta_c); % 1 x N variable coefficient ...
% % %              % vector; continuously descending weakening branch
        ww = -sigma_j .* (mu_st - mu_dyn) .* (abs(delta_j) <= delta_c) ./ delta_c; ...
            % 1 x N vector
        W = diag(ww); % N x N diagonal matrix
        zz = sqrt(1-z_j.^2)/(pi*A); % 1 x N vector
        Z = diag(zz); % N x N diagonal matrix
        % a_tilde = -( (acos(z_j) - z_j.*sqrt(1-z_j.^2))/(2*pi*A) )'; % N x 1 vector
        % AA_tilde = [zeros(N,1),a_tilde,zeros(N,N-2)];
        % AA = W*( AA_tilde + Z*(U*N_0-U_2*N_2) );
        AA = W*Z*(U*N_0-U_2*N_2);
        BB = 2*T;
        % [E_top,e_top] = eigs(AA,BB,1); % regular eigenproblem (without constr. on c_0 and c_1)
        % % % (AA*E_top - e_top*BB*E_top)' * (AA*E_top - e_top*BB*E_top) % check; should be zero
        AA_bar = AA(2:N-1,3:N);
        BB_bar = BB(2:N-1,3:N);
        [E_bar_top,e_bar_top] = eigs(AA_bar,BB_bar,1); % eigenpr. with constr. on c_0 and c_1
        e_top = e_bar_top;
        E_top = [0;0;E_bar_top];
        % % % (AA_bar*E_bar_top - e_bar_top*BB_bar*E_bar_top)' * ...
        % % %     (AA_bar*E_bar_top - e_bar_top*BB_bar*E_bar_top) % check; should be zero
        if flag.sym == 1
            Delta_y_UR_bot = Delta_y_UR_top;
            e_bot = e_top;
            E_bot = E_top;
        end
    case 2 % coupled; note: currently only available for symmetric case %%% 
        % Compute critical slip length for top patch:
        N = N_top;
        [T,z_j] = ifs_cheb_matrix_T(N,N,points_type);
        [U,~] = ifs_cheb_matrix_U(N,N,points_type);
        n_0 = [0,0,1./(2*(3:N))];
        N_0 = diag(n_0);
        n_2 = [0,0,1./(2*(1:N-2))];
        N_2 = diag(n_2);
        U_2 = [zeros(N,2),U(:,1:N-2)];
        T(:,1) = T(:,1)/2;
        bar_y_top = (y_til(4)-y_til(3))/2;
        y_bar_top = (y_til(3)+y_til(4))/2;
        y_j_top = y_bar_top + z_j * bar_y_top;
        sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,y_j_top,y_j_top);
        sigma_norm_eff_comb_top = sigma_top.norm_eff_comb;
        sigma_j = sigma_norm_eff_comb_top;
        delta_j = interp1(y_delta_top,delta_top,y_j_top,'linear');

        % Approximate analytical solution (Uenishi and Rice):
        w_bar = ( trapz(y_j_top,-sigma_j.* (abs(delta_j) <= delta_c) ) * ...
            (mu_st-mu_dyn) / delta_c ) / (y_til(4)-y_til(3));
        Delta_y_UR_top = 1.158*G/(w_bar*(1-nu));

        % Semi-analytical solution in terms of Chebyshev polynomials:
        ww = -sigma_j .* (mu_st - mu_dyn) .* (abs(delta_j) <= delta_c) ./ delta_c; ...
            % 1 x N vector
        W = diag(ww); % N x N diagonal matrix
        zz = sqrt(1-z_j.^2)/(pi*A); % 1 x N vector
        Z = diag(zz); % N x N diagonal matrix
        AA = W*Z*(U*N_0-U_2*N_2);
        BB = 2*T;
        AA_bar = AA(2:N-1,3:N);
        BB_bar = BB(2:N-1,3:N);
        [E_bar_top,e_bar_top] = eigs(AA_bar,BB_bar,1); % eigenpr. with constr. on c_0 and c_1
        e_top = e_bar_top;
        E_top = [0;0;E_bar_top];
        if flag.sym == 1
            Delta_y_UR_bot = Delta_y_UR_top;
            e_bot = e_top;
            E_bot = E_top;
        end
end
