function [epsilon,rms_dR_dp,rms_dW_dp_delta,rms_W_ddelta_dp] = ...
    ifs_loading_stress_components_dp(flag,model,numpar,delta,delta_store,p_inc,p_inc_store,...
    y_delta,y_delta_store)
%
% Computes root-mean-squared values of the loading stress components dR_dp, dW_dp_delta and
% W_ddelta_dp over the interval y_min < y < y_max, where y_min = y_delta(1) and ...
% y_max = y_delta(end). dR_dp and dW_dp are computed anaytically; ddelta_dp is computed
% numerically.
%

% Retrieve:
delta_c = model.delta_c;
g = model.g;
mu_dyn = model.mu_dyn;
mu_st = model.mu_st;

% Auxiliary variables:
y = y_delta;
y_store = y_delta_store;
% y = y_delta(2:end);
% y_store = y_delta_store(2:end);
% delta = delta(2:end);
% delta_store = delta_store(2:end);
y_min = y_delta(1);
y_max = y_delta(end);

% dR/dp:
sigma = ifs_sigma(flag,model,numpar,0,0,p_inc,0,y,y);
R_inc = sigma.shear + sigma.norm_eff * mu_st; % only the incremental-pressure dependent part
dR_dp = R_inc/p_inc; % analytical
% W:
W = -sigma.norm_eff_comb * (mu_st-mu_dyn)/delta_c; % analytical
% dW/dp:
dW_dp = W/p_inc; % analytical
% ddelta/dp:
ddelta_dp = (delta-delta_store)/(p_inc-p_inc_store); % numerical
% delta_store_corr = interp1(y_store,delta_store,y,'linear',0); % corrected for vertical ...
% % shift between pressure steps
% ddelta_dp = (delta-delta_store_corr)/(p_inc-p_inc_store); % numerical
% delta_corr = interp1(y,delta,y_store,'linear',0); % corrected for vertical shift
% ddelta_dp_corr = (delta_corr-delta_store)/(p_inc-p_inc_store); % numerical
% ddelta_dp = interp1(y_store,ddelta_dp_corr,y,'linear',0); % corrected for vertical shift (back)
% delta_corr = ifs_barylag([y,delta],y_store); % corrected for vertical shift between pr. steps   
% ddelta_dp_corr = (delta_corr-delta_store)/(p_inc-p_inc_store); % numerical
% ddelta_dp = ifs_barylag([y_store,ddelta_dp_corr],y); % corrected for vertical shift (back)

% Compute root-mean-squared values and epsilon:
rms_dR_dp = sqrt(trapz(y,dR_dp.^2)/(y_max-y_min)); 
rms_dW_dp_delta = sqrt(trapz(y,(dW_dp.*delta).^2)/(y_max-y_min));
rms_W_ddelta_dp = sqrt(trapz(y,(W.*ddelta_dp).^2)/(y_max-y_min));
% epsilon = trapz(y,sqrt( (dR_dp + dW_dp.*delta).^2./(W.*ddelta_dp).^2 ))/(y_max-y_min);
epsilon = trapz(y,abs(dR_dp + dW_dp.*delta)) / trapz(y,abs(W.*ddelta_dp));