function [epsilon,rms_dW_dy_ddelta_dp,rms_W_d2delta_dpdy] = ...
    ifs_loading_stress_components_dpdy(flag,model,numpar,delta,delta_store,grad,grad_store,...
    p_inc,p_inc_store,y_delta,y_delta_store)
%
% Computes root-mean-squared values of the loading stress components dR_dy, dW_dy_delta and
% W_ddelta_dy over the interval y_min < y < y_max, where y_min = y_delta(1) and ...
% y_max = y_delta(end). 
%

% Retrieve:
a = model.a;
b = model.b;
alpha = model.alpha;
delta_c = model.delta_c;
g = model.g;
K_eff = model.K_eff;
mu_dyn = model.mu_dyn;
mu_st = model.mu_st;
nu = model.nu;
phi = model.phi;
rho_f = model.rho_f;
rho_s = model.rho_s;
theta = model.theta;
e = numpar.eta_reg;

% Auxiliary variables:
C = ((1-2*nu)*alpha*p_inc) / (2*pi*(1-nu)); % scaling parameter, N/m^2
cc = (cos(theta))^2;
sc = sin(theta)*cos(theta);
ss = (sin(theta))^2;
y = y_delta;
y_store = y_delta_store;
y_min = y_delta(1);
y_max = y_delta(end);

% Compute derivative of pressure gradient:
 d_p_0_dy = rho_f * g;
    
% Compute derivatives of initial stresses:
if flag.sym == 0
    d_sigma_v_0_dy = ( (1-phi)*rho_s + phi*rho_f ) * g;
    d_sigma_v_eff_0_dy = d_sigma_v_0_dy + alpha * d_p_0_dy;
    d_sigma_h_eff_0_dy = K_eff .* d_sigma_v_eff_0_dy;
    d_sigma_h_0_dy = d_sigma_h_eff_0_dy - alpha * d_p_0_dy;
    d_sigma_norm_0_dy = d_sigma_h_0_dy * ss + d_sigma_v_0_dy * cc;
end

% Compute derivatives of incremental stresses:
d_sigma_xx_dy = C * ( ( (a+b)*e*(2*y+a-b) )./( ((a+b)*e)^2 + ((y-b).*(y+a)+e^2).^2 ) ...
                    + ( (a+b)*e*(2*y-a+b) )./( ((a+b)*e)^2 + ((y-a).*(y+b)+e^2).^2 ) );
P = e^2 + (y-a).^2;
Q = e^2 + (y+a).^2;
R = e^2 + (y-b).^2;
S = e^2 + (y+b).^2;
d_sigma_xy_dy = (C./(P.*Q)) .* ( P.*(y+a) + Q.*(y-a) - P.*Q.*(y+b)./S - P.*Q.*(y-b)./R );
d_sigma_norm_dy  = -d_sigma_xy_dy * sc + d_sigma_xx_dy * ss;

% Compute derivatives of effective stresses:
if flag.sym == 0
    d_sigma_norm_eff_0_dy = d_sigma_norm_0_dy + alpha*d_p_0_dy;
end
d_sigma_norm_eff_dy = d_sigma_norm_dy + (alpha*p_inc/pi) * ...
-(2*(b+a)*e*y)./(((y-b).*(y+b)+e.^2).^2.*(((b+a).^2*e.^2)./((y-b).*(y+b)+e.^2).^2+1));

% Compute derivatives of combined quantities:
if flag.sym == 0
    d_sigma_norm_eff_comb_dy = d_sigma_norm_eff_0_dy + d_sigma_norm_eff_dy;
else
    d_sigma_norm_eff_comb_dy = d_sigma_norm_eff_dy;
end
sigma = ifs_sigma(flag,model,numpar,0,0,p_inc,0,y,y);
W = -sigma.norm_eff_comb * (mu_st-mu_dyn)/delta_c;
dW_dy = -d_sigma_norm_eff_comb_dy * (mu_st-mu_dyn)/delta_c;
ddelta_dp = (delta-delta_store)/(p_inc-p_inc_store); % numerical
d2delta_dpdy = (grad-grad_store)/(p_inc-p_inc_store); 
% delta_store_corr = interp1(y_store,delta_store,y,'linear',0); % corrected for vertical shift
% grad_store_corr = interp1(y_store,grad_store,y,'linear',0); 
% ddelta_dp = (delta-delta_store_corr)/(p_inc-p_inc_store); % numerical
% d2delta_dpdy = (grad-grad_store_corr)/(p_inc-p_inc_store); 

% Compute root-mean-squared values and epsilon:
rms_dW_dy_ddelta_dp = sqrt(trapz(y,(dW_dy.*ddelta_dp).^2)/(y_max-y_min));
rms_W_d2delta_dpdy = sqrt(trapz(y,(W .* d2delta_dpdy).^2)/(y_max-y_min));
epsilon = trapz(y,abs(dW_dy.*ddelta_dp)) / trapz(y,abs(W.*d2delta_dpdy));
