% Script file ifs_main
%
% Induced Fault Slip (IFS), release 2, February 2025
%
% Jan-Dirk Jansen
% Department of Geoscience and Engineering
% Faculty of Civil Engineering and Geosciences
% Delft University of Technology
% The Netherlands
% email: j.d.jansen@tudelft.nl
%                                                                                                                          
%

clear variables
close all

% ---------------------------------------------------------------------------------------------
% Start of user input: 
% ---------------------------------------------------------------------------------------------

% Select input file:
admin.input = 04; % Flag to select input file; see ifs_input_xx.m for further details. 
    % 01 = Example from Meulenbroek and Jansen (2024)
    % 02 = Depletion in a reservoir with a displaced vertical fault 
    % 04 = Example with small and large relative fault throws (Jansen and Meulenbroek 2025)  
    % 06 = Nucleation as function of fault throw (only relevant for ifs_main_nucleation.m) 

% Assign run identifier:
admin.run_ID = 'Default';

% Set paths for data and output files:
admin.path_out  = ...
    'C:\Users\djansen\My Documents\Onderzoek\Induced seismicity\IFS\IFS output files\';

% ---------------------------------------------------------------------------------------------
% End of user input. All other input data may be changed in the input files "ifs_inp_...".
% ---------------------------------------------------------------------------------------------
% Write to screen:
fprintf('\r*** Induced Fault Slip (IFS) ***\r');

% Initialize:
[data,flag,numpar] = ifs_initialize;

% Read input:
[flag,model,numpar,plotpar] = ifs_read_input(admin,flag,numpar);

% Write to screen:
fprintf('\rIFS run ID: %s\r', admin.run_ID); 
fprintf('\rIFS input file nr.: %02d\r', admin.input);

% Check input:
[flag,numpar,plotpar] = ifs_check(admin,flag,model,numpar,plotpar);

% Compute auxiliary variables and flags:
[data,flag,model,numpar,plotpar] = ifs_auxiliary(admin,data,flag,model,numpar,plotpar);

% Trigger timer:
if flag.echo > 0; tic; end 

if flag.fric == 0
    % Compute and plot stresses and fault slip for a frictionless vertical fault:
    data = ifs_frictionless(data,flag,model,numpar,plotpar);
else
    % Run quasi-static simulation for uncoupled slip patches (if required for plotting):
    data = ifs_patch_bounds_adu(data,flag,model,numpar,plotpar);

    % Run simulation for (incorrect) Mushkelishvili and Weertman results (if required for
    % plotting):
    [data,flag] = ifs_patch_bounds_amu(data,flag,model,numpar,plotpar);

    % Run simulation for symmetric configuration (if required for plotting):
    data = ifs_patch_bounds_asy(data,flag,model,numpar,plotpar);

    % Run regular simulation:
    % Print info
    if flag.echo > 0
        fprintf('\rRegular simulation:');
    end
    % Simulate:
    [data,flag,model,numpar] = ifs_patch_bounds(data,flag,model,numpar,plotpar);
    % Print time:
    if flag.echo > 0
        t_sim = toc;
        fprintf('\rQuasi-static simulation time = %g s\r',t_sim);
    end
end

% Plot & print quasi-static simulation results:
ifs_plot(admin,data,flag,model,numpar,plotpar);

% Store input data and results as binary files:
if flag.store == 1
    ifs_store(admin,data,flag,model,numpar,plotpar);
end
