function ifs_plot_C(admin,data,flag,numpar,plotpar)
%
% Plots coefficients C0 and C1 for coupled simulation (for diagnostics).
%

% Retrieve data:
p_inc = data.p_inc; % incremental pressure; negative for depletion, Pa
C0 = data.coeff_C0; % m^2
C0_short = data.coeff_C0_short; % m^2
C1 = data.coeff_C1; % m 
C1_short = data.coeff_C1_short; % m 
if flag.plot_asy == 1
    C0_sym = data.coeff_C0_sym; % m^2
    C0_short_sym = data.coeff_C0_short_sym; % m 
end
p_max_bounds = numpar.p_max_bounds; % highest incremental pressure (negative for depletion), Pa
p_min_bounds = numpar.p_min_bounds; % lowest incremental pressure (negative for depletion), Pa
j_merge_y_til = data.j_merge_y_til; % pressure step at which slip patches have merged, -
j_merge_y_sym = data.j_merge_y_sym; % pressure step at which symmetric slip patches ...
% have merged, -
blue = plotpar.colors.blue;
coal = plotpar.colors.coal;
orange = plotpar.colors.orange;
red = plotpar.colors.red;

% Compute auxiliary variables:
n_plot_max = length(p_inc); % maximum number of pressure steps, -

% Truncate plot arrays to avoid plotting for pressures below p_merge or p_seismic:
p_inc_plot            =    p_inc(1:min(j_merge_y_til-1,n_plot_max));
C0_plot               =       C0(1:min(j_merge_y_til-1,n_plot_max));
C0_short_plot         = C0_short(1:min(j_merge_y_til-1,n_plot_max));
C1_plot               =       C1(1:min(j_merge_y_til-1,n_plot_max));
C1_short_plot         = C1_short(1:min(j_merge_y_til-1,n_plot_max));
if flag.plot_asy == 1
    p_inc_sym_plot    =        p_inc(1:min(j_merge_y_sym-1,n_plot_max));
    C0_sym_plot       =       C0_sym(1:min(j_merge_y_sym-1,n_plot_max));
    C0_short_sym_plot = C0_short_sym(1:min(j_merge_y_sym-1,n_plot_max));
end

% % Retrieve data from previous runs:
% path_in = admin.path_out;
% run_ID   = 'Example_1_short_cut_256_per_patch';
% file_name_in = ['ifs_output_',run_ID];
% data_256 = load([path_in,file_name_in],'data');
% p_inc_256 = data_256.data.p_inc; 
% C1_short_256 = data_256.data.coeff_C1_short; 
% j_merge_y_til_256 = data_256.data.j_merge_y_til; 
% p_inc_plot_256 = p_inc_256(1:min(j_merge_y_til_256-1,n_plot_max));
% C1_short_plot_256  = C1_short_256(1:min(j_merge_y_til_256-1,n_plot_max));
% 
% run_ID   = 'Example_1_short_cut_512_per_patch';
% file_name_in = ['ifs_output_',run_ID];
% data_512 = load([path_in,file_name_in],'data');
% p_inc_512 = data_512.data.p_inc; 
% C1_short_512 = data_512.data.coeff_C1_short; 
% j_merge_y_til_512 = data_512.data.j_merge_y_til; 
% p_inc_plot_512 = p_inc_512(1:min(j_merge_y_til_512-1,n_plot_max));
% C1_short_plot_512  = C1_short_512(1:min(j_merge_y_til_512-1,n_plot_max));
% 
% run_ID   = 'Example_1_short_cut_1024_per_patch';
% file_name_in = ['ifs_output_',run_ID];
% data_1024 = load([path_in,file_name_in],'data');
% p_inc_1024 = data_1024.data.p_inc; 
% C1_short_1024 = data_1024.data.coeff_C1_short; 
% j_merge_y_til_1024 = data_1024.data.j_merge_y_til; 
% p_inc_plot_1024 = p_inc_1024(1:min(j_merge_y_til_1024-1,n_plot_max));
% C1_short_plot_1024  = C1_short_1024(1:min(j_merge_y_til_1024-1,n_plot_max));

% Create plot:
figure
subplot(2,1,1)
x_plot_min = - p_max_bounds/1e6; 
x_plot_max = - p_min_bounds/1e6; 
y_plot_min = -inf;
y_plot_max =  inf;
hold on
plot(-p_inc_plot/1e6,C0_plot,'-','Color',red,'LineWidth',1.5);
plot(-p_inc_plot/1e6,C0_short_plot,'--','Color',blue,'LineWidth',1.5);
if flag.plot_asy == 1
    plot(-p_inc_sym_plot/1e6,C0_sym_plot,'-','Color',coal,'LineWidth',1.5);
    plot(-p_inc_sym_plot/1e6,C0_short_sym_plot,'--','Color',orange,'LineWidth',1.5);
end
hold off
box on
grid on
axis([x_plot_min x_plot_max y_plot_min y_plot_max])
if flag.plot_asy == 1
    legend('Full','Short cut','Full, symmetric','Short cut, symmetric','FontSize',10,...
        'location','SouthWest')
%     legend('Full','Short cut','Full, symmetric','Short cut, symmetric','Interpreter',...
%         'latex','FontSize',11,'location','SouthWest')
else
    legend('Full','Short cut','FontSize',10,'location','SouthWest')
%     legend('Full','Short cut','Interpreter','latex','FontSize',11,'location','SouthWest')
end
xlabel('$-\Delta p$ (MPa)','Interpreter','latex','FontSize',11)
ylabel('$C_0 \, {\rm (m^2)}$','Interpreter','latex','FontSize',11)
if flag.plot_cap == 1
    [t,s] = title('plot\_C',' '); % first line: plot file locator
    t.Color = red;
    t.FontSize = 10;
    s.FontSize = 10;
    t.FontWeight = 'normal';
    s.FontWeight = 'normal';
end

subplot(2,1,2)
x_plot_min = - p_max_bounds/1e6; 
x_plot_max = - p_min_bounds/1e6; 
% y_plot_min = -100;
% y_plot_max =  100;
y_plot_min = -inf;
y_plot_max =  inf;
hold on
plot(-p_inc_plot/1e6,C1_plot,'-','Color',red,'LineWidth',1.5);
plot(-p_inc_plot/1e6,C1_short_plot,'--','Color',blue,'LineWidth',1.5);
% plot(-p_inc_plot_256/1e6,C1_short_plot_256,'--','Color',blue,'LineWidth',1.5);
% plot(-p_inc_plot_512/1e6,C1_short_plot_512,'-.','Color',blue,'LineWidth',1.5);
% plot(-p_inc_plot_1024/1e6,C1_short_plot_1024,'-','Color',blue,'LineWidth',1.5);
hold off
box on
grid on
axis([x_plot_min x_plot_max y_plot_min y_plot_max])
switch flag.plot_nota
    case 0
        xlabel('$-p$ (MPa)','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$-\Delta p$ (MPa)','Interpreter','latex','FontSize',11)
end
% legend('Full','Short cut, $\hat N_k = 256$','$\hat N_k = 512$','$\hat N_k = 1024$',...
%     'Interpreter','latex','FontSize',11,'location','SouthWest')
ylabel('$C_1$ (m)','Interpreter','latex','FontSize',11)

