function ifs_plot_const_x(flag,model,plotpar)
%
% Creates plots of pre-slip stresses for constant values x = x_shift for a vertical fault, or
% for y/tan(theta) + x_shift for an inclined fault. The values of x_shift are specified by the
% parameters x_plot.const_x_i, i = 1,...,3. Note that for x_shift = small, the stresses are
% plotted just to the right of the fault.     
%

% Retrieve variables:
a = model.a;
b = model.b;
c = model.c;
d = model.d;
theta = model.theta;

C_ref = plotpar.C_ref;
x_plot = plotpar.x_plot;
y_plot = plotpar.y_plot;
colors = plotpar.colors;

black = colors.black;
blue = colors.blue;
green = colors.green;
red = colors.red;

% Compute auxiliary variables:
y_plot_min = y_plot.const_x_min;
y_plot_max = y_plot.const_x_max;
n_pt_y = y_plot.const_x_n_pt;
y = linspace(y_plot_min,y_plot_max,n_pt_y);
small = 1e-9;

% Plot G_xx or sigma_xx:
figure
if flag.vert == 1 % vertical fault
    x = small;  % x = 0+
    if flag.inf == 1
        G_xx_plot_0 = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xx_plot_0 = Green_vert_g_xx(a,b,c,d,x,y);
    end
    G_xx_plot_0 = G_xx_plot_0 - 2*pi .* (-a < y) .* (y < b);
    sigma_xx_plot_0 = C_ref * G_xx_plot_0;
    x = x_plot.const_x_1;
    if flag.inf == 1
        G_xx_plot_1 = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xx_plot_1 = Green_vert_g_xx(a,b,c,d,x,y);
    end
    G_xx_plot_1 = G_xx_plot_1 - 2*pi .* (-a < y) .* (y < b);
    sigma_xx_plot_1 = C_ref * G_xx_plot_1;
    x = x_plot.const_x_2;
    if flag.inf == 1
        G_xx_plot_2 = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xx_plot_2 = Green_vert_g_xx(a,b,c,d,x,y);
    end
    G_xx_plot_2 = G_xx_plot_2 - 2*pi .* (-a < y) .* (y < b);
    sigma_xx_plot_2 = C_ref * G_xx_plot_2;
    x = x_plot.const_x_3;
    if flag.inf == 1
        G_xx_plot_3 = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xx_plot_3 = Green_vert_g_xx(a,b,c,d,x,y);
    end
    G_xx_plot_3 = G_xx_plot_3 - 2*pi .* (-a < y) .* (y < b);
    sigma_xx_plot_3 = C_ref * G_xx_plot_3;
else % inclined fault
    x = y/tan(theta) + small;
    if flag.inf == 1
        G_xx_plot_0 = Green_incl_g_xx_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xx_plot_0 = Green_incl_g_xx(a,b,c,d,theta,x,y);
    end
    G_xx_plot_0 = G_xx_plot_0 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_xx_plot_0 = C_ref * G_xx_plot_0;
    x = y/tan(theta) + x_plot.const_x_1;
    if flag.inf == 1
        G_xx_plot_1 = Green_incl_g_xx_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xx_plot_1 = Green_incl_g_xx(a,b,c,d,theta,x,y);
    end
    G_xx_plot_1 = G_xx_plot_1 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_xx_plot_1 = C_ref * G_xx_plot_1;
    x = y/tan(theta) + x_plot.const_x_2;
    if flag.inf == 1
        G_xx_plot_2 = Green_incl_g_xx_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xx_plot_2 = Green_incl_g_xx(a,b,c,d,theta,x,y);
    end
    G_xx_plot_2 = G_xx_plot_2 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_xx_plot_2 = C_ref * G_xx_plot_2;
    x = y/tan(theta) + x_plot.const_x_3;
    if flag.inf == 1
        G_xx_plot_3 = Green_incl_g_xx_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xx_plot_3 = Green_incl_g_xx(a,b,c,d,theta,x,y);
    end
    G_xx_plot_3 = G_xx_plot_3 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_xx_plot_3 = C_ref * G_xx_plot_3;
end
if flag.plot_G_or_sigma == 0
    x_plot_min = -8;
    x_plot_max = 2;
    hold on
    line([x_plot_min x_plot_max],[-b -b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[-a -a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[a a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[b b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
    line([0 0],[y_plot_min y_plot_max],'LineStyle','-','Color',black,'LineWidth',0.5)
    xx3 = plot(G_xx_plot_3,y,'Color',black,'LineWidth',1.0);
    xx2 = plot(G_xx_plot_2,y,'Color',green,'LineWidth',1.0);
    xx1 = plot(G_xx_plot_1,y,'Color',blue,'LineWidth',1.0);
    xx0 = plot(G_xx_plot_0,y,'Color',red,'LineWidth',1.0); % G_xx at x = 0
    hold off
    axis([x_plot_min x_plot_max y_plot_min y_plot_max])
    box on
    xlabel('$\it G_{xx} \; \rm (-)$','Interpreter','latex','FontSize',11)
    ylabel('$\it y \; \rm (m)$','Interpreter','latex','FontSize',11)
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.05 * (x_plot_max-x_plot_min);
        y_text = y_plot_max + 0.05 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_const\_x','FontSize',10,'Color',red)
    end
    leg_1 = (['$\it x \rm = 0 \, \it m $']);
    leg_2 = (['$\it x \rm = \,$',num2str(x_plot.const_x_1),'$ \, m$']);
    leg_3 = (['$\it x \rm = \,$',num2str(x_plot.const_x_2),'$ \, m$']);
    leg_4 = (['$\it x \rm = \,$',num2str(x_plot.const_x_3),'$ \, m$']);
    legend([xx0,xx1,xx2,xx3],{leg_1,leg_2,leg_3,leg_4},'Interpreter','latex','FontSize',10,...
        'Location','southwest')
else
    x_plot_max = max(-8*C_ref/1e6,2*C_ref/1e6);
    x_plot_min = min(-8*C_ref/1e6,2*C_ref/1e6);
    hold on
    line([x_plot_min x_plot_max],[-b -b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[-a -a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[a a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[b b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
    line([0 0],[y_plot_min y_plot_max],'LineStyle','-','Color',black,'LineWidth',0.5)
    xx3 = plot(sigma_xx_plot_3/1e6,y,'Color',black,'LineWidth',1.0);
    xx2 = plot(sigma_xx_plot_2/1e6,y,'Color',green,'LineWidth',1.0);
    xx1 = plot(sigma_xx_plot_1/1e6,y,'Color',blue,'LineWidth',1.0);
    xx0 = plot(sigma_xx_plot_0/1e6,y,'Color',red,'LineWidth',1.0);
    hold off
    axis([x_plot_min x_plot_max y_plot_min y_plot_max])
    box on
    switch flag.plot_nota
    case 0
        xlabel('$\it \sigma_{xx} \; \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$\rm\Delta\it\sigma_{xx} \; \rm (MPa)$','Interpreter','latex','FontSize',11)
    end
    ylabel('$\it y \; \rm (m)$','Interpreter','latex','FontSize',11)
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.05 * (x_plot_max-x_plot_min);
        y_text = y_plot_max + 0.05 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_const\_x','FontSize',10,'Color',red)
    end
    leg_1 = (['$\it x \rm = 0 \, \it m $']);
    leg_2 = (['$\it x \rm = \,$',num2str(x_plot.const_x_1),'$ \, m$']);
    leg_3 = (['$\it x \rm = \,$',num2str(x_plot.const_x_2),'$ \, m$']);
    leg_4 = (['$\it x \rm = \,$',num2str(x_plot.const_x_3),'$ \, m$']);
    legend([xx0,xx1,xx2,xx3],{leg_1,leg_2,leg_3,leg_4},'Interpreter','latex','FontSize',10,...
        'Location','southeast')
end

% Plot G_yy or sigma_yy:
figure
if flag.vert == 1 % vertical fault
    x = small;  % x = 0+
    if flag.inf == 1
        G_yy_plot_0 = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_yy_plot_0 = Green_vert_g_yy(a,b,c,d,x,y);
    end
    G_yy_plot_0 = G_yy_plot_0 - 2*pi .* (-a < y) .* (y < b);
    sigma_yy_plot_0 = C_ref * G_yy_plot_0;
    x = x_plot.const_x_1;
    if flag.inf == 1
        G_yy_plot_1 = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_yy_plot_1 = Green_vert_g_yy(a,b,c,d,x,y);
    end
    G_yy_plot_1 = G_yy_plot_1 - 2*pi .* (-a < y) .* (y < b);
    sigma_yy_plot_1 = C_ref * G_yy_plot_1;
    x = x_plot.const_x_2;
    if flag.inf == 1
        G_yy_plot_2 = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_yy_plot_2 = Green_vert_g_yy(a,b,c,d,x,y);
    end
    G_yy_plot_2 = G_yy_plot_2 - 2*pi .* (-a < y) .* (y < b);
    sigma_yy_plot_2 = C_ref * G_yy_plot_2;
    x = x_plot.const_x_3;
    if flag.inf == 1
        G_yy_plot_3 = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_yy_plot_3 = Green_vert_g_yy(a,b,c,d,x,y);
    end
    G_yy_plot_3 = G_yy_plot_3 - 2*pi .* (-a < y) .* (y < b);
    sigma_yy_plot_3 = C_ref * G_yy_plot_3;
else % inclined fault
    x = y/tan(theta) + small;
    if flag.inf == 1
        G_yy_plot_0 = Green_incl_g_yy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_yy_plot_0 = Green_incl_g_yy(a,b,c,d,theta,x,y);
    end
    G_yy_plot_0 = G_yy_plot_0 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
        (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_yy_plot_0 = C_ref * G_yy_plot_0;
    x = y/tan(theta) + x_plot.const_x_1;
    if flag.inf == 1
        G_yy_plot_1 = Green_incl_g_yy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_yy_plot_1 = Green_incl_g_yy(a,b,c,d,theta,x,y);
    end
    G_yy_plot_1 = G_yy_plot_1 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
        (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_yy_plot_1 = C_ref * G_yy_plot_1;
    x = y/tan(theta) + x_plot.const_x_2;
    if flag.inf == 1
        G_yy_plot_2 = Green_incl_g_yy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_yy_plot_2 = Green_incl_g_yy(a,b,c,d,theta,x,y);
    end
    G_yy_plot_2 = G_yy_plot_2 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
        (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_yy_plot_2 = C_ref * G_yy_plot_2;
    x = y/tan(theta) + x_plot.const_x_3;
    if flag.inf == 1
        G_yy_plot_3 = Green_incl_g_yy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_yy_plot_3 = Green_incl_g_yy(a,b,c,d,theta,x,y);
    end
    G_yy_plot_3 = G_yy_plot_3 - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
        (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
    sigma_yy_plot_3 = C_ref * G_yy_plot_3;
end
if flag.plot_G_or_sigma == 0
    x_plot_min = -5;
    x_plot_max = 5;
    hold on
    line([x_plot_min x_plot_max],[-b -b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[-a -a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[a a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[b b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
    line([0 0],[y_plot_min y_plot_max],'LineStyle','-','Color',black,'LineWidth',0.5)
    yy3 = plot(G_yy_plot_3,y,'Color',black,'LineWidth',1.0);
    yy2 = plot(G_yy_plot_2,y,'Color',green,'LineWidth',1.0);
    yy1 = plot(G_yy_plot_1,y,'Color',blue,'LineWidth',1.0);
    yy0 = plot(G_yy_plot_0,y,'Color',red,'LineWidth',1.0); % G_yy at x = 0
    hold off
    axis([x_plot_min x_plot_max y_plot_min y_plot_max])
    box on
    xlabel('$\it G_{yy} \; \rm (-)$','Interpreter','latex','FontSize',11)
    ylabel('$\it y \; \rm (m)$','Interpreter','latex','FontSize',11)
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.05 * (x_plot_max-x_plot_min);
        y_text = y_plot_max + 0.05 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_const\_x','FontSize',10,'Color',red)
    end
    leg_1 = (['$\it x \rm = 0 \, \it m $']);
    leg_2 = (['$\it x \rm = \,$',num2str(x_plot.const_x_1),'$ \, m$']);
    leg_3 = (['$\it x \rm = \,$',num2str(x_plot.const_x_2),'$ \, m$']);
    leg_4 = (['$\it x \rm = \,$',num2str(x_plot.const_x_3),'$ \, m$']);
    legend([yy0,yy1,yy2,yy3],{leg_1,leg_2,leg_3,leg_4},'Interpreter','latex','FontSize',10,...
        'Location','southwest')
else
    x_plot_max = max(-5*C_ref/1e6,5*C_ref/1e6);
    x_plot_min = min(-5*C_ref/1e6,5*C_ref/1e6);
    hold on
    line([x_plot_min x_plot_max],[-b -b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[-a -a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[a a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[b b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
    line([0 0],[y_plot_min y_plot_max],'LineStyle','-','Color',black,'LineWidth',0.5)
    yy3 = plot(sigma_yy_plot_3/1e6,y,'Color',black,'LineWidth',1.0);
    yy2 = plot(sigma_yy_plot_2/1e6,y,'Color',green,'LineWidth',1.0);
    yy1 = plot(sigma_yy_plot_1/1e6,y,'Color',blue,'LineWidth',1.0);
    yy0 = plot(sigma_yy_plot_0/1e6,y,'Color',red,'LineWidth',1.0);
    hold off
    axis([x_plot_min x_plot_max y_plot_min y_plot_max])
    box on
    switch flag.plot_nota
    case 0
        xlabel('$\it \sigma_{yy} \; \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$\rm\Delta\it\sigma_{yy} \; \rm (MPa)$','Interpreter','latex','FontSize',11)
    end
    ylabel('$\it y \; \rm (m)$','Interpreter','latex','FontSize',11)
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.05 * (x_plot_max-x_plot_min);
        y_text = y_plot_max + 0.05 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_const\_x','FontSize',10,'Color',red)
    end
    leg_1 = (['$\it x \rm = 0 \, \it m $']);
    leg_2 = (['$\it x \rm = \,$',num2str(x_plot.const_x_1),'$ \, m$']);
    leg_3 = (['$\it x \rm = \,$',num2str(x_plot.const_x_2),'$ \, m$']);
    leg_4 = (['$\it x \rm = \,$',num2str(x_plot.const_x_3),'$ \, m$']);
    legend([yy0,yy1,yy2,yy3],{leg_1,leg_2,leg_3,leg_4},'Interpreter','latex','FontSize',10,...
        'Location','southeast')
end

% Plot G_xy or sigma_xy:
figure
% G_xy_plot_0 = 0.5 * log( (y-a).^2.*(y+a).^2 ./ ((y-b).^2.*(y+b).^2) ); % x = 0
if flag.vert == 1 % vertical fault
    x = small;  % x = 0+
    if flag.inf == 1
        G_xy_plot_0 = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xy_plot_0 = Green_vert_g_xy(a,b,c,d,x,y);
    end
    sigma_xy_plot_0 = C_ref * G_xy_plot_0;
    x = x_plot.const_x_1;
    if flag.inf == 1
        G_xy_plot_1 = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xy_plot_1 = Green_vert_g_xy(a,b,c,d,x,y);
    end
    sigma_xy_plot_1 = C_ref * G_xy_plot_1;
    x = x_plot.const_x_2;
    if flag.inf == 1
        G_xy_plot_2 = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xy_plot_2 = Green_vert_g_xy(a,b,c,d,x,y);
    end
    sigma_xy_plot_2 = C_ref * G_xy_plot_2;
    x = x_plot.const_x_3;
    if flag.inf == 1
        G_xy_plot_3 = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xy_plot_3 = Green_vert_g_xy(a,b,c,d,x,y);
    end
    sigma_xy_plot_3 = C_ref * G_xy_plot_3;
else % inclined fault
    x = y/tan(theta) + small;
    if flag.inf == 1
        G_xy_plot_0 = Green_incl_g_xy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xy_plot_0 = Green_incl_g_xy(a,b,c,d,theta,x,y);
    end
    sigma_xy_plot_0 = C_ref * G_xy_plot_0;
    x = y/tan(theta) + x_plot.const_x_1;
    if flag.inf == 1
        G_xy_plot_1 = Green_incl_g_xy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xy_plot_1 = Green_incl_g_xy(a,b,c,d,theta,x,y);
    end
    sigma_xy_plot_1 = C_ref * G_xy_plot_1;
    x = y/tan(theta) + x_plot.const_x_2;
    if flag.inf == 1
        G_xy_plot_2 = Green_incl_g_xy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xy_plot_2 = Green_incl_g_xy(a,b,c,d,theta,x,y);
    end
    sigma_xy_plot_2 = C_ref * G_xy_plot_2;
    x = y/tan(theta) + x_plot.const_x_3;
    if flag.inf == 1
        G_xy_plot_3 = Green_incl_g_xy_inf(a,b,theta,x,y); % limit for infinite reservoir
    else
        G_xy_plot_3 = Green_incl_g_xy(a,b,c,d,theta,x,y);
    end
    sigma_xy_plot_3 = C_ref * G_xy_plot_3;
end
if flag.plot_G_or_sigma == 0
    x_plot_min = -6;
    x_plot_max = 4;
    hold on
    line([x_plot_min x_plot_max],[-b -b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[-a -a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[a a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[b b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
    line([0 0],[y_plot_min y_plot_max],'LineStyle','-','Color',black,'LineWidth',0.5)
    xy3 = plot(G_xy_plot_3,y,'Color',black,'LineWidth',1.0);
    xy2 = plot(G_xy_plot_2,y,'Color',green,'LineWidth',1.0);
    xy1 = plot(G_xy_plot_1,y,'Color',blue,'LineWidth',1.0);
    xy0 = plot(G_xy_plot_0,y,'Color',red,'LineWidth',1.0); % G_xy at x = 0
    hold off
    axis([x_plot_min x_plot_max y_plot_min y_plot_max])
    box on
    xlabel('$\it G_{xy} \; \rm (-)$','Interpreter','latex','FontSize',11)
    ylabel('$\it y \; \rm (m)$','Interpreter','latex','FontSize',11)
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.05 * (x_plot_max-x_plot_min);
        y_text = y_plot_max + 0.05 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_const\_x','FontSize',10,'Color',red)
    end
    leg_1 = (['$\it x \rm = 0 \, \it m $']);
    leg_2 = (['$\it x \rm = \,$',num2str(x_plot.const_x_1),'$ \, m$']);
    leg_3 = (['$\it x \rm = \,$',num2str(x_plot.const_x_2),'$ \, m$']);
    leg_4 = (['$\it x \rm = \,$',num2str(x_plot.const_x_3),'$ \, m$']);
    legend([xy0,xy1,xy2,xy3],{leg_1,leg_2,leg_3,leg_4},'Interpreter','latex','FontSize',10,...
        'Location','southwest')
else
    x_plot_max = max(-6*C_ref/1e6,4*C_ref/1e6);
    x_plot_min = min(-6*C_ref/1e6,4*C_ref/1e6);
    hold on
    line([x_plot_min x_plot_max],[-b -b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[-a -a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[a a],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[b b],'LineStyle',':','Color',black,'LineWidth',1)
    line([x_plot_min x_plot_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
    line([0 0],[y_plot_min y_plot_max],'LineStyle','-','Color',black,'LineWidth',0.5)
    xy3 = plot(sigma_xy_plot_3/1e6,y,'Color',black,'LineWidth',1.0);
    xy2 = plot(sigma_xy_plot_2/1e6,y,'Color',green,'LineWidth',1.0);
    xy1 = plot(sigma_xy_plot_1/1e6,y,'Color',blue,'LineWidth',1.0);
    xy0 = plot(sigma_xy_plot_0/1e6,y,'Color',red,'LineWidth',1.0); % G_xy at x = 0
    hold off
    axis([x_plot_min x_plot_max y_plot_min y_plot_max])
    box on
    switch flag.plot_nota
    case 0
        xlabel('$\it \sigma_{xy} \; \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$\rm\Delta\it\sigma_{xy} \; \rm (MPa)$','Interpreter','latex','FontSize',11)
    end
    ylabel('$\it y \; \rm (m)$','Interpreter','latex','FontSize',11)
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.05 * (x_plot_max-x_plot_min);
        y_text = y_plot_max + 0.05 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_const\_x','FontSize',10,'Color',red)
    end
    leg_1 = (['$\it x \rm = 0 \, \it m $']);
    leg_2 = (['$\it x \rm = \,$',num2str(x_plot.const_x_1),'$ \, m$']);
    leg_3 = (['$\it x \rm = \,$',num2str(x_plot.const_x_2),'$ \, m$']);
    leg_4 = (['$\it x \rm = \,$',num2str(x_plot.const_x_3),'$ \, m$']);
    legend([xy0,xy1,xy2,xy3],{leg_1,leg_2,leg_3,leg_4},'Interpreter','latex','FontSize',10,...
        'Location','southeast')
end