function ifs_plot_d_sigma_C_dy(data,flag,model,plotpar) 
%
% Plots derivative of pre-slip Coulombs stress close to singularity at y = a (for diagnostics).
%

% Retrieve:
a = model.a;
y = data.y_reg; % y values of segment for plotting, m
sigma_C = data.sigma_C_reg; % regularized Coulomb stress value, Pa
sigma_C_unreg = data.sigma_C_unreg; % unregularized Coulomb stress value, Pa
y_pre_unreg = data.y_pre_unreg; % unregularized Coulomb stress zero, m
d_sigma_C_dy = data.d_sigma_C_dy_reg; % regularized Coulomb stress derivative, Pa/m
d_sigma_C_dy_unreg = data.d_sigma_C_dy_unreg; % unregularized Coulomb stress derivative, Pa/m
y_0_deriv = data.y_0_deriv_reg; % regularized Coulomb stress derivative zero, m
snap = data.snap;
y_pre_snap = snap.y_pre; % pre-slip Coulomb stress zeros, m
i_snap_ref = plotpar.i_snap_ref; % snap shot serving as reference, -
y_delta_snap = snap.y_delta; % y values for slip and slip gradient, m
y_plot_min_d_sigma_C_dy = plotpar.y_plot_min_d_sigma_C_dy;
y_plot_max_d_sigma_C_dy = plotpar.y_plot_max_d_sigma_C_dy;
black = plotpar.colors.black;
blue = plotpar.colors.blue;
green = plotpar.colors.green;
orange = plotpar.colors.orange;
red = plotpar.colors.red;

% Create plots:
figure

% % check:
% sigma_C_check = sigma_C(1) + cumtrapz(y,d_sigma_C_dy); % integration to check differentiation

subplot(1,2,1)
marg = 0.1*(max(sigma_C)-min(sigma_C)); % margin
x_min = (min(sigma_C)-marg)/1e6;
x_max = (max(sigma_C)+marg)/1e6;
y_min = y_plot_min_d_sigma_C_dy;
y_max = y_plot_max_d_sigma_C_dy;

hold on
line([0 0],[y_min y_max],'LineStyle','-','Color',black,'LineWidth',0.5)
line([x_min x_max],[a a],'LineStyle',':','Color',black,'LineWidth',1.0)
line([x_min x_max],[y_pre_snap(4,i_snap_ref) y_pre_snap(4,i_snap_ref)],'LineStyle',...
    '-','Color',green,'LineWidth',1.0)
line([x_min x_max],[y_pre_unreg, y_pre_unreg],'LineStyle',':','Color',green,'LineWidth',1.0)
line([x_min x_max],[y_0_deriv y_0_deriv],'LineStyle','-','Color',orange,'LineWidth',1.0)
plot(sigma_C_unreg/1e6,y,'-','LineWidth',1.5,'Color',red)
plot(sigma_C/1e6,y,'-','LineWidth',1.5,'Color',blue)
% plot(sigma_C_check/1e6,y,'--','LineWidth',1.5,'Color',blue) % to check derivative
help01 = interp1(y,sigma_C,y_delta_snap(:,i_snap_ref));
plot(help01/1e6,y_delta_snap(:,i_snap_ref),'o','MarkerSize',5,'MarkerEdgeColor',blue,...
    'MarkerFaceColor',blue);
hold off
switch flag.plot_nota
    case 0
        xlabel('${\rm\Sigma}_{\it C}$ (MPa)','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$\tau_C$ (MPa)','Interpreter','latex','FontSize',11)
end
ylabel('$\it y \rm(m)$','Interpreter','latex','FontSize',11)
axis([x_min x_max y_min y_max])
box on
if flag.plot_cap == 1
    [t,s] = title('plot\_d\_sigma\_C\_dy'); % plot file locator
    t.Color = red;
    t.FontSize = 10;
    s.FontSize = 10;
    t.FontWeight = 'normal';
    s.FontWeight = 'normal';
end

subplot(1,2,2)
marg = 0.1*(max(d_sigma_C_dy)-min(d_sigma_C_dy)); % margin
x_min = (min(d_sigma_C_dy)-marg)/1e6;
x_max = (max(d_sigma_C_dy)+marg)/1e6;
y_min = y_plot_min_d_sigma_C_dy;
y_max = y_plot_max_d_sigma_C_dy;
hold on
line([0 0],[y_min y_max],'LineStyle','-','Color',black,'LineWidth',0.5)
line([x_min x_max],[a a],'LineStyle',':','Color',black,'LineWidth',1.0)
line([x_min x_max],[y_0_deriv y_0_deriv],'LineStyle','-','Color',orange,'LineWidth',1.0)
aa = plot(d_sigma_C_dy_unreg/1e6,y,'-','LineWidth',1.5,'Color',red);
bb = plot(d_sigma_C_dy/1e6,y,'-','LineWidth',1.5,'Color',blue);
% help02 = interp1(y,d_sigma_C_dy,y_delta_snap(:,i_snap_ref));
% plot(help02/1e6,y_delta_snap(:,i_snap_ref),'o','MarkerSize',5,'MarkerEdgeColor',blue,...
%     'MarkerFaceColor',blue);
hold off
switch flag.plot_nota
    case 0
        xlabel('${\rm d\Sigma}_{\it C}/{\rm d}{\it y}$ (MPa/m)','Interpreter','latex',...
            'FontSize',11)
    case 1
        xlabel('${\rm d}{\it\tau}_{\it C}/{\rm d}{\it y}$ (MPa/m)','Interpreter','latex',...
            'FontSize',11)
end
% ylabel('$\it y \rm(m)$','Interpreter','latex','FontSize',11)
axis([x_min x_max y_min y_max])
legend([aa,bb],{'Unregularized','Regularized'},'Location','SouthWest')
box on

% subplot(1,3,3)
% marg = 0.1*(max(p_shift_reg)-min(p_shift_reg)); % margin
% x_min = (min(p_shift_reg)-marg)/1e6;
% x_max = (max(p_shift_reg)+marg)/1e6;
% y_min = min(y);
% y_max = max(y);
% hold on
% line([0 0],[y_min y_max],'LineStyle','-','Color',black,'LineWidth',0.5)
% aa = plot(p_shift_unreg/1e6,y,'-','LineWidth',1.5,'Color',red);
% bb = plot(p_shift_reg/1e6,y,'--','LineWidth',1.5,'Color',blue);
% hold off
% xlabel('${\it p_{shift}$ (MPa)','Interpreter','latex','FontSize',11)
% % ylabel('$\it y \rm(m)$','Interpreter','latex','FontSize',11)
% axis([x_min x_max y_min y_max])
% legend([aa,bb],{'Unregularized','Regularized'},'Location','SouthWest')
% box on


