function ifs_plot_frictionless(data,flag,plotpar) 
%
% Plots depletion-induced stresses and fault slip along a frictionless vertical fault.  
%
% Only relevant for ifs_input_01_example_1. Figure used in Jansen and Meulenbroek (2022).
%

% Retrieve plot data: 
frls = data.frls;
delta = frls.delta; % fault slip, m
delta_BO = data.frls.delta_BO; % Bourne and Oates (2017) fault slip, m
sigma_C = frls.sigma_C; % pre-slip Coulomb stresses, Pa
y_pre = frls.y_pre; % pre-slip Coulomb stress zeros, m
y_delta = frls.y_delta; % y values for fault slip, m
y_sigma = frls.y_sigma; % y values for pre-slip Coulomb stresses, m
y_max = plotpar.y_plot.max_sigma;
y_min = plotpar.y_plot.min_sigma;

% Retrieve colors:
black = plotpar.colors.black;
blue = plotpar.colors.blue;
gray = plotpar.colors.gray;
green = plotpar.colors.green;
orange = plotpar.colors.orange;
red = plotpar.colors.red;

% % Read DARTS data:
% data_DARTS_vertical_frictionless_fault = ...
%     readmatrix('C:\Users\djansen\Documents\Onderzoek\Induced seismicity\IFS\IFS data GGGG\data_DARTS_vertical_frictionless_fault.txt');
% y_DARTS = data_DARTS_vertical_frictionless_fault(:,1);
% delta_DARTS = data_DARTS_vertical_frictionless_fault(:,4);

% Plot shear stresses and slip thresholds:
figure
subplot(1,2,1)
hold on
x_patch_left = [-29.8 -29.8 -15 -15];
y_patch_left = [-150 75 75 -150];
patch(x_patch_left,y_patch_left,gray,'LineStyle','none')
x_patch_right = [15 15 29.8 29.8];
y_patch_right = [-75 150 150 -75];
patch(x_patch_right,y_patch_right,gray,'LineStyle','none')
% Plot colored patches between x = 0 and sigma_C: 
n_seg = 100; % number of segments
y_seg = linspace(y_pre(1),y_pre(2),n_seg);
y_seg_bot = y_seg(1:end-1);
y_seg_top = y_seg(2:end);
y_patch = [y_seg_bot' y_seg_top' y_seg_top' y_seg_bot'];
x_seg_1 = zeros(n_seg-1,1);
x_seg_2 = zeros(n_seg-1,1);
x_seg_3 = interp1(y_sigma,sigma_C,y_seg_top');
x_seg_4 = interp1(y_sigma,sigma_C,y_seg_bot');
x_patch = [x_seg_1/1e6 x_seg_2/1e6 x_seg_3/1e6 x_seg_4/1e6];
patch(x_patch',y_patch',green,'LineStyle','none')
y_seg = linspace(y_pre(3),y_pre(4),n_seg);
y_seg_bot = y_seg(1:end-1);
y_seg_top = y_seg(2:end);
y_patch = [y_seg_bot' y_seg_top' y_seg_top' y_seg_bot'];
x_seg_1 = zeros(n_seg-1,1);
x_seg_2 = zeros(n_seg-1,1);
x_seg_3 = interp1(y_sigma,sigma_C,y_seg_top');
x_seg_4 = interp1(y_sigma,sigma_C,y_seg_bot');
x_patch = [x_seg_1/1e6 x_seg_2/1e6 x_seg_3/1e6 x_seg_4/1e6];
patch(x_patch',y_patch',green,'LineStyle','none')
x_min = -30;
x_max = 30;
line([x_min x_max],[y_pre(4) y_pre(4)],'LineStyle','-','Color',green,'LineWidth',0.5)
line([x_min x_max],[y_pre(1) y_pre(1)],'LineStyle','-','Color',green,'LineWidth',0.5)
line([0 0],[y_min y_max],'LineStyle','-','Color','k','LineWidth',0.5)
line([x_min x_max],[150 150],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[75 75],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[-75 -75],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[-150 -150],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
plot(sigma_C/1e6,y_sigma,'-r','LineWidth',1.5) % pre-slip Coulomb stresses
plot(-sigma_C/1e6,y_sigma,'-','Color',orange,'LineWidth',1.5) % slip-induced shear stresses
line([-30 -15],[150 150],'LineStyle','-','Color',red,'LineWidth',1.5) % cosmetic correction
line([-30 -15],[-150 -150],'LineStyle','-','Color',red,'LineWidth',1.5) % cosmetic correction
line([15 30],[150 150],'LineStyle','-','Color',orange,'LineWidth',1.5) % cosmetic correction
line([15 30],[-150 -150],'LineStyle','-','Color',orange,'LineWidth',1.5) % cosmetic correction
line([15 30],[75 75],'LineStyle','-','Color',red,'LineWidth',1.5) % cosmetic correction
line([15 30],[-75 -75],'LineStyle','-','Color',red,'LineWidth',1.5) % cosmetic correction
line([-30 -15],[75 75],'LineStyle','-','Color',orange,'LineWidth',1.5) % cosmetic correction
line([-30 -15],[-75 -75],'LineStyle','-','Color',orange,'LineWidth',1.5) % cosmetic correction
y_post_slip = linspace(-250,250,40);
plot(zeros(40,1),y_post_slip,'o','MarkerSize',3,'MarkerEdgeColor',blue,'MarkerFaceColor',blue)
% line([0 0],[-300 300],'LineStyle','-','Color',blue,'LineWidth',1.5) % post-slip Coulomb str.
hold off
switch flag.plot_nota
    case 0
        xlabel('$\Sigma_C$, $\breve{\sigma}_{\parallel}$, $\breve{\Sigma}_C$ (MPa) ',...
            'Interpreter','latex','FontSize',11)
    case 1
        xlabel('$\tau_C$, $\breve\tau$, ${\breve\tau}_C$ (MPa)','Interpreter','latex',...
            'FontSize',11)
end
ylabel('$\it y \rm(m)$','Interpreter','latex','FontSize',11)
axis([x_min x_max y_min y_max])
text(31.0,y_pre(1),'$\it y_1$','Interpreter','latex','FontSize',11)
text(31.0,y_pre(4),'$\it y_4$','Interpreter','latex','FontSize',11)
box on

subplot(1,2,2)
hold on
x_patch_left = [0.001 0.001 0.05 0.05];
y_patch_left = [-150 75 75 -150];
patch(x_patch_left,y_patch_left,gray,'LineStyle','none')
x_patch_right = [0.15 0.15 0.199 0.199];
y_patch_right = [-75 150 150 -75];
patch(x_patch_right,y_patch_right,gray,'LineStyle','none')
x_min = 0;
x_max = 0.20;
line([x_min x_max],[ 150  150],'LineStyle','-','Color',blue,'LineWidth',0.5)
line([x_min x_max],[-150 -150],'LineStyle','-','Color',blue,'LineWidth',0.5)
line([x_min x_max],[150 150],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[75 75],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[-75 -75],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[-150 -150],'LineStyle',':','Color',black,'LineWidth',1)
line([x_min x_max],[0 0],'LineStyle','-','Color',black,'LineWidth',0.5)
plot(delta,y_delta,'Color',red,'LineWidth',1.5)
plot(delta_BO,y_delta,'LineStyle','--','Color',red,'LineWidth',1.5)
% plot(delta_DARTS,y_DARTS,'^','MarkerIndices',1:25:length(y_DARTS),...
%     'MarkerSize',5.0,'MarkerEdgeColor',blue,'MarkerFaceColor',blue);
hold off
xlabel('$\delta$ (m) ','Interpreter','latex','FontSize',11)
axis([x_min x_max y_min y_max])
text(0.202,-150,'$\it \tilde{y}_1$','Interpreter','latex','FontSize',11)
text(0.202,150,'$\it \tilde{y}_4$','Interpreter','latex','FontSize',11)
box on
