function ifs_plot_images(flag,model,plotpar)
%
% Creates image plots of (scaled) pre-slip stresses and displacements as a function of x and y.
% (Displacements are only available for vertical faults.)
%

% Retrieve variables:
a = model.a;
b = model.b;
c = model.c;
d = model.d;
G = model.G;
theta = model.theta;
alpha = model.alpha; % Biot's coefficient, -
p_ref = plotpar.p_inc_ref; % reference value for incremental pressure, Pa

C_ref = plotpar.C_ref;
x_plot = plotpar.x_plot;
y_plot = plotpar.y_plot;
x_plot_min = x_plot.im_min;
x_plot_max = x_plot.im_max;
y_plot_min = y_plot.im_min;
y_plot_max = y_plot.im_max;
n_pt_x = x_plot.im_n_pt;
n_pt_y = y_plot.im_n_pt;
map = plotpar.map; % colormap for image plots

% Compute auxiliary variables:
x = linspace(x_plot_min,x_plot_max,n_pt_x);
y = linspace(y_plot_min,y_plot_max,n_pt_y)'; % note transpose
D_ref = C_ref/G;

clims = [-abs(p_ref)/1e6 abs(p_ref)/1e6];
% clims = [-inf inf];

% Create image plot of G_xx or sigma_xx:
if flag.vert == 1 % vertical fault
    if flag.inf == 1
        G_xx_image = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xx_image = Green_vert_g_xx(a,b,c,d,x,y);
    end
    G_xx_image = G_xx_image - 2*pi * ...
        ( (-c < x) .* (x < 0) .* (-b < y) .* (y < a) + ...
          (0 <= x) .* (x < d) .* (-a < y) .* (y < b) );
else % inclined fault
    if flag.inf == 1
        G_xx_image = Green_incl_g_xx_inf(a,b,theta,x,y); % limit for infinite res.
    else
        G_xx_image = Green_incl_g_xx(a,b,c,d,theta,x,y);
    end
    G_xx_image = G_xx_image - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
end
sigma_xx_image = C_ref * G_xx_image;
figure
xx = [x_plot_min x_plot_max];
yy = [y_plot_min y_plot_max];
if flag.plot_G_or_sigma == 0
    imagesc(xx,-yy,G_xx_image)
    title('$\rm\it G_{xx}-2\pi\delta_{\Omega} \rm \, (-)$','Interpreter','latex','FontSize',11)
else
    imagesc(xx,-yy,sigma_xx_image/1e6,clims)
    switch flag.plot_nota
    case 0
        title('$\it \sigma_{xx} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        title('$\rm\Delta\it\sigma_{xx} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    end
end
if flag.plot_cap == 1
    x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
    y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
    text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
end
if flag.vert == 1 % vertical fault
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
else % inclined fault
    ifs_plot_layout_incl(a,b,c,d,flag,theta,x_plot_max,x_plot_min,y_plot_max,y_plot_min) 
end
colormap(map)

% Create image plot of G_yy or sigma_yy:
if flag.vert == 1 % vertical fault
    if flag.inf == 1
        G_yy_image = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_yy_image = Green_vert_g_yy(a,b,c,d,x,y);
    end
    G_yy_image = G_yy_image - 2*pi * ...
        ( (-c < x) .* (x < 0) .* (-b < y) .* (y < a) + ...
          (0 <= x) .* (x < d) .* (-a < y) .* (y < b) );
else % inclined fault
    if flag.inf == 1
        G_yy_image = Green_incl_g_yy_inf(a,b,theta,x,y); % limit for infinite res.
    else
        G_yy_image = Green_incl_g_yy(a,b,c,d,theta,x,y);
    end
    G_yy_image = G_yy_image - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
end
sigma_yy_image = C_ref * G_yy_image;
figure
xx = [x_plot_min x_plot_max];
yy = [y_plot_min y_plot_max];
if flag.plot_G_or_sigma == 0
    imagesc(xx,-yy,G_yy_image)
    title('$\rm\it G_{yy}-2\pi\delta_{\Omega} \rm \, (-)$','Interpreter','latex','FontSize',11)
else
    imagesc(xx,-yy,sigma_yy_image/1e6,clims)
    switch flag.plot_nota
    case 0
        title('$\it \sigma_{yy} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        title('$\rm\Delta\it\sigma_{yy} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    end
end
if flag.plot_cap == 1
    x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
    y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
    text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
end
if flag.vert == 1 % vertical fault
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
else % inclined fault
    ifs_plot_layout_incl(a,b,c,d,flag,theta,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
end
colormap(map)

% Create image plot of G_xy or sigma_xy:
if flag.vert == 1 % vertical fault
    if flag.inf == 1
        G_xy_image = Green_vert_g_xy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xy_image = Green_vert_g_xy(a,b,c,d,x,y);
    end
else % inclined fault
    if flag.inf == 1
        G_xy_image = Green_incl_g_xy_inf(a,b,theta,x,y); % limit for infinite res.
    else
        G_xy_image = Green_incl_g_xy(a,b,c,d,theta,x,y);
    end
end
sigma_xy_image = C_ref * G_xy_image;
figure
xx = [x_plot_min x_plot_max];
yy = [y_plot_min y_plot_max];
if flag.plot_G_or_sigma == 0
    clims = [-4 4];
    imagesc(xx,-yy,G_xy_image,clims)
    title('$\rm\it G_{xy} \rm \, (-)$','Interpreter','latex','FontSize',11)
else
%     clims = [-4*abs(C_ref)/1e6 4*abs(C_ref)/1e6];
    clims = [-6*abs(C_ref)/1e6 6*abs(C_ref)/1e6];
    imagesc(xx,-yy,sigma_xy_image/1e6,clims)
    switch flag.plot_nota
    case 0
        title('$\it \sigma_{xy} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        title('$\rm\Delta\it\sigma_{xy} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
%         title('$\rm\Delta\it\sigma_{xy} \, \rm (MPa)$','Interpreter','latex','FontSize',16)
    end
end
if flag.plot_cap == 1
    x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
    y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
    text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
end
if flag.vert == 1 % vertical fault
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
else % inclined fault
    ifs_plot_layout_incl(a,b,c,d,flag,theta,x_plot_max,x_plot_min,y_plot_max,y_plot_min) 
end
% % % if flag.vert == 1 && flag.inf == 1
% % %     % Plot boundaries between positive and negative shear stresses:
% % %     boundary_1 =  sqrt(2*x.^2+b^2+a^2)/sqrt(2);
% % %     boundary_2 = -sqrt(2*x.^2+b^2+a^2)/sqrt(2);
% % %     hold on
% % %     plot(x,boundary_1,'--k')
% % %     plot(x,boundary_2,'--k')
% % %     hold off
% % % end
colormap(map)

%----------------------------------------------------------------------------------------------

% Create image plot of (Delta) p:
if flag.vert == 1 % vertical fault
    p_image = p_ref * ...
        ( (-c < x) .* (x < 0) .* (-b < y) .* (y < a) + ...
          (0 <= x) .* (x < d) .* (-a < y) .* (y < b) );
else % inclined fault
    p_image = p_ref * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
end
figure
xx = [x_plot_min x_plot_max];
yy = [y_plot_min y_plot_max];
imagesc(xx,-yy,p_image/1e6,clims)
switch flag.plot_nota
    case 0
        title('$\it p \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        title('$\rm\Delta\it p \, \rm (MPa)$','Interpreter','latex','FontSize',11)
end
if flag.plot_cap == 1
    x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
    y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
    text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
end
if flag.vert == 1 % vertical fault
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
else % inclined fault
    ifs_plot_layout_incl(a,b,c,d,flag,theta,x_plot_max,x_plot_min,y_plot_max,y_plot_min) 
end
colormap(map)

% Create image plot of sigma_eff_xx:
if flag.vert == 1 % vertical fault
    if flag.inf == 1
        G_xx_image = Green_vert_g_xx_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_xx_image = Green_vert_g_xx(a,b,c,d,x,y);
    end
    G_xx_image = G_xx_image - 2*pi * ...
        ( (-c < x) .* (x < 0) .* (-b < y) .* (y < a) + ...
          (0 <= x) .* (x < d) .* (-a < y) .* (y < b) );
else % inclined fault
    if flag.inf == 1
        G_xx_image = Green_incl_g_xx_inf(a,b,theta,x,y); % limit for infinite res.
    else
        G_xx_image = Green_incl_g_xx(a,b,c,d,theta,x,y);
    end
    G_xx_image = G_xx_image - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
end
sigma_xx_image = C_ref * G_xx_image;
sigma_eff_xx_image = sigma_xx_image + alpha * p_ref * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
figure
xx = [x_plot_min x_plot_max];
yy = [y_plot_min y_plot_max];
    imagesc(xx,-yy,sigma_eff_xx_image/1e6,clims)
%    imagesc(xx,-yy,-sigma_eff_xx_image/1e6,clims)  % rock mechanics sign convention
    switch flag.plot_nota
    case 0
        title('$\it \sigma\prime_{xx} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        title('$\rm\Delta\it\sigma\prime_{xx} \, \rm (MPa)$','Interpreter','latex',...
            'FontSize',11)
    end
if flag.plot_cap == 1
    x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
    y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
    text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
end
if flag.vert == 1 % vertical fault
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
else % inclined fault
    ifs_plot_layout_incl(a,b,c,d,flag,theta,x_plot_max,x_plot_min,y_plot_max,y_plot_min) 
end
colormap(map)

% Create image plot of sigma_eff_yy:
if flag.vert == 1 % vertical fault
    if flag.inf == 1
        G_yy_image = Green_vert_g_yy_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_yy_image = Green_vert_g_yy(a,b,c,d,x,y);
    end
    G_yy_image = G_yy_image - 2*pi * ...
        ( (-c < x) .* (x < 0) .* (-b < y) .* (y < a) + ...
          (0 <= x) .* (x < d) .* (-a < y) .* (y < b) );
else % inclined fault
    if flag.inf == 1
        G_yy_image = Green_incl_g_yy_inf(a,b,theta,x,y); % limit for infinite res.
    else
        G_yy_image = Green_incl_g_yy(a,b,c,d,theta,x,y);
    end
    G_yy_image = G_yy_image - 2*pi * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
end
sigma_yy_image = C_ref * G_yy_image;
sigma_eff_yy_image = sigma_yy_image + alpha * p_ref * ...
        ( (-c < x) .* (x < y/tan(theta)) .* (-b < y) .* (y < a) + ...
          (y/tan(theta) <= x) .* (x < d) .* (-a < y) .* (y < b) );
figure
xx = [x_plot_min x_plot_max];
yy = [y_plot_min y_plot_max];
    imagesc(xx,-yy,sigma_eff_yy_image/1e6,clims) 
%     imagesc(xx,-yy,-sigma_eff_yy_image/1e6,clims) % rock mechanics sign convention
    switch flag.plot_nota
    case 0
        title('$\it \sigma\prime_{yy} \, \rm (MPa)$','Interpreter','latex','FontSize',11)
    case 1
        title('$\rm\Delta\it\sigma\prime_{yy} \, \rm (MPa)$','Interpreter','latex',...
            'FontSize',11)
%         title('$\rm\Delta\it\sigma\prime_{yy} \, \rm (MPa)$','Interpreter','latex',...
%             'FontSize',16)
    end
if flag.plot_cap == 1
    x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
    y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
    text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
end
if flag.vert == 1 % vertical fault
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
else % inclined fault
    ifs_plot_layout_incl(a,b,c,d,flag,theta,x_plot_max,x_plot_min,y_plot_max,y_plot_min) 
end
colormap(map)

%----------------------------------------------------------------------------------------------

% Create image plot of G_x or u_x (functionality only available for vertical faults):
if flag.vert == 1 % vertical fault
    if flag.inf == 1
        G_x_image = Green_vert_g_x_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_x_image = Green_vert_g_x(a,b,c,d,x,y);
    end
    u_x_image = D_ref * G_x_image;
    figure
    % subplot(3,1,1)
    % subplot(1,3,1)
    xx = [x_plot_min x_plot_max];
    yy = [y_plot_min y_plot_max];
    if flag.plot_G_or_sigma == 0
        imagesc(xx,-yy,G_x_image)
        title('$\rm\it G_x \rm \, (-)$','Interpreter','latex','FontSize',11)
    else
        imagesc(xx,-yy,u_x_image*1e3)
        title('$\it u_x \, \rm (mm)$','Interpreter','latex','FontSize',11)
    end
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
        y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
    end
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
    colormap(map)
end

% Create image plot of G_y or u_y (functionality only available for vertical faults):
if flag.vert == 1 % vertical fault
    if flag.inf == 1
        G_y_image = Green_vert_g_y_inf(a,b,x,y); % limit for infinite reservoir
    else
        G_y_image = Green_vert_g_y(a,b,c,d,x,y);
    end
    u_y_image = D_ref * G_y_image;
    figure
    xx = [x_plot_min x_plot_max];
    yy = [y_plot_min y_plot_max];
    if flag.plot_G_or_sigma == 0
        imagesc(xx,-yy,G_y_image)
        title('$\rm\it G_y \rm \, (-)$','Interpreter','latex','FontSize',11)
    else
        imagesc(xx,-yy,u_y_image*1e3)
        title('$\it u_y \, \rm (mm)$','Interpreter','latex','FontSize',11)
    end
    if flag.plot_cap == 1
        x_text = x_plot_min + 0.10 * (x_plot_max-x_plot_min);
        y_text = y_plot_min - 0.06 * (y_plot_max-y_plot_min);
        text(x_text,y_text,'plot\_images','FontSize',10,'Color','r')
    end
    ifs_plot_layout_vert(a,b,c,d,flag,x_plot_max,x_plot_min,y_plot_max,y_plot_min)
    colormap(map)
end



