function ifs_plot_loading_stress_components_dpdy(data,flag,plotpar)
%
% Plots root-mean-squared values of the loading stress components d2W_dpdy_delta and
% W_d2delta_dpdy, and epsilon_py as a function of depletion pressure. 
%

% Retrieve:
epsilon = data.epsilon_py; % -
rms_dW_dy_ddelta_dp = data.rms_dW_dy_ddelta_dp; % root-mean-square value of d2W_dpdy_delta, -
rms_W_d2delta_dpdy = data.rms_W_d2delta_dpdy; % root-mean-square value of W_d2delta_dpdy, -
p_inc = data.p_inc; % incremental pressure; negative for depletion, Pa
p_seismic = data.p_seismic; % depletion pressure at which seismicity occurs, Pa
  
x_plot_max_nucl = plotpar.x_plot_max_nucl; % maximum value nucleation plot, MPa 
x_plot_min_nucl = plotpar.x_plot_min_nucl; % minimum value nucleation plot, MPa 
y_plot_max_bounds = plotpar.y_plot.max_bounds;
y_plot_min_bounds = plotpar.y_plot.min_bounds;

black = plotpar.colors.black;
blue = plotpar.colors.blue;
coal = plotpar.colors.coal;
green = plotpar.colors.green;
orange = plotpar.colors.orange;
purple = plotpar.colors.purple;
red = plotpar.colors.red;

% Truncate plot array for p_inc to avoid plotting for pressures p_seismic:
% n_plot_max = length(p_inc); % maximum number of pressure steps, -
% p_inc_plot = p_inc(  1:min(j_merge_y_til,n_plot_max));
p_inc_plot = p_inc;

% figure
subplot(1,2,2)
y_plot_max_bounds_plot = 4;
hold on
line([-p_seismic/1e6 -p_seismic/1e6],[y_plot_min_bounds y_plot_max_bounds],...
    'LineStyle',':','Color',red,'LineWidth',1.0)
L1 = plot(-p_inc_plot(1:end-1)/1e6,rms_dW_dy_ddelta_dp(1:end-1),'-','Color',blue,...
    'LineWidth',1.5);
L2 = plot(-p_inc_plot(1:end-1)/1e6,rms_W_d2delta_dpdy(1:end-1),'-','Color',black,...
    'LineWidth',1.5);
L3 = plot(-p_inc_plot(1:end-1)/1e6,epsilon(1:end-1),'-','Color',green,'LineWidth',1.5);
hold off
switch flag.plot_nota
    case 0
        xlabel('$\it -p$ (MPa)','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$-\rm\Delta\it p$ (MPa)','Interpreter','latex','FontSize',11)
end
axis([x_plot_min_nucl x_plot_max_nucl 0 y_plot_max_bounds_plot])
ylabel('$\{\rm rms ({\it \nabla W \dot\delta}), \rm rms ({\it W \nabla\dot\delta})\} (1/m), \it\epsilon_2$ (-)',...
    'Interpreter','latex','FontSize',11)
legend([L1,L2,L3],{'$\it \nabla W \dot\delta$','$\it W \nabla\dot\delta$','$\it\epsilon_2$'},'Interpreter',...
    'latex','FontSize',11,'location','northwest')
if flag.plot_cap == 1
    t = title('plot\_nucleation'); % plot file locator
    t.Color = red;
    t.FontSize = 10;
    t.FontWeight = 'normal';
end
box on
grid on

