function ifs_plot_nucleation(data,flag,model,plotpar)
%
% Plots distances between slip patch boundaries y_til, and nucleation lengths as a function of
% depletion pressure. 
%

% Retrieve:
a = model.a;
Delta_y_eig_top = data.Delta_y_eig_top; % nucleation length top patch (eigenvalue-based), m
Delta_y_UR_top = data.Delta_y_UR_top; % nucleation length top patch (Uenishi & Rice), m
p_inc = data.p_inc; % incremental pressure; negative for depletion, Pa
p_seismic = data.p_seismic; % depletion pressure at which seismicity occurs, Pa
y_til = data.y_til; % coupled slip patch bounds, m
j_merge_y_til = data.j_merge_y_til; % pressure step at which coupled slip patch bounds have ...
    % merged, -
  
x_plot_max_nucl = plotpar.x_plot_max_nucl; % maximum value nucleation plot, MPa 
x_plot_min_nucl = plotpar.x_plot_min_nucl; % minimum value nucleation plot, MPa 
y_plot_max_nucl = plotpar.y_plot_max_nucl; % maximum value nucleation plot, MPa 
y_plot_min_nucl = plotpar.y_plot_min_nucl; % minimum value nucleation plot, MPa 

blue = plotpar.colors.blue;
coal = plotpar.colors.coal;
green = plotpar.colors.green;
red = plotpar.colors.red;

% Compute auxiliary variables:
n_plot_max = length(p_inc); % maximum number of pressure steps, -
y_til_4_plot = y_til(4,:);

% Truncate plot arrays for y_pre(2,:) and y_pre(3,:) to avoid plotting for pressures below ...
    % p_merge or p_seismic:
p_til_3_plot = p_inc(  1:min(j_merge_y_til,n_plot_max));
y_til_3_plot = y_til(3,1:min(j_merge_y_til,n_plot_max));

n_plot_3 = length(y_til_3_plot);
Delta_y_plot_top = y_til_4_plot(1:n_plot_3) - y_til_3_plot(1:n_plot_3);

figure
subplot(1,2,1)
hold on
line([-p_seismic/1e6 -p_seismic/1e6],[y_plot_min_nucl y_plot_max_nucl],...
    'LineStyle',':','Color',red,'LineWidth',0.75)
Delta_y_UR_top(end) = Delta_y_UR_top(end-1); % cosmetic
Delta_y_plot_top(end) = max(Delta_y_eig_top(end-1),Delta_y_UR_top(end-1)); % cosmetic
if flag.int == 3
    L2 = plot(-p_til_3_plot(1:end)/1e6,Delta_y_eig_top(1:end),'-','Color',blue,...
        'LineWidth',1.5);
end
L4 = plot(-p_til_3_plot(1:end)/1e6,Delta_y_UR_top(1:end),'-','Color',green,...
    'LineWidth',1.5);
L6 = plot(-p_til_3_plot/1e6,Delta_y_plot_top,'-','Color',red,'LineWidth',1.5);
if flag.sym == 1
    L7 = plot(-p_til_3_plot/1e6,ones(1,length(p_til_3_plot))*a,':','Color',coal,...
        'LineWidth',1.5);
    L8 = plot(-p_til_3_plot/1e6,a-y_til_3_plot,'--','Color',red,'LineWidth',1.5);
end

hold off
switch flag.plot_nota
    case 0
        xlabel('$\it -p$ (MPa)','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$-\rm\Delta\it p$ (MPa)','Interpreter','latex','FontSize',11)
end
ylabel('$ \Delta y, \Delta y^*$ (m)','Interpreter','latex','FontSize',11)
axis([x_plot_min_nucl x_plot_max_nucl y_plot_min_nucl y_plot_max_nucl])
if flag.sym == 0
    if flag.int == 3
        if flag.coupled == 1
            legend([L2,L4,L6],{'$\Delta y_{top,eig}$','$\Delta y_{top,EU\&R}$',...
                '$\Delta y_{top,sim}$'},'Interpreter','latex','FontSize',11,'Location',...
                'SouthWest');
        else
            legend([L2,L4,L6],{'$\Delta y_{top,eig}$','$\Delta y_{top,U\&R}$',...
                '$\Delta y_{top,sim}$'},'Interpreter','latex','FontSize',11,'Location',...
                'SouthWest');
        end
    else
        legend([L4,L6],{'$\Delta y_{top,EU\&R}$',...
            '$\Delta y_{top,sim}$'},'Interpreter','latex','FontSize',11,'Location',...
            'SouthWest');
    end
else
    if flag.int == 3
        legend([L2,L6,L7,L8],{'$\Delta y_{eig}$','$\Delta y_{sim}$','$a$',...
            '$a-\tilde y_3$'},'Interpreter','latex','FontSize',11,'Location','SouthEast');
    else
        legend([L6,L7,L8],{'$\Delta y_{sim}$','$a$','$a-\tilde y_3$'},'Interpreter',...
            'latex','FontSize',11,'Location','SouthEast');
    end
end
if flag.plot_cap == 1
    t = title('plot\_nucleation'); % plot file locator
    t.Color = red;
    t.FontSize = 10;
    t.FontWeight = 'normal';
end
box on
