function ifs_plot_patch_bounds(admin,data,flag,model,numpar,plotpar)
%
% Plots pre-slip Coulomb stress zeros y_pre and slip patch boundaries y_til as a function of
% depletion pressure. 
%

% Retrieve:
input = admin.input; % flag to select input file

p_inc = data.p_inc; % incremental pressure; negative for depletion, Pa
p_mus = data.p_mus; % incremental pressure for plotting incorrect Muskelishvili coupled ...
    % slip patch boundaries, Pa
p_seismic = data.p_seismic; % depletion pressure at which seismicity occurs, Pa
p_sym = data.p_sym; % incremental pressure for plotting symmetric configuration results
p_unc = data.p_unc; % incremental pressure for plotting uncoupled slip patch boundaries, Pa
p_wee = data.p_wee; % incremental pressure for plotting incorrect Weertman coupled slip ...
    % patch boundaries, Pa
y_mus = data.y_mus; % incorrect Mushkelisvili coupled slip patch bounds, m
y_pre = data.y_pre; % pre-slip Coulomb stress zeros, m
y_sym = data.y_sym; % symmetric configuration bounds, m
y_til = data.y_til; % coupled slip patch bounds, m
y_unc = data.y_unc; % uncoupled slip patch bounds, m
y_wee = data.y_wee; % incorrect Weertman coupled slip patch bounds, m
j_merge_y_pre = data.j_merge_y_pre; % pressure step at which pre-slip Coulomb stress ...
    % patches have merged, -
j_merge_y_til = data.j_merge_y_til; % pressure step at which coupled slip patch bounds have ...
    % merged, -
j_merge_y_unc = data.j_merge_y_unc; % pressure step at which uncoupled slip patch bounds ...
    % have merged, -
j_merge_y_mus = data.j_merge_y_mus; % pressure step at which incorrect Mushkelishvili ...
    % coupled slip patch bounds have merged, -
j_merge_y_wee = data.j_merge_y_wee; % pressure step at which incorrect Weertman coupled ...
    % slip patch bounds have merged, -
j_merge_y_sym = data.j_merge_y_sym; % pressure step at which symmetric slip patch bounds ...
% have merged, -

a = model.a;
b = model.b;
    
dir = numpar.dir; % indicates operation: dir = 1: injection; dir = -1: depletion, - 
p_max_bounds = numpar.p_max_bounds; % highest incremental pressure (negative for depletion), Pa
p_min_bounds = numpar.p_min_bounds; % lowest incremental pressure (negative for depletion), Pa

n_snap = plotpar.n_snap; % number of snap_shots, - 
p_inc_ref = plotpar.p_inc_ref; % reference pressure used in image plots etc., Pa
p_inc_snap = plotpar.p_inc_snap; % incremental pressures at which to take snapshots, Pa
x_plot_max_bounds = plotpar.x_plot.max_bounds;
x_plot_min_bounds = plotpar.x_plot.min_bounds;
x_plot_min_bounds_detail = plotpar.x_plot_min_bounds_detail;
x_plot_max_bounds_detail = plotpar.x_plot_max_bounds_detail;
y_plot_max_bounds = plotpar.y_plot.max_bounds;
y_plot_min_bounds = plotpar.y_plot.min_bounds;
y_plot_min_bounds_detail = plotpar.y_plot_min_bounds_detail;
y_plot_max_bounds_detail = plotpar.y_plot_max_bounds_detail;

black = plotpar.colors.black;
blue = plotpar.colors.blue;
coal = plotpar.colors.coal;
gray = plotpar.colors.gray;
green = plotpar.colors.green;
orange = plotpar.colors.orange;
purple = plotpar.colors.purple;
red = plotpar.colors.red;

% Remove last element from all plot arrays in case of sign reversal criterion:
if flag.fric == 2 && flag.nuc == 4
    p_inc = p_inc(:,1:end-1);
    p_sym = p_sym(:,1:end-1);
    p_unc = p_unc(:,1:end-1);
    y_pre = y_pre(:,1:end-1);
    y_til = y_til(:,1:end-1);
    y_sym = y_sym(:,1:end-1);
    y_unc = y_unc(:,1:end-1);
end

% Compute auxiliary variables:
n_plot_max = length(p_inc); % maximum number of pressure steps, -

% Truncate plot arrays for y_pre(1,:) and y_pre(4,:) to avoid plotting for pressures below ...
    % p_seismic or p_min: 
% Delta_p_plot = Delta_p(1:i);
% Delta_y_max_obs_plot = Delta_y_max_obs(1:i);
p_pre_1_plot = p_inc;
p_pre_4_plot = p_inc;
y_pre_1_plot = y_pre(1,:);
y_pre_4_plot = y_pre(4,:);
p_til_1_plot = p_inc;
p_til_4_plot = p_inc;
y_til_1_plot = y_til(1,:);
y_til_4_plot = y_til(4,:);
if flag.coupled == 1 && flag.plot_adu == 1
    p_unc_1_plot = p_unc;
    p_unc_4_plot = p_unc;
    y_unc_1_plot = y_unc(1,:);
    y_unc_4_plot = y_unc(4,:);
end
if flag.coupled == 1 && flag.plot_amu == 1
    p_mus_1_plot = p_mus;
    p_mus_4_plot = p_mus;
    y_mus_1_plot = y_mus(1,:);
    y_mus_4_plot = y_mus(4,:);
    p_wee_1_plot = p_wee;
    p_wee_4_plot = p_wee;
    y_wee_1_plot = y_wee(1,:);
    y_wee_4_plot = y_wee(4,:);
end
if flag.coupled == 1 && flag.plot_asy == 1
    p_sym_1_plot = p_sym;
    p_sym_4_plot = p_sym;
    y_sym_1_plot = y_sym(1,:);
    y_sym_4_plot = y_sym(4,:);
end

% Truncate plot arrays for y_pre(2,:) and y_pre(3,:) to avoid plotting for pressures below ...
    % p_merge or p_seismic:
p_pre_2_plot = p_inc(  1:min(j_merge_y_pre,n_plot_max));
p_pre_3_plot = p_inc(  1:min(j_merge_y_pre,n_plot_max));
y_pre_2_plot = y_pre(2,1:min(j_merge_y_pre,n_plot_max));
y_pre_3_plot = y_pre(3,1:min(j_merge_y_pre,n_plot_max));
p_til_2_plot = p_inc(  1:min(j_merge_y_til,n_plot_max));
p_til_3_plot = p_inc(  1:min(j_merge_y_til,n_plot_max));
y_til_2_plot = y_til(2,1:min(j_merge_y_til,n_plot_max));
y_til_3_plot = y_til(3,1:min(j_merge_y_til,n_plot_max));
if flag.coupled == 1 && flag.plot_adu == 1
    p_unc_2_plot = p_unc(  1:min(j_merge_y_unc,n_plot_max));
    p_unc_3_plot = p_unc(  1:min(j_merge_y_unc,n_plot_max));
    y_unc_2_plot = y_unc(2,1:min(j_merge_y_unc,n_plot_max));
    y_unc_3_plot = y_unc(3,1:min(j_merge_y_unc,n_plot_max));
end
if flag.coupled == 1 && flag.plot_amu == 1
    p_mus_2_plot = p_mus(  1:min(j_merge_y_mus,n_plot_max));
    p_mus_3_plot = p_mus(  1:min(j_merge_y_mus,n_plot_max));
    y_mus_2_plot = y_mus(2,1:min(j_merge_y_mus,n_plot_max));
    y_mus_3_plot = y_mus(3,1:min(j_merge_y_mus,n_plot_max));
    p_wee_2_plot = p_wee(  1:min(j_merge_y_wee,n_plot_max));
    p_wee_3_plot = p_wee(  1:min(j_merge_y_wee,n_plot_max));
    y_wee_2_plot = y_wee(2,1:min(j_merge_y_wee,n_plot_max));
    y_wee_3_plot = y_wee(3,1:min(j_merge_y_wee,n_plot_max));
end
if flag.coupled == 1 && flag.plot_asy == 1
    p_sym_2_plot = p_sym(  1:min(j_merge_y_sym,n_plot_max));
    p_sym_3_plot = p_sym(  1:min(j_merge_y_sym,n_plot_max));
    y_sym_2_plot = y_sym(2,1:min(j_merge_y_sym,n_plot_max));
    y_sym_3_plot = y_sym(3,1:min(j_merge_y_sym,n_plot_max));
end
% Delta_y_plot_bot = y_til_2(1:min(i_max_2_til+1,n_p_max)) - ...
%     y_til_1(1:min(i_max_2_til+1,n_p_max));
% Delta_y_plot_top = y_til_4(1:min(i_max_3_til+1,n_p_max)) - ...
%     y_til_3(1:min(i_max_3_til+1,n_p_max));

% Read DARTS data:
path_in = 'C:\Users\djansen\My Documents\Onderzoek\Induced seismicity\IFS\IFS data GGGG\';
data_DARTS = readmatrix([path_in,'data_DARTS_constant_friction_patch_boundaries.txt']);
data_DARTS_plot_1 = data_DARTS;
data_DARTS_plot_1([5:8,39,41,42,44,75:78],:) = []; % removes superfluous data points
p_DARTS_plot_1 = data_DARTS_plot_1(:,1);
y_tilde_DARTS_plot_1 = data_DARTS_plot_1(:,2);
data_DARTS_plot_2 = data_DARTS;
data_DARTS_plot_2([5:8,40,43,75:78],:) = []; % removes superfluous data points
p_DARTS_plot_2 = data_DARTS_plot_2(:,1);
y_tilde_DARTS_plot_2 = data_DARTS_plot_2(:,2);

figure
if flag.fric == 1 % static friction
    hold on
    line([ 0 dir*p_min_bounds],[   0    0],'LineStyle','-','Color',black,'LineWidth',0.5)
    line([ 0 dir*p_min_bounds],[   a    a],'LineStyle',':','Color',black,'LineWidth',0.75)
    line([ 0 dir*p_min_bounds],[  -a   -a],'LineStyle',':','Color',black,'LineWidth',0.75)
    line([ 0 dir*p_min_bounds],[   b    b],'LineStyle',':','Color',black,'LineWidth',0.75)
    line([ 0 dir*p_min_bounds],[  -b   -b],'LineStyle',':','Color',black,'LineWidth',0.75)
    % if flag.plot_snap == 1
    %     for i_snap = 1:n_snap
    %         line([dir*p_inc_snap(i_snap)/1e6 dir*p_inc_snap(i_snap)/1e6],...
    %             [y_plot_min_bounds y_plot_max_bounds],'LineStyle','-.','Color',coal,...
    %             'LineWidth',0.5) % snap shot pressures
    %     end
    % end
    line([dir*p_inc_ref/1e6 dir*p_inc_ref/1e6],[y_plot_min_bounds y_plot_max_bounds],...
        'LineStyle','-.','Color',black,'LineWidth',0.5) % reference pressure
    label_1 = plot(dir*p_pre_1_plot/1e6,y_pre_1_plot,'-','Color',green,'LineWidth',1.5);
    plot(dir*p_pre_2_plot/1e6,y_pre_2_plot,'-','Color',green,'LineWidth',1.5)
    plot(dir*p_pre_3_plot/1e6,y_pre_3_plot,'-','Color',green,'LineWidth',1.5)
    plot(dir*p_pre_4_plot/1e6,y_pre_4_plot,'-','Color',green,'LineWidth',1.5)
    if flag.coupled == 1 && flag.plot_adu == 1
        label_2 = plot(dir*p_unc_1_plot/1e6,y_unc_1_plot,'-','Color',blue,'LineWidth',1.5);
        plot(dir*p_unc_2_plot/1e6,y_unc_2_plot,'-','Color',blue,'LineWidth',1.5)
        plot(dir*p_unc_3_plot/1e6,y_unc_3_plot,'-','Color',blue,'LineWidth',1.5)
        plot(dir*p_unc_4_plot/1e6,y_unc_4_plot,'-','Color',blue,'LineWidth',1.5)
    end
    if flag.coupled == 1 && flag.plot_amu == 1
        label_3 = plot(dir*p_mus_1_plot/1e6,y_mus_1_plot,'-','Color',orange,'LineWidth',1.5);
        plot(dir*p_mus_2_plot/1e6,y_mus_2_plot,'-','Color',orange,'LineWidth',1.5)
        plot(dir*p_mus_3_plot/1e6,y_mus_3_plot,'-','Color',orange,'LineWidth',1.5)
        plot(dir*p_mus_4_plot/1e6,y_mus_4_plot,'-','Color',orange,'LineWidth',1.5)
        label_4 = plot(dir*p_wee_1_plot/1e6,y_wee_1_plot,'-.','Color',orange,'LineWidth',1.5);
        plot(dir*p_wee_2_plot/1e6,y_wee_2_plot,'-.','Color',orange,'LineWidth',1.5)
        plot(dir*p_wee_3_plot/1e6,y_wee_3_plot,'-.','Color',orange,'LineWidth',1.5)
        plot(dir*p_wee_4_plot/1e6,y_wee_4_plot,'-.','Color',orange,'LineWidth',1.5)
    end
    if input == 01
        label_6 = plot(p_DARTS_plot_1,y_tilde_DARTS_plot_1,'o','Color',coal,'LineWidth',0.75,...
            'MarkerSize',4.0);
    end
    label_5 = plot(dir*p_til_1_plot/1e6,y_til_1_plot,'-','Color',red,'LineWidth',1.5);
    plot(dir*p_til_2_plot/1e6,y_til_2_plot,'-','Color',red,'LineWidth',1.5)
    plot(dir*p_til_3_plot/1e6,y_til_3_plot,'-','Color',red,'LineWidth',1.5)
    plot(dir*p_til_4_plot/1e6,y_til_4_plot,'-','Color',red,'LineWidth',1.5)
    hold off
    if input == 01
        text(30.3,-75,'$\it y_1$','Interpreter','latex','FontSize',11)
        text(28.9,-20,'$\it y_2$','Interpreter','latex','FontSize',11)
        text(28.8, 20,'$\it y_3$','Interpreter','latex','FontSize',11)
        text(30.3, 75,'$\it y_4$','Interpreter','latex','FontSize',11)
        text(30.3,-88,'$\it \tilde{y}_1$','Interpreter','latex','FontSize',11)
        text(26.8,-20,'$\it \tilde{y}_2$','Interpreter','latex','FontSize',11)
        text(26.7, 20,'$\it \tilde{y}_3$','Interpreter','latex','FontSize',11)
        text(30.3, 88,'$\it \tilde{y}_4$','Interpreter','latex','FontSize',11)
    end
    if dir == 1 % injection
        switch flag.plot_nota
            case 0
                xlabel('$\it p$ (MPa)','Interpreter','latex','FontSize',11)
            case 1
                xlabel('$\rm \Delta\it p$ (MPa)','Interpreter','latex','FontSize',11)
        end
        axis([p_min_bounds/1e6 p_max_bounds/1e6 y_plot_min_bounds y_plot_max_bounds])
    else % depletion
        switch flag.plot_nota
            case 0
                xlabel('$\it -p$ (MPa)','Interpreter','latex','FontSize',11)
            case 1
                xlabel('$\rm -\Delta\it p$ (MPa)','Interpreter','latex','FontSize',11)
        end
        % % % %         axis([-p_max_bounds/1e6 -p_min_bounds/1e6 y_plot_min_bounds y_plot_max_bounds])
        axis([x_plot_min_bounds x_plot_max_bounds y_plot_min_bounds y_plot_max_bounds])
    end
    ylabel('$\it y_i, \tilde{y}_i$ (m)','Interpreter','latex','FontSize',11)
    if admin.input == 01 && flag.coupled == 1 && flag.plot_adu == 1 && flag.plot_amu == 1
        line([22 22],[ 59.5  75.5],'LineStyle','-','Color',green,'LineWidth',0.75)
        line([22 22],[-61.7 -75.4],'LineStyle','-','Color',green,'LineWidth',0.75)
        line([23 23],[ 45.0  78.6],'LineStyle','-','Color',red,'LineWidth',0.75)
        line([23 23],[-49.0 -78.1],'LineStyle','-','Color',red,'LineWidth',0.75)
        cx = 1.5;
        line([22 22],[ 59.5+cx  59.5+cx],'Marker','v','MarkerSize',3,'MarkerEdgeColor',green,...
            'MarkerFaceColor',green)
        line([22 22],[ 75.5-cx  75.5-cx],'Marker','^','MarkerSize',3,'MarkerEdgeColor',green,...
            'MarkerFaceColor',green)
        line([22 22],[-61.7-cx -61.7-cx],'Marker','^','MarkerSize',3,'MarkerEdgeColor',green,...
            'MarkerFaceColor',green)
        line([22 22],[-75.4+cx -75.4+cx],'Marker','v','MarkerSize',3,'MarkerEdgeColor',green,...
            'MarkerFaceColor',green)
        line([23 23],[ 45.0+cx  45.0+cx],'Marker','v','MarkerSize',3,'MarkerEdgeColor',red,...
            'MarkerFaceColor',red)
        line([23 23],[ 78.6-cx  78.6-cx],'Marker','^','MarkerSize',3,'MarkerEdgeColor',red,...
            'MarkerFaceColor',red)
        line([23 23],[-49.0-cx -49.0-cx],'Marker','^','MarkerSize',3,'MarkerEdgeColor',red,...
            'MarkerFaceColor',red)
        line([23 23],[-78.1+cx -78.1+cx],'Marker','v','MarkerSize',3,'MarkerEdgeColor',red,...
            'MarkerFaceColor',red)
        if input == 01
            legend([label_1,label_2,label_5,label_4,label_3,label_6],...
                {'Coulomb stress zeros','Uncoupled','Coupled','Coupled, Weertman',...
                'Coupled, Mushkelishvili','Numerical'},'Location','West');
        else
            legend([label_1,label_2,label_5,label_4,label_3],...
                {'Coulomb stress zeros','Uncoupled','Coupled','Coupled, Weertman',...
                'Coupled, Mushkelishvili'},'Location','West');
        end
    end
    box on
%     grid on

    if input == 01 % static friction
        figure % detailed view
        hold on
        line([ 0 dir*p_min_bounds],[   0    0],'LineStyle','-','Color',black,'LineWidth',0.5)
        line([ 0 dir*p_min_bounds],[   a    a],'LineStyle',':','Color',black,'LineWidth',0.75)
        line([ 0 dir*p_min_bounds],[  -a   -a],'LineStyle',':','Color',black,'LineWidth',0.75)
        line([ 0 dir*p_min_bounds],[   b    b],'LineStyle',':','Color',black,'LineWidth',0.75)
        line([ 0 dir*p_min_bounds],[  -b   -b],'LineStyle',':','Color',black,'LineWidth',0.75)
        %     line([dir*p_inc_ref/1e6 dir*p_inc_ref/1e6],[y_plot_min_bounds y_plot_max_bounds],...
        %         'LineStyle','-.','Color',black,'LineWidth',0.5) % reference pressure
        label_1 = plot(dir*p_pre_1_plot/1e6,y_pre_1_plot,'-','Color',green,'LineWidth',1.5);
        plot(dir*p_pre_2_plot/1e6,y_pre_2_plot,'-','Color',green,'LineWidth',1.5)
        plot(dir*p_pre_3_plot/1e6,y_pre_3_plot,'-','Color',green,'LineWidth',1.5)
        plot(dir*p_pre_4_plot/1e6,y_pre_4_plot,'-','Color',green,'LineWidth',1.5)
        if flag.coupled == 1 && flag.plot_adu == 1
            label_2 = plot(dir*p_unc_1_plot/1e6,y_unc_1_plot,'-','Color',blue,'LineWidth',1.5);
            plot(dir*p_unc_2_plot/1e6,y_unc_2_plot,'-','Color',blue,'LineWidth',1.5)
            plot(dir*p_unc_3_plot/1e6,y_unc_3_plot,'-','Color',blue,'LineWidth',1.5)
            plot(dir*p_unc_4_plot/1e6,y_unc_4_plot,'-','Color',blue,'LineWidth',1.5)
        end
        if flag.coupled == 1 && flag.plot_amu == 1
            label_3 = plot(dir*p_mus_1_plot/1e6,y_mus_1_plot,'-','Color',orange,'LineWidth',1.5);
            plot(dir*p_mus_2_plot/1e6,y_mus_2_plot,'-','Color',orange,'LineWidth',1.5)
            plot(dir*p_mus_3_plot/1e6,y_mus_3_plot,'-','Color',orange,'LineWidth',1.5)
            plot(dir*p_mus_4_plot/1e6,y_mus_4_plot,'-','Color',orange,'LineWidth',1.5)
            label_4 = plot(dir*p_wee_1_plot/1e6,y_wee_1_plot,'-.','Color',orange,'LineWidth',1.5);
            plot(dir*p_wee_2_plot/1e6,y_wee_2_plot,'-.','Color',orange,'LineWidth',1.5)
            plot(dir*p_wee_3_plot/1e6,y_wee_3_plot,'-.','Color',orange,'LineWidth',1.5)
            plot(dir*p_wee_4_plot/1e6,y_wee_4_plot,'-.','Color',orange,'LineWidth',1.5)
        end
        if flag.coupled == 1 && flag.plot_asy == 1
            label_7 = plot(dir*p_sym_1_plot/1e6,y_sym_1_plot,'--','Color',coal,'LineWidth',1.5);
            plot(dir*p_sym_2_plot/1e6,y_sym_2_plot,'--','Color',coal,'LineWidth',1.5)
            plot(dir*p_sym_3_plot/1e6,y_sym_3_plot,'--','Color',coal,'LineWidth',1.5)
            plot(dir*p_sym_4_plot/1e6,y_sym_4_plot,'--','Color',coal,'LineWidth',1.5)
        end
        label_8 = plot(p_DARTS_plot_2,y_tilde_DARTS_plot_2,'o','Color',coal,'LineWidth',1.0,...
            'MarkerSize',7.0);
        label_5 = plot(dir*p_til_1_plot/1e6,y_til_1_plot,'-','Color',red,'LineWidth',1.5);
        plot(dir*p_til_2_plot/1e6,y_til_2_plot,'-','Color',red,'LineWidth',1.5)
        plot(dir*p_til_3_plot/1e6,y_til_3_plot,'-','Color',red,'LineWidth',1.5)
        plot(dir*p_til_4_plot/1e6,y_til_4_plot,'-','Color',red,'LineWidth',1.5)
        hold off
        axis([x_plot_min_bounds_detail x_plot_max_bounds_detail y_plot_min_bounds_detail ...
            y_plot_max_bounds_detail])
        switch flag.plot_nota
            case 0
                xlabel('$\it -p$ (MPa)','Interpreter','latex','FontSize',11)
            case 1
                xlabel('$\rm -\Delta\it p$ (MPa)','Interpreter','latex','FontSize',11)
        end
        ylabel('$\it y_i, \tilde{y}_i$ (m)','Interpreter','latex','FontSize',11)
        if admin.input == 01 && flag.coupled == 1 && flag.plot_adu == 1 && flag.plot_amu == 1 && ...
                flag.plot_asy == 1
            legend([label_1,label_2,label_5,label_7,label_4,label_3,label_8],...
                {'Coulomb stress zeros','Uncoupled','Coupled','Coupled, symmetric',...
                'Coupled, Weertman','Coupled, Mushkelishvili','Numerical'},'Location','NorthEast');
        end
        box on
%         grid on
    end

else % slip-weakening
    hold on
%     plot(-p_til_1_plot(1:end-1)/1e6,y_til_1_plot(1:end-1),'-','Color',red,'LineWidth',1.5)
%     plot(-p_til_2_plot(1:end-1)/1e6,y_til_2_plot(1:end-1),'-','Color',red,...
%         'LineWidth',1.5)
%     plot(-p_til_3_plot(1:end-1)/1e6,y_til_3_plot(1:end-1),'-','Color',red,...
%         'LineWidth',1.5)
%     plot(-p_til_4_plot(1:end-1)/1e6,y_til_4_plot(1:end-1),'-','Color',red,'LineWidth',1.5)
    plot(-p_til_1_plot(1:end)/1e6,y_til_1_plot(1:end),'-','Color',red,'LineWidth',1.5)
    plot(-p_til_2_plot(1:end)/1e6,y_til_2_plot(1:end),'-','Color',red,...
        'LineWidth',1.5)
    plot(-p_til_3_plot(1:end)/1e6,y_til_3_plot(1:end),'-','Color',red,...
        'LineWidth',1.5)
    plot(-p_til_4_plot(1:end)/1e6,y_til_4_plot(1:end),'-','Color',red,'LineWidth',1.5)
    line([ 0 35],[   0    0],'LineStyle','-','Color',black,'LineWidth',0.5) % horizontal line
    line([ 0 35],[   a    a],'LineStyle',':','Color',black,'LineWidth',0.5)
    line([ 0 35],[  -a   -a],'LineStyle',':','Color',black,'LineWidth',0.5)
    line([-p_seismic/1e6 -p_seismic/1e6],[y_plot_min_bounds y_plot_max_bounds],...
        'LineStyle',':','Color',red,'LineWidth',0.5)
    hold off
    box on
    p_min_bounds_plot = floor(1.02 * p_til_4_plot(end-1)/1e6);
%    p_min_bounds_plot = -19;
    p_max_bounds_plot = max(p_til_3_plot(1:end-1)/1e6);
    x_text = ( -p_min_bounds_plot + 0.03 * (-p_min_bounds_plot+p_max_bounds_plot) )/1e6;
    text(x_text,max(y_til_1_plot(end-1),y_plot_min_bounds)-5,...
        '$\it \tilde{y}_1$','Interpreter','latex','FontSize',11)
    text(x_text,y_til_2_plot(end-1)+7,'$\it \tilde{y}_2$','Interpreter',...
        'latex','FontSize',11)
    text(x_text,y_til_3_plot(end-1)-5,'$\it \tilde{y}_3$','Interpreter',...
        'latex','FontSize',11)
    text(x_text,min(y_til_4_plot(end-1),y_plot_max_bounds)+7,...
        '$\it \tilde{y}_4$','Interpreter','latex','FontSize',11)
    switch flag.plot_nota
        case 0
            xlabel('$\it -p$ (MPa)','Interpreter','latex','FontSize',11)
        case 1
            xlabel('$\it -{\rm \Delta} p$ (MPa)','Interpreter','latex','FontSize',11)
    end
    ylabel('$\tilde{y}_i$ (m)','Interpreter','latex','FontSize',11)
% % % %     axis([-p_max_bounds/1e6 -p_min_bounds_plot y_plot_min_bounds y_plot_max_bounds])
    axis([x_plot_min_bounds x_plot_max_bounds y_plot_min_bounds y_plot_max_bounds])
    box on
end
if flag.plot_cap == 1
    [t,s] = title('plot\_patch\_bounds',' '); % first line: plot file locator
    t.Color = red;
    t.FontSize = 10;
    s.FontSize = 10;
    t.FontWeight = 'normal';
    s.FontWeight = 'normal';
end
