function ifs_plot_snaps(admin,data,flag,model,plotpar) 
%
% Plots stresses and slip at the fault at pre-selected depletion pressures.
%

% Retrieve:
snap = data.snap;
delta = snap.delta; % slip, m
grad = snap.grad; % slip gradient, -
sigma_brv = snap.sigma_brv; % slip-induced stresses, Pa
sigma_C = snap.sigma_C; % pre-slip Coulomb stresses, Pa
sigma_shear_comb = snap.sigma_shear_comb; % combined shear stress, Pa
sigma_slip = snap.sigma_slip; % right slip threshold, Pa
y_sigma = snap.y_sigma; % y values for pre-slip Coulomb stresses, m
y_delta = snap.y_delta; % y values for slip and slip gradient, m
y_pre_snap = snap.y_pre; % pre-slip Coulomb stress zeros, m
y_til_snap = snap.y_til; % slip patch boundaries, m
if flag.coupled == 1 && flag.plot_amu == 1 % triggers additional plotting of incorrect results
    delta_mus = snap.delta_mus; % slip for Muskelishvili, m
    delta_wee = snap.delta_wee; % idem for Weertman, m
    grad_mus = snap.grad_mus; % slip gradient for Mushkelishvili, -
    grad_wee = snap.grad_wee; % idem for Weertman, -
    y_delta_mus = snap.y_delta_mus; % y values for Mushkelishvili, m
    y_delta_wee = snap.y_delta_wee; % idem for Weertman, m
    y_til_mus = snap.y_til_mus; % slip patch boundary for Muskelishvili, m
    y_til_wee = snap.y_til_wee; % slip patch boundary for Weertman, m
end

a = model.a; % height of reservoir bottom part (for positive x values) or reservoir ...
    % top part (for negative x values), m
b = model.b; % height of reservoir top part (for positive x values) or reservoir ...
    % bottom part (for negative x values), m
i_snap_ref = plotpar.i_snap_ref; % snap shot serving as reference, -
n_snap = plotpar.n_snap; % number of snap_shots, - 
x_plot = plotpar.x_plot;
y_plot = plotpar.y_plot;
black = plotpar.colors.black;
blue = plotpar.colors.blue;
coal = plotpar.colors.coal;
gray = plotpar.colors.gray;
green = plotpar.colors.green;
orange = plotpar.colors.orange;
purple = plotpar.colors.purple;
red = plotpar.colors.red;

% Create plots:
if flag.fric == 1
    figure % Shear stresses and slip threshold (left) and Coulomb stresses (right) for a ...
        % single depletion pressure (@ p_inc = plotpar.p_inc_snap(2))
    ifs_plot_snaps_shear_Coulomb_single

    figure % Shear stresses and slip threshold (left) and Coulomb stresses (right) for ...
        % multiple depletion pressures (@ p_inc = plotpar.p_inc_snap(1:n_snap))
    ifs_plot_snaps_shear_Coulomb_multiple    
 
    figure % pre-slip Coulomb stresses (left) and slip (right) for a single depletion ...
        % pressure (@ p_inc = plotpar.p_inc_ref)        
    ifs_plot_snaps_Coulomb_slip_single

    figure % post-slip Coulomb stresses (left) and slip (right) for a single depletion ...
        % pressure (@ p_inc = plotpar.p_inc_ref)        
    ifs_plot_snaps_slip_and_post_C_stress_single    

    figure % pre-slip Coulomb stresses (left), slip (middle) and post-slip Coulomb stresses ...
        % for a single depletion pressure (@ p_inc = plotpar.p_inc_ref)        
    ifs_plot_snaps_Coulomb_slip_post_Coulomb

    figure % Coulomb stresses (left), slip gradient (middle) and slip (right) for multiple ...
        % depletion pressures (@ p_inc = plotpar.p_inc_snap(1:n_snap)) - detail
    ifs_plot_snaps_Coulomb_grad_slip_multiple      
    
    figure % post-slip Coulomb stresses (left), slip gradient (middle) and slip (right) ...
        % including incorrect Muskhelisvili and Weertman results - detail
    ifs_plot_snaps_post_Coulomb_Musk_Weert      

end

if flag.fric == 2   
    figure % Shear stress and slip threshold (left) and Coulomb stress (right) for a ...
        % single depletion pressure (@ p_inc = plotpar.p_inc_snap(2))
    ifs_plot_snaps_shear_Coulomb_single

    figure % Shear stresses and slip thresholds (left) and Coulomb stresses (right) for ...
        % multiple depletion pressures (@ p_inc = plotpar.p_inc_snap(1:n_snap))
    ifs_plot_snaps_shear_Coulomb_multiple    
 
    figure % pre-slip Coulomb stress (left) and slip (right) for a single depletion ...
    % pressure (@ p_inc = plotpar.p_inc_ref)        
    ifs_plot_snaps_Coulomb_slip_single        

    figure % slip (left) and post-slip Coulomb stress (right) for a single depletion ...
        % pressure (@ p_inc = plotpar.p_inc_ref)        
    ifs_plot_snaps_slip_and_post_C_stress_single

    figure % Coulomb stress (left), slip gradient (middle) and slip (right) for multiple ...
        % depletion pressures (@ p_inc = plotpar.p_inc_snap(1:n_snap)) - detail
    ifs_plot_snaps_Coulomb_grad_slip_multiple      

end

