function ifs_plot_step_history(data,flag,numpar,plotpar)
%
% Plots pressure stepping history (for diagnostics).
%

% Retrieve data:
p_inc = data.p_inc; % incremental pressure; negative for depletion, Pa
p_step = data.p_step; % pressure step history, Pa
y_step = data.y_step; % maximum slip patch boundary growth history, m 

dir = numpar.dir; % indicates operation: dir = 1: injection; dir = -1: depletion, - 
p_max_bounds = numpar.p_max_bounds; % highest incremental pressure (negative for depletion), Pa
p_min_bounds = numpar.p_min_bounds; % lowest incremental pressure (negative for depletion), Pa
p_step_init = numpar.p_step_init; % initial pressure step size (negative for depletion), Pa
p_step_max = numpar.p_step_max; % maximum allowed (largest absolute value) pressure step ...
    % size (negative for depletion), Pa
p_step_min = numpar.p_step_min; % minimum allowed (smallest absolute value) pressure step ...
    % size (negative for depletion), Pa
y_step_max = numpar.y_step_max; % maximum allowed y_step value, m
y_step_target = numpar.y_step_target; % target y_step value, m

n_snap = plotpar.n_snap; % number of snap_shots, - 
p_inc_ref = plotpar.p_inc_ref; % reference pressure used in image plots etc., Pa
p_inc_snap = plotpar.p_inc_snap; % incremental pressures at which to take snapshots, Pa

black = plotpar.colors.black;
green = plotpar.colors.green;
red = plotpar.colors.red;

figure
% p_step history:
subplot(2,1,1) 
hold on
line([dir*p_inc_ref/1e6 dir*p_inc_ref/1e6],[0 dir*p_step_max/1e6],'LineStyle','--','Color',...
    black,'LineWidth',0.5)
if flag.plot_snap == 1
    for i_snap = 1:n_snap
        line([dir*p_inc_snap(i_snap)/1e6 dir*p_inc_snap(i_snap)/1e6],[0 dir*p_step_max/1e6],...
            'LineStyle',':','Color',green,'LineWidth',1.0)
    end
end
line([dir*p_inc_ref/1e6 dir*p_inc_ref/1e6],[0 dir*p_step_max/1e6],'LineStyle','--','Color',...
    black,'LineWidth',0.5) % repeated to bring on top, while maintaining legend order
line([dir*p_max_bounds/1e6 dir*p_min_bounds/1e6],[dir*p_step_init/1e6 dir*p_step_init/1e6],...
    'LineStyle','-.','Color',black,'LineWidth',0.75)
line([dir*p_max_bounds/1e6 dir*p_min_bounds/1e6],[dir*p_step_max/1e6 dir*p_step_max/1e6],...
    'LineStyle','-.','Color',black,'LineWidth',0.75)
line([dir*p_max_bounds/1e6 dir*p_min_bounds/1e6],[dir*p_step_min/1e6 dir*p_step_min/1e6],...
    'LineStyle','-.','Color',black,'LineWidth',0.75)
plot(dir*p_inc/1e6,dir*p_step/1e6,'-o','Color',red,'MarkerEdgeColor',red,'LineWidth',1.0,...
    'MarkerSize',4);
hold off
p_min_bounds_plot = floor(1.02 * p_inc(end));
if dir == 1 % injection
    text_x = p_max_bounds/1e6 + 0.02 * (p_max_bounds-p_min_bounds_plot)/1e6; 
    axis([p_min_bounds/1e6 p_max_bounds/1e6 0 p_step_max/1e6])
else % depletion
    text_x = -p_min_bounds_plot/1e6 + 0.02 * (p_max_bounds-p_min_bounds_plot)/1e6; 
    axis([-p_max_bounds/1e6 -p_min_bounds_plot/1e6 0 -p_step_max/1e6])
end
text_y = dir*p_step_init/1e6;
text(text_x,text_y,'Initial','Interpreter','latex','FontSize',11)
text_y = dir*p_step_max/1e6;
text(text_x,text_y,'Max','Interpreter','latex','FontSize',11)
text_y = dir*p_step_min/1e6;
text(text_x,text_y,'Min','Interpreter','latex','FontSize',11)
box on
if flag.plot_snap == 1
    legend('$p_{ref}$','$p_{snap}$','Interpreter','latex','FontSize',10,'location',...
        'NorthWest')
end
switch flag.plot_nota
    case 0
        xlabel('$\it -p$ (MPa)','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$\rm-\Delta \it p$ (MPa)','Interpreter','latex','FontSize',11)
end
ylabel('$\rm -\Delta \it p_{step}$ (MPa)','Interpreter','latex','FontSize',11)
if flag.plot_cap == 1
    [t,s] = title('plot\_step\_history',' '); % first line: plot file locator
    t.Color = red;
    t.FontSize = 10;
    s.FontSize = 10;
    t.FontWeight = 'normal';
    s.FontWeight = 'normal';
end

% y_step history:
subplot(2,1,2)
hold on
if flag.plot_snap == 1
    for i_snap = 1:n_snap
        line([dir*p_inc_snap(i_snap)/1e6 dir*p_inc_snap(i_snap)/1e6],[0 dir*p_step_max/1e6],...
            'LineStyle',':','Color',green,'LineWidth',1.0)
    end
end
line([dir*p_inc_ref/1e6 dir*p_inc_ref/1e6],[0 y_step_max],'LineStyle','--','Color',...
    black,'LineWidth',0.5)
line([dir*p_max_bounds/1e6 dir*p_min_bounds/1e6],[y_step_max y_step_max],...
    'LineStyle','-.','Color',black,'LineWidth',0.75)
line([dir*p_max_bounds/1e6 dir*p_min_bounds/1e6],[y_step_target y_step_target],...
    'LineStyle','-.','Color',black,'LineWidth',0.75)
plot(dir*p_inc/1e6,y_step,'-o','Color',red,'MarkerEdgeColor',red,'LineWidth',1.0,...
    'MarkerSize',4);
hold off
box on
if dir == 1 % injection
    text_x = p_max_bounds_plot/1e6 + 0.02 * (p_max_bounds-p_min_bounds_plot)/1e6; 
    axis([p_min_bounds/1e6 p_max_bounds/1e6 0 y_step_max])
else % depletion
    text_x = -p_min_bounds_plot/1e6 + 0.02 * (p_max_bounds-p_min_bounds_plot)/1e6; 
    axis([-p_max_bounds/1e6 -p_min_bounds_plot/1e6 0 y_step_max])
end
text_y = y_step_target;
text(text_x,text_y,'Target','Interpreter','latex','FontSize',11)
text_y = y_step_max;
text(text_x,text_y,'Max','Interpreter','latex','FontSize',11)
switch flag.plot_nota
    case 0
        xlabel('$\it -p$ (MPa)','Interpreter','latex','FontSize',11)
    case 1
        xlabel('$\rm-\Delta \it p$ (MPa)','Interpreter','latex','FontSize',11)
end
ylabel('$\rm\Delta{\it y_{max,obs}}$ (m)','Interpreter','latex','FontSize',11)
