function [p_step_new,y_step_max_obs] = ifs_pressure_step(numpar,j,p_step_old,y_pre,...
    y_tilde,y_tilde_unc)
%
% Computes the pressure step size p_step_new for simulation with variable pressure steps. Aims
% at a value of p_step_new that results in a target y_step value, where y_step is the largest
% expected change in either the pre-slip Coulomb stress zeros y_pre(i,j), i = 1,...,4, or the 
% slip patch boundaries (coupled) y_tilde(i,j), or the slip patch boundaries y_tilde_unc(i,j)
% (uncoupled), where j is the current incremental pressure step.  

% Retrieve parameters and variables:
p_step_max = numpar.p_step_max; % maximum allowed (largest absolute value) pressure step ...
    % size (negative for depletion), Pa
p_step_min = numpar.p_step_min; % minimum allowed (smallest absolute value) pressure step ...
    % size (negative for depletion), Pa
y_step_target = numpar.y_step_target; % target y_step value, m
n_grow = numpar.n_grow; % exponent to determine agressiveness of pressure step udating;

% Compute next step with aim to achieve y_step = y_step_target:
y_step_obs = max(abs(y_pre(:,j-1) - y_pre(:,j-2))); % maximum observed change in pre-slip Coulomb ...
    % stress zeros y_pre(i,j), -
y_step_tilde_obs = max(abs(y_tilde(:,j-1) - y_tilde(:,j-2))); %  % maximum observerd ...
    % change in slip patch boundaries (coupled) y_tilde(i,j), -
y_step_tilde_unc_obs = max(abs(y_tilde_unc(:,j-1) - y_tilde_unc(:,j-2))); % maximum observerd ...
    % change in slip patch boundaries (uncoupled) y_tilde_unc(i,j), -
y_step_max_obs = max([y_step_obs,y_step_tilde_obs,y_step_tilde_unc_obs]);
p_step_new = p_step_old * (y_step_target/y_step_max_obs)^n_grow;

% Check step size:
if abs(p_step_new) > abs(p_step_max)
    p_step_new = p_step_max;
end
if abs(p_step_new) < abs(p_step_min)
    p_step_new = p_step_min;
end