function p_step_new = ifs_pressure_step_predict(numpar,j,p_step,y_pre,y_til)
%
% Computes the pressure step size p_step_new for simulation with variable pressure steps. Aims
% at a value of p_step_new that results in a target y_step value, where y_step is the largest
% expected change in either the pre-slip Coulomb stress zeros y_pre(i,j), i = 1,...,4, or the 
% slip patch boundaries y_til(i,j), and where j is the current incremental pressure step.
% Serves as a predictor in the sense that if the actual y_step value will turn out to be larger
% than the target y_step value the presure step will be repeated with a corrected (smaller)
% pressure step; see also ifs_pressure_step_correct.m.

% Retrieve:
y_step_target = numpar.y_step_target; % target y_step value, m
p_step_n_grow = numpar.p_step_n_grow; % exponent to determine agressiveness of pressure ...
    % step udating;

% Compute next step with aim to achieve y_step = y_step_target:
y_step_pre_obs = max(abs(y_pre(:,j-1) - y_pre(:,j-2))); % maximum observed change in pre-...
    % slip Coulomb stress zeros y_pre(i,j), -
y_step_til_obs = max(abs(y_til(:,j-1) - y_til(:,j-2))); %  % maximum observerd ...
    % change in slip patch boundaries (coupled) y_til(i,j), -
y_step_max_obs = max([y_step_pre_obs,y_step_til_obs]);
p_step_old = p_step(j-1);
p_step_new = p_step_old * (y_step_target/y_step_max_obs)^p_step_n_grow;

