function resid = ifs_resid_bounds(flag,model,numpar,plotpar,delta,p_inc,y_delta,y_loc)
%
% Computes residuals for computation of slip patch bounds y_bound with the aid of Matlab
% function fsolve. 
%

global c_bot c_mer c_top

% Retrieve:
% a       = model.a; 
delta_c = model.delta_c; % critical slip distance for slip weakening 0, m
mu_dyn  = model.mu_dyn; % dynamic friction coefficient, -
mu_st   = model.mu_st; % static friction coefficient, -
N_bot   = numpar.N_bot;
N_top   = numpar.N_top;
N_cheb  = numpar.N_cheb;
N_mer   = numpar.N_mer;

switch flag.sim_type     
    case {1,2} % uncoupled or coupled; y_loc has four elements            
        switch flag.int
            case {1,2} % inverse method: Gauss-Chebyshev quadrature, or Matlab's ...
                % variable-support trapezium rule
                [~,w_j_bot,~,y_j_bot] = ifs_GaussCheb(00,N_bot,y_loc(1),y_loc(2));
                [~,w_j_top,~,y_j_top] = ifs_GaussCheb(00,N_top,y_loc(3),y_loc(4));
                if delta == 0
                    delta_bot = 0;
                    delta_top = 0;
                    y_delta_bot = 0;
                    y_delta_top = 0;
                else
                    delta_bot = delta(2:N_bot);
                    delta_top = delta(N_bot+1:end-1);
                    y_delta_bot = y_delta(2:N_bot);
                    y_delta_top = y_delta(N_bot+1:end-1);
                end
            case 3 % forward method: discrete Chebyshev polynomials
                A = model.A;
                N = N_cheb/2;
                [~,~,~,y_j_bot] = ifs_GaussCheb(11,N,y_loc(1),y_loc(2));
                [~,~,~,y_j_top] = ifs_GaussCheb(11,N,y_loc(3),y_loc(4));
                delta_bot = 0;
                delta_top = 0;
                y_delta_bot = 0;
                y_delta_top = 0;
        end
        sigma_bot = ifs_sigma(flag,model,numpar,delta_bot,0,p_inc,y_delta_bot,y_j_bot,y_j_bot);
        sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,y_j_top,y_j_top);%%%
        if flag.sim_type == 2 % coupled simulation 
            if flag.int ~= 3 % inverse method: Gauss-Chebyshev quadrature or trapezium rule
                if flag.short == 1 % short cut procedure used to compute coupling effect
                    switch flag.int
                        case 1 % inverse method: Gauss-Chebyshev quadrature
                            F_bot = -sigma_bot.C ./ -ifs_Psi(y_j_bot,y_loc(3:4));
                            F_top = -sigma_top.C ./  ifs_Psi(y_j_top,y_loc(1:2));
                            switch flag.cond % coupling conditions
                                case 1 % correct conditions (default)
                                    resid(1) = sum(           F_bot .* w_j_bot) + ...
                                        sum(           F_top .* w_j_top); % I0
                                    resid(2) = sum(y_j_bot .* F_bot .* w_j_bot) + ...
                                        sum(y_j_top .* F_top .* w_j_top); % I1
                                    delta = ifs_delta(flag,model,numpar,plotpar,delta,p_inc,...
                                        y_delta,y_loc);
                                    N_delta = length(delta);
                                    resid(3) = delta(((N_delta-2)/2)+1) - delta(2);
                                    resid(4) = delta(N_delta-1) - delta(((N_delta-2)/2)+2);
                                case 2 % incorrect Muskelishvili conditions
                                    resid(1) = sum(           F_bot .* w_j_bot) + ...
                                        sum(           F_top .* w_j_top); % I0
                                    resid(2) = sum(y_j_bot .* F_bot .* w_j_bot) + ...
                                        sum(y_j_top .* F_top .* w_j_top); % I1
                                    resid(3) = sum(y_j_bot.^2 .* F_bot .* w_j_bot) + ...
                                        sum(y_j_top.^2 .* F_top .* w_j_top); % I2
                                    resid(4) = sum(y_j_bot.^3 .* F_bot .* w_j_bot) + ...
                                        sum(y_j_top.^3 .* F_top .* w_j_top); % I3
                                case 3 % incorrect Weertman conditions
                                    resid(1) = sum(           F_bot .* w_j_bot) + ...
                                        sum(           F_top .* w_j_top); % I0
                                    resid(2) = sum(y_j_bot .* F_bot .* w_j_bot) + ...
                                        sum(y_j_top .* F_top .* w_j_top); % I1
                                    resid(3) = sum(y_j_bot.^2 .* F_bot .* w_j_bot) + ...
                                        sum(y_j_top.^2 .* F_top .* w_j_top); % I2
                                    resid(4) = sum(y_j_bot.*abs(y_j_bot) .* F_bot .* ...
                                        w_j_bot) + sum(y_j_top.*abs(y_j_top) .* F_top .*...
                                        w_j_top); % I3
                            end
                        case 2 % inverse method: Matlab's variable-support trapezium rule
                            Psi_2_bot = -ifs_Psi(y_j_bot,y_loc(1:4));
                            Psi_2_top =  ifs_Psi(y_j_top,y_loc(1:4));
                            F_bot = -sigma_bot.C ./ Psi_2_bot;
                            F_top = -sigma_top.C ./ Psi_2_top;
                            switch flag.cond % coupling conditions
                                case 1 % correct conditions (default)
                                    resid(1) = trapz(y_j_bot,           F_bot) + ...
                                        trapz(y_j_top,           F_top); % I0
                                    resid(2) = trapz(y_j_bot,y_j_bot .* F_bot) + ...
                                        trapz(y_j_top,y_j_top .* F_top); % I1
                                    delta = ifs_delta(flag,model,numpar,plotpar,delta,p_inc,...
                                        y_delta,y_loc);
                                    N_delta = length(delta);
                                    resid(3) = delta(((N_delta-2)/2)+1) - delta(2);
                                    resid(4) = delta(N_delta-1) - delta(((N_delta-2)/2)+2);
                                case 2 % incorrect Muskelishvili conditions
                                    resid(1) = trapz(y_j_bot,           F_bot) + ...
                                        trapz(y_j_top,           F_top); % I0
                                    resid(2) = trapz(y_j_bot,y_j_bot .* F_bot) + ...
                                        trapz(y_j_top,y_j_top .* F_top); % I1
                                    resid(3) = trapz(y_j_bot,y_j_bot.^2 .* F_bot) + ...
                                        trapz(y_j_top,y_j_top.^2 .* F_top); % I2
                                    resid(4) = trapz(y_j_bot,y_j_bot.^3 .* F_bot) + ...
                                        trapz(y_j_top,y_j_top.^3 .* F_top); % I3
                                case 3 % incorrect Weertman conditions
                                    resid(1) = trapz(y_j_bot,           F_bot) + ...
                                        trapz(y_j_top,           F_top); % I0
                                    resid(2) = trapz(y_j_bot,y_j_bot .* F_bot) + ...
                                        trapz(y_j_top,y_j_top .* F_top); % I1
                                    resid(3) = trapz(y_j_bot,y_j_bot.^2 .* F_bot) + ...
                                        trapz(y_j_top,y_j_top.^2 .* F_top); % I2
                                    resid(4) = ...
                                        trapz(y_j_bot,y_j_bot.*abs(y_j_bot) .* F_bot) + ...
                                        trapz(y_j_top,y_j_top.*abs(y_j_top) .* F_top); % I3
                            end
                    end
                else % full procedure used to compute coupling effect
                    [C0,~,C1,~,D0,D1,D2,D3] = ifs_compute_CD(flag,model,numpar,delta,p_inc,...
                        y_delta,y_loc);
                    resid(1) = C0 + D0;
                    resid(2) = C1 + D1;
                    resid(3) = D2;
                    resid(4) = D3;
                end
            else % discrete Chebyshev polynomials
                N = N_cheb/2;
                T = numpar.T_1;
                U = numpar.U_2;
                z_n = numpar.z_U_2;
                z_m = numpar.z_T_1;
                NN = diag(1./(1:N));
                Z = diag(sqrt(1-z_n.^2));
                bar_y_bot = (y_loc(2)-y_loc(1))/2;
                bar_y_top = (y_loc(4)-y_loc(3))/2;
                y_bar_bot = (y_loc(1)+y_loc(2))/2;
                y_bar_top = (y_loc(3)+y_loc(4))/2;
                r_bot = sigma_bot.shear_comb + sigma_bot.norm_eff_comb*mu_st;
                r_top = sigma_top.shear_comb + sigma_top.norm_eff_comb*mu_st;
                r = [r_bot;r_top];
                w_tilde_bot = -bar_y_bot*sigma_bot.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                w_tilde_top = -bar_y_top*sigma_top.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                W_tilde_bot = diag(w_tilde_bot);
                W_tilde_top = diag(w_tilde_top);
                if flag.fric == 1
                    AA_11 = -A*pi*U;
                    AA_22 = -A*pi*U;
                else
                    AA_11 = W_tilde_bot*Z*U*NN - A*pi*U;
                    AA_22 = W_tilde_top*Z*U*NN - A*pi*U;
                end
                bar_r_bot = bar_y_bot/bar_y_top; % referred to as bar_r in paper 
                bar_r_top = bar_y_top/bar_y_bot; % referred to as 1/bar_r in paper
                r_bar_bot = (y_bar_top-y_bar_bot)/bar_y_top; % referred to as r_bar in paper
                r_bar_top = (y_bar_bot-y_bar_top)/bar_y_bot; % ref. to as -r_bar/bar_r in pap.
% %                 % Analytical integration:
% %                 alpha_bot = r_bar_bot-bar_r_bot*z_n;
% %                 alpha_top = -r_bar_top+bar_r_top*z_n;
% %                 omega_bot = -alpha_bot + sqrt(alpha_bot.^2-1);
% %                 omega_top = -alpha_top + sqrt(alpha_top.^2-1);                
% %                 Omega_bot = omega_bot .^(1:N)./sqrt(alpha_bot.^2-1);
% %                 Omega_top = omega_top .^(1:N)./sqrt(alpha_top.^2-1);
% %                 AA_12 = -A*pi * Omega_bot;
% %                 AA_21 = -A*pi * Omega_top;
                % Gauss-Chebyshev quadrature:
                Z_tilde_bot = 1./(z_m'-z_n*bar_r_bot+r_bar_bot); 
                Z_tilde_top = 1./(z_m'-z_n*bar_r_top+r_bar_top);
                AA_12 = -(A*pi/N) * Z_tilde_bot * T(:,2:N+1);
                AA_21 = -(A*pi/N) * Z_tilde_top * T(:,2:N+1);
                AA = [AA_11, AA_12;...
                      AA_21, AA_22];
                cc = AA\r;
                c_bot = cc(1:N); % a
                c_top = cc(N+1:end); % b
                c_bot_scaled = c_bot*A*pi;
                c_top_scaled = c_top*A*pi;
                resid(1) = sum( c_bot_scaled(1:2:end) );
                resid(2) = sum( c_bot_scaled(2:2:end) );
                resid(3) = sum( c_top_scaled(1:2:end) );
                resid(4) = sum( c_top_scaled(2:2:end) );
            end
        else % uncoupled
            switch flag.int
                case 1 % inverse method: Gauss-Chebyshev quadrature 
                    resid(1) = sum(           sigma_bot.C .* w_j_bot);
                    resid(2) = sum(y_j_bot .* sigma_bot.C .* w_j_bot);
                    resid(3) = sum(           sigma_top.C .* w_j_top);
                    resid(4) = sum(y_j_top .* sigma_top.C .* w_j_top);
                case 2 % inverse method: Matlab's variable-support trapezium rule
                    Psi_2_bot = ifs_Psi(y_j_bot,y_loc(1:2));
                    Psi_2_top = ifs_Psi(y_j_top,y_loc(3:4));
                    F_bot = -sigma_bot.C ./ Psi_2_bot;
                    F_top = -sigma_top.C ./ Psi_2_top;
                    resid(1) = trapz(y_j_bot,           F_bot);
                    resid(2) = trapz(y_j_bot,y_j_bot .* F_bot);
                    resid(3) = trapz(y_j_top,           F_top);
                    resid(4) = trapz(y_j_top,y_j_top .* F_top);
                case 3 % forward method: discrete Chebyshev polynomials
                    N = N_cheb/2;
                    U = numpar.U_2;
                    z_n = numpar.z_T_2;
                    NN = diag(1./(1:N));
                    Z = diag(sqrt(1-z_n.^2));
                    bar_y_bot = (y_loc(2)-y_loc(1))/2;
                    bar_y_top = (y_loc(4)-y_loc(3))/2;
                    r_bot = sigma_bot.shear_comb + sigma_bot.norm_eff_comb*mu_st;
                    r_top = sigma_top.shear_comb + sigma_top.norm_eff_comb*mu_st;
                    w_tilde_bot = -bar_y_bot*sigma_bot.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                    w_tilde_top = -bar_y_top*sigma_top.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                    W_tilde_bot = diag(w_tilde_bot);
                    W_tilde_top = diag(w_tilde_top);
                    if flag.fric == 1
                        AA_bot = -A*pi*U;
                        AA_top = -A*pi*U;
                    else
                        AA_bot = W_tilde_bot*Z*U*NN - A*pi*U;
                        AA_top = W_tilde_top*Z*U*NN - A*pi*U;
                    end
                    c_bot = AA_bot\r_bot;
                    c_top = AA_top\r_top;
                    c_bot_scaled = c_bot*A*pi; 
                    c_top_scaled = c_top*A*pi;
                    resid(1) = sum( c_bot_scaled(1:2:end) );
                    resid(2) = sum( c_bot_scaled(2:2:end) );
                    resid(3) = sum( c_top_scaled(1:2:end) );
                    resid(4) = sum( c_top_scaled(2:2:end) );
            end
        end  

    case 3 % merged; y_loc has two elements
        switch flag.int
            case {1,2} % inverse method: Gauss-Chebyshev quadrature, or Matlab's ...
                % variable-support trapezium rule
                [~,w_j_mer,~,y_j_mer] = ifs_GaussCheb(00,N_mer,y_loc(1),y_loc(2));
                if delta == 0
                    delta_mer = 0;
                    y_delta_mer = 0;
                else
                    delta_mer = delta(2:end-1);
                    y_delta_mer = y_delta(2:end-1);
                end
                sigma_mer = ifs_sigma(flag,model,numpar,delta_mer,0,p_inc,y_delta_mer,...
                    y_j_mer,y_j_mer);
            case 3 % forward method: discrete Chebyshev polynomials
                A = model.A;
                N = N_cheb/2;
                [~,~,~,y_j_mer] = ifs_GaussCheb(11,N,y_loc(1),y_loc(2));
                if delta == 0
                    delta_mer = 0;
                    y_delta_mer = 0;
                else
                    delta_mer = delta(2:end-1);
                    y_delta_mer = y_delta(2:end-1);
                end
                sigma_mer = ifs_sigma(flag,model,numpar,delta_mer,0,p_inc,y_delta_mer,...
                    y_j_mer,y_j_mer);
        end
        switch flag.int
            case 1 % inverse method: Gauss-Chebyshev quadrature
                resid(1) = sum(           sigma_mer.C .* w_j_mer);
                resid(2) = sum(y_j_mer .* sigma_mer.C .* w_j_mer);
            case 2 % inverse method: Matlab's variable-support trapezium rule
                Psi_mer = ifs_Psi(y_j_mer,y_loc(1:2));
                F_mer = -sigma_mer.C ./ Psi_mer;
                resid(1) = trapz(y_j_mer,           F_mer);
                resid(2) = trapz(y_j_mer,y_j_mer .* F_mer);
            case 3 % forward method: discrete Chebyshev polynomials
                N = N_cheb/2;
                U = numpar.U_2;
                z_n = numpar.z_U_2;
                NN = diag(1./(1:N));
                Z = diag(sqrt(1-z_n.^2));
                bar_y_mer = (y_loc(2)-y_loc(1))/2;
                r_mer = sigma_mer.shear_comb + sigma_mer.norm_eff_comb*mu_st;
                w_tilde_mer = -bar_y_mer*sigma_mer.norm_eff_comb*(mu_st-mu_dyn)/delta_c;
                W_tilde_mer = diag(w_tilde_mer);
                if flag.fric == 1
                    AA_mer = -A*pi*U;
                else
                    AA_mer = W_tilde_mer*Z*U*NN - A*pi*U;
                end
                c_mer = AA_mer\r_mer;
                c_mer_scaled = c_mer*A*pi;
                resid(1) = sum( c_mer_scaled(1:2:end) );
                resid(2) = sum( c_mer_scaled(2:2:end) );
        end
end






