function resid = ifs_resid_bounds_sym(flag,model,numpar,plotpar,delta,p_inc,y_delta,y_loc)
%
% Computes residuals for computation of slip patch bounds y_bound with the aid of Matlab
% function fsolve. Makes use of symmetry around y = 0.
%

switch flag.sim_type     
    case 1 % uncoupled; because of symmetry, y_loc has only two elements
        N = numpar.N_cheb; % number of integration steps
        N_sym = round(N/2);
        [~,w_j_top,~,y_j_top] = ifs_GaussCheb(00,N_sym,y_loc(1),y_loc(2));
        if delta == 0
            delta_top = 0;
            y_delta_top = 0;
        else
            delta_top = delta(N_sym+1:end-1);
            y_delta_top = y_delta(N_sym+1:end-1);
        end
        sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,y_j_top,y_j_top);
        switch flag.int
            case 1 % inverse method: Gauss-Chebyshev quadrature
                resid(1) = sum(           sigma_top.C .* w_j_top);
                resid(2) = sum(y_j_top .* sigma_top.C .* w_j_top);
            case 2 % inverse method: Matlab's variable-support trapezium rule
                Psi_top = -ifs_Psi(y_j_top,y_loc(1:2));
                resid(1) = trapz(y_j_top,           sigma_top.C ./ Psi_top);
                resid(2) = trapz(y_j_top,y_j_top .* sigma_top.C ./ Psi_top);
        end
        
    case 2 % coupled; because of symmetry, y_loc has only two elements        
        N = numpar.N_cheb; % number of integration steps
        N_sym = round(N/2);
        [~,w_j_top,~,y_j_top] = ifs_GaussCheb(00,N_sym,y_loc(1),y_loc(2));
        if delta == 0
            delta_top = 0;
            y_delta_top = 0;
        else
            delta_top = delta(N_sym+1:end-1);
            y_delta_top = y_delta(N_sym+1:end-1);
        end
        sigma_top = ifs_sigma(flag,model,numpar,delta_top,0,p_inc,y_delta_top,y_j_top,y_j_top);
        if flag.short == 1 % short cut procedure used to compute coupling effect
            switch flag.int
                case 1 % inverse method: Gauss-Chebyshev quadrature
                    F_top = -sigma_top.C ./ ifs_Psi(y_j_top,-y_loc(1:2));
                    switch flag.cond % coupling conditions
                        case 1 % correct conditions (default)
                            resid(1) = sum(y_j_top .* F_top .* w_j_top); % I1
                            delta = ifs_delta(flag,model,numpar,plotpar,0,p_inc,0,...
                                [-flip(y_loc'),y_loc']');
                            N_delta = length(delta);
                            resid(2) = delta(N_delta-1) - delta(((N_delta-2)/2)+2);
                        case 2 % incorrect Muskelishvili conditions
                            resid(1) = sum(y_j_top .* F_top .* w_j_top); % I1
                            resid(2) = sum(y_j_top.^3 .* F_top .* w_j_top); % I3
                        case 3 % incorrect Weertman conditions
                            resid(1) = sum(y_j_top .* F_top .* w_j_top); % I1
                            resid(2) = sum(y_j_top.*abs(y_j_top) .* F_top .* w_j_top); % I3
                   end
                case 2 % inverse method: Matlab's variable-support trapezium rule
                    Psi_2_sym = ifs_Psi(y_j_top.^2,y_loc(1:2).^2) ;
                    F_top = -sigma_top.C ./ Psi_2_sym;
                    switch flag.cond % coupling conditions
                        case 1 % correct conditions (default)
                            resid(1) = trapz(y_j_top,y_j_top .* F_top); % I1
                            delta = ifs_delta(flag,model,numpar,plotpar,0,p_inc,0,...
                                [-flip(y_loc'),y_loc']');
                            N_delta = length(delta);
                            resid(2) = delta(N_delta-1) - delta(((N_delta-2)/2)+2);
                        case 2 % incorrect Muskelishvili conditions
                            resid(1) = trapz(y_j_top,y_j_top .* F_top); % I1
                            resid(2) = trapz(y_j_top,y_j_top.^3 .* F_top); % I3
                        case 3 % incorrect Weertman conditions
                            resid(1) = trapz(y_j_top,y_j_top .* F_top); % I1
                            resid(2) = trapz(y_j_top,y_j_top.*abs(y_j_top) .* F_top); % I3
                    end
            end
        else % full procedure used to compute coupling effect
            [C0,~,D0,D2] = ifs_compute_CD_sym(flag,model,numpar,p_inc,y_loc);
            resid(1) = C0 + D0;
            resid(2) = D2;
        end

    case 3 % merged; because of symmetry, y_loc has only one element
        N_sym = numpar.N_mer;
        z_j = flip(cos( pi*((1:N_sym)-0.5)/N_sym ))';
        z_j_sym = z_j((N_sym+1)/2:N_sym); 
        bar_y_sym = y_loc;
        y_j_sym = z_j_sym * bar_y_sym;
        w_j_sym = pi/N_sym;
        if delta ~= 0
            delta = delta(2:end-1);
            delta_sym = delta((N_sym+1)/2:N_sym); 
            y_delta = y_delta(2:end-1);
            y_delta_sym = y_delta((N_sym+1)/2:N_sym); 
        else
            delta_sym = 0;
            y_delta_sym = 0;
        end
        sigma_sym = ifs_sigma(flag,model,numpar,delta_sym,0,p_inc,y_delta_sym,y_j_sym,y_j_sym);
        switch flag.int
            case 1 % inverse method: Gauss-Chebyshev quadrature
               resid(1) = sum(sigma_sym.C .* w_j_sym);
            case 2 % inverse method: Matlab's variable-support trapezium rule
                Psi_sym = ifs_Psi(y_j_sym.^2,y_loc.^2); % Psi tilde
                F_sym = -sigma_sym.C ./ Psi_sym;
                resid(1) = trapz(y_j_sym,F_sym);
        end
end    






