function y_pre = ifs_y_pre(flag,model,numpar,p_inc,y_pre_0)
%
% Computes the intersections y_pre(i), i = 1,...,4, of the combined shear stress with the right
% slip boundary, i.e. the zeros of the pre-slip Coulomb stress sigma_C.  
%
% y_pre_0 is an optional input argument containing an initial guess.
%

% Retrieve parameters:
a = model.a; % height of reservoir bottom part (for positive x values) or reservoir ...
    % top part (for negative x values), m; see Fig. 1 in Jansen et al. (2019)
b = model.b; % height of reservoir top part (for positive x values) or reservoir ...
    % bottom part (for negative x values), m
dir = numpar.dir; % indicates operation: dir = 1: injection; dir = -1: depletion, - 

% Set parameters:
small = 1e-12;
narrow_peak_bot = 0;
narrow_peak_top = 0;

% Compute initial guess:
if nargin == 4 % no initial guess supplied
    if dir == 1 % injection
        y_pre_0(1,:) = [-2*b     -b-small]; % interval containing initial guess, m
        y_pre_0(2,:) = [-b+small -a-small];
        y_pre_0(3,:) = [ a+small  b-small];
        y_pre_0(4,:) = [ b+small  2*b];
    else % depletion
        y_pre_0(1,:) = [-b+small -a-small]; % interval containing initial guess, m
        y_pre_0(2,:) = [-a+small  0      ];
        y_pre_0(3,:) = [ 0        a-small];
        y_pre_0(4,:) = [ a+small  b-small];
    end
end

% Compute intersections:
try
    y_pre(1) = fzero(@(y) ifs_resid_intersect(flag,model,numpar,p_inc,y),y_pre_0(1,:));
catch MExc
    if strcmp(MExc.identifier,'MATLAB:fzero:ValuesAtEndPtsSameSign') % no sign change at end
        % points detected by fzero
        y_pre(1) = -a-small;
        y_pre(2) = -a+small;
        narrow_peak_bot = 1;
    else % other error encountered by fzero
        error('Fatal error in fzero while computing y_pre(1).')
    end
end
try
    y_pre(4) = fzero(@(y) ifs_resid_intersect(flag,model,numpar,p_inc,y),y_pre_0(4,:));
catch MExc
    if strcmp(MExc.identifier,'MATLAB:fzero:ValuesAtEndPtsSameSign') % no sign change at end
        % points detected by fzero
        y_pre(4) = a+small;
        y_pre(3) = a-small;
        narrow_peak_top = 1;
    else % other error encountered by fzero
        error('Fatal error in fzerow hile computing y_pre(4).')
    end
end
if narrow_peak_bot == 0
    try
        y_pre(2) = fzero(@(y) ifs_resid_intersect(flag,model,numpar,p_inc,y),y_pre_0(2,:));
    catch MExc
        if strcmp(MExc.identifier,'MATLAB:fzero:ValuesAtEndPtsSameSign') % no sign change ...
            % at end points detected by fzero
            y_pre(2) = 0; % merging has occurred
        else % other error encountered by fzero
            error('Fatal error in fzero while computing y_pre(2).')
        end
    end
end
if narrow_peak_top == 0
    try
        y_pre(3) = fzero(@(y) ifs_resid_intersect(flag,model,numpar,p_inc,y),y_pre_0(3,:));
    catch MExc
        if strcmp(MExc.identifier,'MATLAB:fzero:ValuesAtEndPtsSameSign') % no sign change ...
            % at end points detected by fzero
            y_pre(3) = 0; % merging has occurred
        else % other error encountered by fzero
            error('Fatal error in fzero while computing y_pre(3).')
        end
    end
end
